# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: diode/v1/ingester.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from netboxlabs.diode.sdk.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64iode/v1/ingester.proto\x12\x08\x64iode.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xed+\n\x06\x45ntity\x12\x44\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xfa\x42\x07\xb2\x01\x04\x08\x01\x38\x01R\ttimestamp\x12!\n\x03\x61sn\x18\x02 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x03\x61sn\x12\x31\n\tasn_range\x18\x03 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x08\x61snRange\x12\x33\n\taggregate\x18\x04 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\taggregate\x12\'\n\x05\x63\x61\x62le\x18\x05 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x05\x63\x61\x62le\x12\x34\n\ncable_path\x18\x06 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\tcablePath\x12I\n\x11\x63\x61\x62le_termination\x18\x07 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x10\x63\x61\x62leTermination\x12-\n\x07\x63ircuit\x18\x08 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x07\x63ircuit\x12=\n\rcircuit_group\x18\t \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x0c\x63ircuitGroup\x12\\\n\x18\x63ircuit_group_assignment\x18\n \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R\x16\x63ircuitGroupAssignment\x12O\n\x13\x63ircuit_termination\x18\x0b \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x12\x63ircuitTermination\x12:\n\x0c\x63ircuit_type\x18\x0c \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x0b\x63ircuitType\x12-\n\x07\x63luster\x18\r \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x07\x63luster\x12=\n\rcluster_group\x18\x0e \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x0c\x63lusterGroup\x12:\n\x0c\x63luster_type\x18\x0f \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x0b\x63lusterType\x12:\n\x0c\x63onsole_port\x18\x10 \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x0b\x63onsolePort\x12M\n\x13\x63onsole_server_port\x18\x11 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x11\x63onsoleServerPort\x12-\n\x07\x63ontact\x18\x12 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x07\x63ontact\x12L\n\x12\x63ontact_assignment\x18\x13 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x11\x63ontactAssignment\x12=\n\rcontact_group\x18\x14 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x0c\x63ontactGroup\x12:\n\x0c\x63ontact_role\x18\x15 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x0b\x63ontactRole\x12*\n\x06\x64\x65vice\x18\x16 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x06\x64\x65vice\x12\x34\n\ndevice_bay\x18\x17 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\tdeviceBay\x12\x37\n\x0b\x64\x65vice_role\x18\x18 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\ndeviceRole\x12\x37\n\x0b\x64\x65vice_type\x18\x19 \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\ndeviceType\x12\x34\n\nfhrp_group\x18\x1a \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\tfhrpGroup\x12S\n\x15\x66hrp_group_assignment\x18\x1b \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x13\x66hrpGroupAssignment\x12\x34\n\nfront_port\x18\x1c \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\tfrontPort\x12\x34\n\nike_policy\x18\x1d \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\tikePolicy\x12:\n\x0cike_proposal\x18\x1e \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x0bikeProposal\x12\x34\n\nip_address\x18\x1f \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\tipAddress\x12.\n\x08ip_range\x18  \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x07ipRange\x12;\n\rip_sec_policy\x18! \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x0bipSecPolicy\x12>\n\x0eip_sec_profile\x18\" \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x0cipSecProfile\x12\x41\n\x0fip_sec_proposal\x18# \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\ripSecProposal\x12\x33\n\tinterface\x18$ \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\tinterface\x12@\n\x0einventory_item\x18% \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\rinventoryItem\x12M\n\x13inventory_item_role\x18& \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x11inventoryItemRole\x12\'\n\x05l2vpn\x18\' \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x05l2vpn\x12I\n\x11l2vpn_termination\x18( \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x10l2vpnTermination\x12\x30\n\x08location\x18) \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x08location\x12\x37\n\x0bmac_address\x18* \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\nmacAddress\x12<\n\x0cmanufacturer\x18+ \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x0cmanufacturer\x12*\n\x06module\x18, \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x12\x34\n\nmodule_bay\x18- \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\tmoduleBay\x12\x37\n\x0bmodule_type\x18. \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\nmoduleType\x12\x30\n\x08platform\x18/ \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x08platform\x12\x34\n\npower_feed\x18\x30 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\tpowerFeed\x12:\n\x0cpower_outlet\x18\x31 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x0bpowerOutlet\x12\x37\n\x0bpower_panel\x18\x32 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\npowerPanel\x12\x34\n\npower_port\x18\x33 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\tpowerPort\x12*\n\x06prefix\x18\x34 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x06prefix\x12\x30\n\x08provider\x18\x35 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x08provider\x12\x46\n\x10provider_account\x18\x36 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x0fproviderAccount\x12\x46\n\x10provider_network\x18\x37 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x0fproviderNetwork\x12!\n\x03rir\x18\x38 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x03rir\x12$\n\x04rack\x18\x39 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x04rack\x12\x46\n\x10rack_reservation\x18: \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x0frackReservation\x12\x31\n\track_role\x18; \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x08rackRole\x12\x31\n\track_type\x18< \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x08rackType\x12\x31\n\trear_port\x18= \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x08rearPort\x12*\n\x06region\x18> \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x06region\x12$\n\x04role\x18? \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\x04role\x12:\n\x0croute_target\x18@ \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x0brouteTarget\x12-\n\x07service\x18\x41 \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x07service\x12$\n\x04site\x18\x42 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x04site\x12\x34\n\nsite_group\x18\x43 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\tsiteGroup\x12!\n\x03tag\x18\x44 \x01(\x0b\x32\r.diode.v1.TagH\x00R\x03tag\x12*\n\x06tenant\x18\x45 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x12:\n\x0ctenant_group\x18\x46 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x0btenantGroup\x12*\n\x06tunnel\x18G \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x06tunnel\x12:\n\x0ctunnel_group\x18H \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x0btunnelGroup\x12L\n\x12tunnel_termination\x18I \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x11tunnelTermination\x12$\n\x04vlan\x18J \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\x04vlan\x12\x34\n\nvlan_group\x18K \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\tvlanGroup\x12Y\n\x17vlan_translation_policy\x18L \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R\x15vlanTranslationPolicy\x12S\n\x15vlan_translation_rule\x18M \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x13vlanTranslationRule\x12:\n\x0cvm_interface\x18N \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x0bvmInterface\x12!\n\x03vrf\x18O \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x03vrf\x12\x43\n\x0fvirtual_chassis\x18P \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x0evirtualChassis\x12\x43\n\x0fvirtual_circuit\x18Q \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x0evirtualCircuit\x12\x65\n\x1bvirtual_circuit_termination\x18R \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\x19virtualCircuitTermination\x12P\n\x14virtual_circuit_type\x18S \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x12virtualCircuitType\x12V\n\x16virtual_device_context\x18T \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x14virtualDeviceContext\x12:\n\x0cvirtual_disk\x18U \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x0bvirtualDisk\x12\x43\n\x0fvirtual_machine\x18V \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x0evirtualMachine\x12:\n\x0cwireless_lan\x18W \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x0bwirelessLan\x12J\n\x12wireless_lan_group\x18X \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x10wirelessLanGroup\x12=\n\rwireless_link\x18Y \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x0cwirelessLink\x12:\n\x0c\x63ustom_field\x18Z \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x0b\x63ustomField\x12W\n\x17\x63ustom_field_choice_set\x18[ \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x14\x63ustomFieldChoiceSet\x12=\n\rjournal_entry\x18\\ \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x0cjournalEntry\x12M\n\x13module_type_profile\x18] \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x11moduleTypeProfile\x12\x37\n\x0b\x63ustom_link\x18^ \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\ncustomLinkB\x08\n\x06\x65ntity\"\xe4\x02\n\rIngestRequest\x12\"\n\x06stream\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01R\x06stream\x12\x39\n\x08\x65ntities\x18\x02 \x03(\x0b\x32\x10.diode.v1.EntityB\x0b\xfa\x42\x08\x92\x01\x05\x08\x01\x10\xe8\x07R\x08\x65ntities\x12\x18\n\x02id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x36\n\x11producer_app_name\x18\x04 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01R\x0fproducerAppName\x12<\n\x14producer_app_version\x18\x05 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01R\x12producerAppVersion\x12%\n\x08sdk_name\x18\x06 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01R\x07sdkName\x12=\n\x0bsdk_version\x18\x07 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x15^(\\d)+\\.(\\d)+\\.(\\d)+$R\nsdkVersion\"(\n\x0eIngestResponse\x12\x16\n\x06\x65rrors\x18\x01 \x03(\tR\x06\x65rrors\"\xaa\x03\n\x03\x41SN\x12\x10\n\x03\x61sn\x18\x01 \x01(\x03R\x03\x61sn\x12$\n\x03rir\x18\x02 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x03rir\x88\x01\x01\x12-\n\x06tenant\x18\x03 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x44\n\rcustom_fields\x18\x07 \x03(\x0b\x32\x1f.diode.v1.ASN.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x06\n\x04_rirB\t\n\x07_tenantB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xb7\x03\n\x08\x41SNRange\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x1f\n\x03rir\x18\x03 \x01(\x0b\x32\r.diode.v1.RIRR\x03rir\x12\x14\n\x05start\x18\x04 \x01(\x03R\x05start\x12\x10\n\x03\x65nd\x18\x05 \x01(\x03R\x03\x65nd\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\t \x03(\x0b\x32$.diode.v1.ASNRange.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_tenantB\x0e\n\x0c_description\"\xfe\x03\n\tAggregate\x12\x16\n\x06prefix\x18\x01 \x01(\tR\x06prefix\x12\x1f\n\x03rir\x18\x02 \x01(\x0b\x32\r.diode.v1.RIRR\x03rir\x12-\n\x06tenant\x18\x03 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x88\x01\x01\x12>\n\ndate_added\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\tdateAdded\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x06 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x08 \x03(\x0b\x32%.diode.v1.Aggregate.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_tenantB\r\n\x0b_date_addedB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xf1\x07\n\x05\x43\x61\x62le\x12\xdd\x01\n\x04type\x18\x01 \x01(\tB\xc3\x01\xfa\x42\xbf\x01r\xbc\x01R\x03\x61ocR\x04\x63\x61t3R\x04\x63\x61t5R\x05\x63\x61t5eR\x04\x63\x61t6R\x05\x63\x61t6aR\x04\x63\x61t7R\x05\x63\x61t7aR\x04\x63\x61t8R\x07\x63oaxialR\ndac-activeR\x0b\x64\x61\x63-passiveR\x03mmfR\x07mmf-om1R\x07mmf-om2R\x07mmf-om3R\x07mmf-om4R\x07mmf-om5R\x0bmrj21-trunkR\x05powerR\x03smfR\x07smf-os1R\x07smf-os2R\x03usbH\x00R\x04type\x88\x01\x01\x12>\n\x0e\x61_terminations\x18\x02 \x03(\x0b\x32\x17.diode.v1.GenericObjectR\raTerminations\x12>\n\x0e\x62_terminations\x18\x03 \x03(\x0b\x32\x17.diode.v1.GenericObjectR\rbTerminations\x12G\n\x06status\x18\x04 \x01(\tB*\xfa\x42\'r%R\tconnectedR\x0f\x64\x65\x63ommissioningR\x07plannedH\x01R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x05 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12\x19\n\x05label\x18\x06 \x01(\tH\x03R\x05label\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x07 \x01(\tH\x04R\x05\x63olor\x88\x01\x01\x12\x1b\n\x06length\x18\x08 \x01(\x01H\x05R\x06length\x88\x01\x01\x12\x42\n\x0blength_unit\x18\t \x01(\tB\x1c\xfa\x42\x19r\x17R\x02\x63mR\x02\x66tR\x02inR\x02kmR\x01mR\x02miH\x06R\nlengthUnit\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\n \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0b \x01(\tH\x08R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0c \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x46\n\rcustom_fields\x18\r \x03(\x0b\x32!.diode.v1.Cable.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_typeB\t\n\x07_statusB\t\n\x07_tenantB\x08\n\x06_labelB\x08\n\x06_colorB\t\n\x07_lengthB\x0e\n\x0c_length_unitB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\x9e\x01\n\tCablePath\x12 \n\tis_active\x18\x01 \x01(\x08H\x00R\x08isActive\x88\x01\x01\x12$\n\x0bis_complete\x18\x02 \x01(\x08H\x01R\nisComplete\x88\x01\x01\x12\x1e\n\x08is_split\x18\x03 \x01(\x08H\x02R\x07isSplit\x88\x01\x01\x42\x0c\n\n_is_activeB\x0e\n\x0c_is_completeB\x0b\n\t_is_split\"\xe3\x06\n\x10\x43\x61\x62leTermination\x12%\n\x05\x63\x61\x62le\x18\x01 \x01(\x0b\x32\x0f.diode.v1.CableR\x05\x63\x61\x62le\x12(\n\tcable_end\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06R\x01\x41R\x01\x42R\x08\x63\x61\x62leEnd\x12\x66\n\x1ftermination_circuit_termination\x18\x03 \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x1dterminationCircuitTermination\x12Q\n\x18termination_console_port\x18\x04 \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x16terminationConsolePort\x12\x64\n\x1ftermination_console_server_port\x18\x05 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1cterminationConsoleServerPort\x12K\n\x16termination_front_port\x18\x06 \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x14terminationFrontPort\x12J\n\x15termination_interface\x18\x07 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x14terminationInterface\x12K\n\x16termination_power_feed\x18\x08 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x14terminationPowerFeed\x12Q\n\x18termination_power_outlet\x18\t \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x16terminationPowerOutlet\x12K\n\x16termination_power_port\x18\n \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x14terminationPowerPort\x12H\n\x15termination_rear_port\x18\x0b \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x13terminationRearPortB\r\n\x0btermination\"\xe6\x08\n\x07\x43ircuit\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\x12.\n\x08provider\x18\x02 \x01(\x0b\x32\x12.diode.v1.ProviderR\x08provider\x12I\n\x10provider_account\x18\x03 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x0fproviderAccount\x88\x01\x01\x12)\n\x04type\x18\x04 \x01(\x0b\x32\x15.diode.v1.CircuitTypeR\x04type\x12j\n\x06status\x18\x05 \x01(\tBM\xfa\x42JrHR\x06\x61\x63tiveR\x0e\x64\x65\x63ommissionedR\x0e\x64\x65provisioningR\x07offlineR\x07plannedR\x0cprovisioningH\x01R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12\x42\n\x0cinstall_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\x0binstallDate\x88\x01\x01\x12J\n\x10termination_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04R\x0fterminationDate\x88\x01\x01\x12$\n\x0b\x63ommit_rate\x18\t \x01(\x03H\x05R\ncommitRate\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\n \x01(\tH\x06R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x64istance\x18\x0b \x01(\x01H\x07R\x08\x64istance\x88\x01\x01\x12>\n\rdistance_unit\x18\x0c \x01(\tB\x14\xfa\x42\x11r\x0fR\x02\x66tR\x02kmR\x01mR\x02miH\x08R\x0c\x64istanceUnit\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\r \x01(\tH\tR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0e \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x42\n\x0b\x61ssignments\x18\x0f \x03(\x0b\x32 .diode.v1.CircuitGroupAssignmentR\x0b\x61ssignments\x12H\n\rcustom_fields\x18\x10 \x03(\x0b\x32#.diode.v1.Circuit.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x13\n\x11_provider_accountB\t\n\x07_statusB\t\n\x07_tenantB\x0f\n\r_install_dateB\x13\n\x11_termination_dateB\x0e\n\x0c_commit_rateB\x0e\n\x0c_descriptionB\x0b\n\t_distanceB\x10\n\x0e_distance_unitB\x0b\n\t_comments\"\xf6\x02\n\x0c\x43ircuitGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12-\n\x06tenant\x18\x04 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x06 \x03(\x0b\x32(.diode.v1.CircuitGroup.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\t\n\x07_tenant\"\xde\x02\n\x16\x43ircuitGroupAssignment\x12,\n\x05group\x18\x01 \x01(\x0b\x32\x16.diode.v1.CircuitGroupR\x05group\x12:\n\x0emember_circuit\x18\x02 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\rmemberCircuit\x12P\n\x16member_virtual_circuit\x18\x03 \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x14memberVirtualCircuit\x12N\n\x08priority\x18\x04 \x01(\tB-\xfa\x42*r(R\x08inactiveR\x07primaryR\tsecondaryR\x08tertiaryH\x01R\x08priority\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tagsB\x08\n\x06memberB\x0b\n\t_priority\"\x8c\x08\n\x12\x43ircuitTermination\x12+\n\x07\x63ircuit\x18\x01 \x01(\x0b\x32\x11.diode.v1.CircuitR\x07\x63ircuit\x12(\n\tterm_side\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06R\x01\x41R\x01ZR\x08termSide\x12G\n\x14termination_location\x18\x03 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x13terminationLocation\x12]\n\x1ctermination_provider_network\x18\x04 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x1aterminationProviderNetwork\x12\x41\n\x12termination_region\x18\x05 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x11terminationRegion\x12;\n\x10termination_site\x18\x06 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x0fterminationSite\x12K\n\x16termination_site_group\x18\x07 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x14terminationSiteGroup\x12\"\n\nport_speed\x18\x08 \x01(\x03H\x01R\tportSpeed\x88\x01\x01\x12*\n\x0eupstream_speed\x18\t \x01(\x03H\x02R\rupstreamSpeed\x88\x01\x01\x12$\n\x0bxconnect_id\x18\n \x01(\tH\x03R\nxconnectId\x88\x01\x01\x12\x1c\n\x07pp_info\x18\x0b \x01(\tH\x04R\x06ppInfo\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0c \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\r \x01(\x08H\x06R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\x0e \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12S\n\rcustom_fields\x18\x0f \x03(\x0b\x32..diode.v1.CircuitTermination.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0bterminationB\r\n\x0b_port_speedB\x11\n\x0f_upstream_speedB\x0e\n\x0c_xconnect_idB\n\n\x08_pp_infoB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\xdf\x02\n\x0b\x43ircuitType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x06 \x03(\x0b\x32\'.diode.v1.CircuitType.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_colorB\x0e\n\x0c_description\"\xc0\x06\n\x07\x43luster\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x15.diode.v1.ClusterTypeR\x04type\x12\x31\n\x05group\x18\x03 \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x01R\x05group\x88\x01\x01\x12V\n\x06status\x18\x04 \x01(\tB9\xfa\x42\x36r4R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x07offlineR\x07plannedR\x07stagingH\x02R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x05 \x01(\x0b\x32\x10.diode.v1.TenantH\x03R\x06tenant\x88\x01\x01\x12;\n\x0escope_location\x18\x06 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\rscopeLocation\x12\x35\n\x0cscope_region\x18\x07 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0bscopeRegion\x12/\n\nscope_site\x18\x08 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\tscopeSite\x12?\n\x10scope_site_group\x18\t \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0escopeSiteGroup\x12%\n\x0b\x64\x65scription\x18\n \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0b \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0c \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12H\n\rcustom_fields\x18\r \x03(\x0b\x32#.diode.v1.Cluster.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05scopeB\x08\n\x06_groupB\t\n\x07_statusB\t\n\x07_tenantB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xbc\x02\n\x0c\x43lusterGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x04 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x05 \x03(\x0b\x32(.diode.v1.ClusterGroup.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\xba\x02\n\x0b\x43lusterType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x04 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x05 \x03(\x0b\x32\'.diode.v1.ClusterType.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\xed\x05\n\x0b\x43onsolePort\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xab\x01\n\x04type\x18\x05 \x01(\tB\x91\x01\xfa\x42\x8d\x01r\x8a\x01R\x05\x64\x62-25R\x04\x64\x65-9R\nmini-din-8R\x05otherR\x05rj-11R\x05rj-12R\x05rj-45R\x05usb-aR\x05usb-bR\x05usb-cR\x0busb-micro-aR\x0cusb-micro-abR\x0busb-micro-bR\nusb-mini-aR\nusb-mini-bH\x02R\x04type\x88\x01\x01\x12<\n\x05speed\x18\x06 \x01(\x03\x42!\xfa\x42\x1e\"\x1c\x30\xb0\t0\xe0\x12\x30\xc0%0\x80K0\x80\x96\x01\x30\x80\xac\x02\x30\x80\xc2\x03\x30\x80\x84\x07H\x03R\x05speed\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\x08 \x01(\x08H\x05R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\n \x03(\x0b\x32\'.diode.v1.ConsolePort.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x07\n\x05_typeB\x08\n\x06_speedB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\xf9\x05\n\x11\x43onsoleServerPort\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xab\x01\n\x04type\x18\x05 \x01(\tB\x91\x01\xfa\x42\x8d\x01r\x8a\x01R\x05\x64\x62-25R\x04\x64\x65-9R\nmini-din-8R\x05otherR\x05rj-11R\x05rj-12R\x05rj-45R\x05usb-aR\x05usb-bR\x05usb-cR\x0busb-micro-aR\x0cusb-micro-abR\x0busb-micro-bR\nusb-mini-aR\nusb-mini-bH\x02R\x04type\x88\x01\x01\x12<\n\x05speed\x18\x06 \x01(\x03\x42!\xfa\x42\x1e\"\x1c\x30\xb0\t0\xe0\x12\x30\xc0%0\x80K0\x80\x96\x01\x30\x80\xac\x02\x30\x80\xc2\x03\x30\x80\x84\x07H\x03R\x05speed\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\x08 \x01(\x08H\x05R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12R\n\rcustom_fields\x18\n \x03(\x0b\x32-.diode.v1.ConsoleServerPort.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x07\n\x05_typeB\x08\n\x06_speedB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\xf9\x04\n\x07\x43ontact\x12\x35\n\x05group\x18\x01 \x01(\x0b\x32\x16.diode.v1.ContactGroupB\x02\x18\x01H\x00R\x05group\x88\x01\x01\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x19\n\x05title\x18\x03 \x01(\tH\x01R\x05title\x88\x01\x01\x12\x19\n\x05phone\x18\x04 \x01(\tH\x02R\x05phone\x88\x01\x01\x12\x19\n\x05\x65mail\x18\x05 \x01(\tH\x03R\x05\x65mail\x88\x01\x01\x12\x1d\n\x07\x61\x64\x64ress\x18\x06 \x01(\tH\x04R\x07\x61\x64\x64ress\x88\x01\x01\x12\x17\n\x04link\x18\x07 \x01(\tH\x05R\x04link\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x06R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\t \x01(\tH\x07R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\n \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12H\n\rcustom_fields\x18\x0b \x03(\x0b\x32#.diode.v1.Contact.CustomFieldsEntryR\x0c\x63ustomFields\x12.\n\x06groups\x18\x0c \x03(\x0b\x32\x16.diode.v1.ContactGroupR\x06groups\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_groupB\x08\n\x06_titleB\x08\n\x06_phoneB\x08\n\x06_emailB\n\n\x08_addressB\x07\n\x05_linkB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\x82\x38\n\x11\x43ontactAssignment\x12.\n\nobject_asn\x18\x01 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\tobjectAsn\x12>\n\x10object_asn_range\x18\x02 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x0eobjectAsnRange\x12@\n\x10object_aggregate\x18\x03 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x0fobjectAggregate\x12\x34\n\x0cobject_cable\x18\x04 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x0bobjectCable\x12\x41\n\x11object_cable_path\x18\x05 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x0fobjectCablePath\x12V\n\x18object_cable_termination\x18\x06 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x16objectCableTermination\x12:\n\x0eobject_circuit\x18\x07 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\robjectCircuit\x12J\n\x14object_circuit_group\x18\x08 \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x12objectCircuitGroup\x12i\n\x1fobject_circuit_group_assignment\x18\t \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R\x1cobjectCircuitGroupAssignment\x12\\\n\x1aobject_circuit_termination\x18\n \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x18objectCircuitTermination\x12G\n\x13object_circuit_type\x18\x0b \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x11objectCircuitType\x12:\n\x0eobject_cluster\x18\x0c \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\robjectCluster\x12J\n\x14object_cluster_group\x18\r \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x12objectClusterGroup\x12G\n\x13object_cluster_type\x18\x0e \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x11objectClusterType\x12G\n\x13object_console_port\x18\x0f \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x11objectConsolePort\x12Z\n\x1aobject_console_server_port\x18\x10 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x17objectConsoleServerPort\x12:\n\x0eobject_contact\x18\x11 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\robjectContact\x12Y\n\x19object_contact_assignment\x18\x12 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x17objectContactAssignment\x12J\n\x14object_contact_group\x18\x13 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x12objectContactGroup\x12G\n\x13object_contact_role\x18\x14 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x11objectContactRole\x12\x37\n\robject_device\x18\x15 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x0cobjectDevice\x12\x41\n\x11object_device_bay\x18\x16 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x0fobjectDeviceBay\x12\x44\n\x12object_device_role\x18\x17 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x10objectDeviceRole\x12\x44\n\x12object_device_type\x18\x18 \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x10objectDeviceType\x12\x41\n\x11object_fhrp_group\x18\x19 \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x0fobjectFhrpGroup\x12`\n\x1cobject_fhrp_group_assignment\x18\x1a \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x19objectFhrpGroupAssignment\x12\x41\n\x11object_front_port\x18\x1b \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x0fobjectFrontPort\x12\x41\n\x11object_ike_policy\x18\x1c \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x0fobjectIkePolicy\x12G\n\x13object_ike_proposal\x18\x1d \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x11objectIkeProposal\x12\x41\n\x11object_ip_address\x18\x1e \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x0fobjectIpAddress\x12;\n\x0fobject_ip_range\x18\x1f \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\robjectIpRange\x12H\n\x14object_ip_sec_policy\x18  \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x11objectIpSecPolicy\x12K\n\x15object_ip_sec_profile\x18! \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x12objectIpSecProfile\x12N\n\x16object_ip_sec_proposal\x18\" \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x13objectIpSecProposal\x12@\n\x10object_interface\x18# \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x0fobjectInterface\x12M\n\x15object_inventory_item\x18$ \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x13objectInventoryItem\x12Z\n\x1aobject_inventory_item_role\x18% \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x17objectInventoryItemRole\x12\x34\n\x0cobject_l2vpn\x18& \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x0bobjectL2vpn\x12V\n\x18object_l2vpn_termination\x18\' \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x16objectL2vpnTermination\x12=\n\x0fobject_location\x18( \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x0eobjectLocation\x12\x44\n\x12object_mac_address\x18) \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x10objectMacAddress\x12I\n\x13object_manufacturer\x18* \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x12objectManufacturer\x12\x37\n\robject_module\x18+ \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x0cobjectModule\x12\x41\n\x11object_module_bay\x18, \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x0fobjectModuleBay\x12\x44\n\x12object_module_type\x18- \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x10objectModuleType\x12=\n\x0fobject_platform\x18. \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x0eobjectPlatform\x12\x41\n\x11object_power_feed\x18/ \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x0fobjectPowerFeed\x12G\n\x13object_power_outlet\x18\x30 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x11objectPowerOutlet\x12\x44\n\x12object_power_panel\x18\x31 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x10objectPowerPanel\x12\x41\n\x11object_power_port\x18\x32 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x0fobjectPowerPort\x12\x37\n\robject_prefix\x18\x33 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x0cobjectPrefix\x12=\n\x0fobject_provider\x18\x34 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x0eobjectProvider\x12S\n\x17object_provider_account\x18\x35 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x15objectProviderAccount\x12S\n\x17object_provider_network\x18\x36 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x15objectProviderNetwork\x12.\n\nobject_rir\x18\x37 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\tobjectRir\x12\x31\n\x0bobject_rack\x18\x38 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\nobjectRack\x12S\n\x17object_rack_reservation\x18\x39 \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x15objectRackReservation\x12>\n\x10object_rack_role\x18: \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x0eobjectRackRole\x12>\n\x10object_rack_type\x18; \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x0eobjectRackType\x12>\n\x10object_rear_port\x18< \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x0eobjectRearPort\x12\x37\n\robject_region\x18= \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0cobjectRegion\x12\x31\n\x0bobject_role\x18> \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\nobjectRole\x12G\n\x13object_route_target\x18? \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x11objectRouteTarget\x12:\n\x0eobject_service\x18@ \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\robjectService\x12\x31\n\x0bobject_site\x18\x41 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\nobjectSite\x12\x41\n\x11object_site_group\x18\x42 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0fobjectSiteGroup\x12.\n\nobject_tag\x18\x43 \x01(\x0b\x32\r.diode.v1.TagH\x00R\tobjectTag\x12\x37\n\robject_tenant\x18\x44 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x0cobjectTenant\x12G\n\x13object_tenant_group\x18\x45 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x11objectTenantGroup\x12\x37\n\robject_tunnel\x18\x46 \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x0cobjectTunnel\x12G\n\x13object_tunnel_group\x18G \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x11objectTunnelGroup\x12Y\n\x19object_tunnel_termination\x18H \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x17objectTunnelTermination\x12\x31\n\x0bobject_vlan\x18I \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\nobjectVlan\x12\x41\n\x11object_vlan_group\x18J \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x0fobjectVlanGroup\x12\x66\n\x1eobject_vlan_translation_policy\x18K \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R\x1bobjectVlanTranslationPolicy\x12`\n\x1cobject_vlan_translation_rule\x18L \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x19objectVlanTranslationRule\x12G\n\x13object_vm_interface\x18M \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x11objectVmInterface\x12.\n\nobject_vrf\x18N \x01(\x0b\x32\r.diode.v1.VRFH\x00R\tobjectVrf\x12P\n\x16object_virtual_chassis\x18O \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x14objectVirtualChassis\x12P\n\x16object_virtual_circuit\x18P \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x14objectVirtualCircuit\x12r\n\"object_virtual_circuit_termination\x18Q \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\x1fobjectVirtualCircuitTermination\x12]\n\x1bobject_virtual_circuit_type\x18R \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x18objectVirtualCircuitType\x12\x63\n\x1dobject_virtual_device_context\x18S \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x1aobjectVirtualDeviceContext\x12G\n\x13object_virtual_disk\x18T \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x11objectVirtualDisk\x12P\n\x16object_virtual_machine\x18U \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x14objectVirtualMachine\x12G\n\x13object_wireless_lan\x18V \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x11objectWirelessLan\x12W\n\x19object_wireless_lan_group\x18W \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x16objectWirelessLanGroup\x12J\n\x14object_wireless_link\x18X \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x12objectWirelessLink\x12G\n\x13object_custom_field\x18^ \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x11objectCustomField\x12\x64\n\x1eobject_custom_field_choice_set\x18_ \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x1aobjectCustomFieldChoiceSet\x12J\n\x14object_journal_entry\x18` \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x12objectJournalEntry\x12Z\n\x1aobject_module_type_profile\x18\x61 \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x17objectModuleTypeProfile\x12\x44\n\x12object_custom_link\x18\x62 \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x10objectCustomLink\x12+\n\x07\x63ontact\x18Y \x01(\x0b\x32\x11.diode.v1.ContactR\x07\x63ontact\x12.\n\x04role\x18Z \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x01R\x04role\x88\x01\x01\x12N\n\x08priority\x18[ \x01(\tB-\xfa\x42*r(R\x08inactiveR\x07primaryR\tsecondaryR\x08tertiaryH\x02R\x08priority\x88\x01\x01\x12!\n\x04tags\x18\\ \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12R\n\rcustom_fields\x18] \x03(\x0b\x32-.diode.v1.ContactAssignment.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06objectB\x07\n\x05_roleB\x0b\n\t_priority\"\xaa\x03\n\x0c\x43ontactGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x33\n\x06parent\x18\x03 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x06parent\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x06 \x03(\x0b\x32(.diode.v1.ContactGroup.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xba\x02\n\x0b\x43ontactRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x04 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x05 \x03(\x0b\x32\'.diode.v1.ContactRole.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\xbb+\n\x1a\x43ustomFieldObjectReference\x12!\n\x03\x61sn\x18\x01 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x03\x61sn\x12\x31\n\tasn_range\x18\x02 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x08\x61snRange\x12\x33\n\taggregate\x18\x03 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\taggregate\x12\'\n\x05\x63\x61\x62le\x18\x04 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x05\x63\x61\x62le\x12\x34\n\ncable_path\x18\x05 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\tcablePath\x12I\n\x11\x63\x61\x62le_termination\x18\x06 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x10\x63\x61\x62leTermination\x12-\n\x07\x63ircuit\x18\x07 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x07\x63ircuit\x12=\n\rcircuit_group\x18\x08 \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x0c\x63ircuitGroup\x12\\\n\x18\x63ircuit_group_assignment\x18\t \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R\x16\x63ircuitGroupAssignment\x12O\n\x13\x63ircuit_termination\x18\n \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x12\x63ircuitTermination\x12:\n\x0c\x63ircuit_type\x18\x0b \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x0b\x63ircuitType\x12-\n\x07\x63luster\x18\x0c \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x07\x63luster\x12=\n\rcluster_group\x18\r \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x0c\x63lusterGroup\x12:\n\x0c\x63luster_type\x18\x0e \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x0b\x63lusterType\x12:\n\x0c\x63onsole_port\x18\x0f \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x0b\x63onsolePort\x12M\n\x13\x63onsole_server_port\x18\x10 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x11\x63onsoleServerPort\x12-\n\x07\x63ontact\x18\x11 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x07\x63ontact\x12L\n\x12\x63ontact_assignment\x18\x12 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x11\x63ontactAssignment\x12=\n\rcontact_group\x18\x13 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x0c\x63ontactGroup\x12:\n\x0c\x63ontact_role\x18\x14 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x0b\x63ontactRole\x12*\n\x06\x64\x65vice\x18\x15 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x06\x64\x65vice\x12\x34\n\ndevice_bay\x18\x16 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\tdeviceBay\x12\x37\n\x0b\x64\x65vice_role\x18\x17 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\ndeviceRole\x12\x37\n\x0b\x64\x65vice_type\x18\x18 \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\ndeviceType\x12\x34\n\nfhrp_group\x18\x19 \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\tfhrpGroup\x12S\n\x15\x66hrp_group_assignment\x18\x1a \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x13\x66hrpGroupAssignment\x12\x34\n\nfront_port\x18\x1b \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\tfrontPort\x12\x34\n\nike_policy\x18\x1c \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\tikePolicy\x12:\n\x0cike_proposal\x18\x1d \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x0bikeProposal\x12\x34\n\nip_address\x18\x1e \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\tipAddress\x12.\n\x08ip_range\x18\x1f \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x07ipRange\x12;\n\rip_sec_policy\x18  \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x0bipSecPolicy\x12>\n\x0eip_sec_profile\x18! \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x0cipSecProfile\x12\x41\n\x0fip_sec_proposal\x18\" \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\ripSecProposal\x12\x33\n\tinterface\x18# \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\tinterface\x12@\n\x0einventory_item\x18$ \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\rinventoryItem\x12M\n\x13inventory_item_role\x18% \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x11inventoryItemRole\x12\'\n\x05l2vpn\x18& \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x05l2vpn\x12I\n\x11l2vpn_termination\x18\' \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x10l2vpnTermination\x12\x30\n\x08location\x18( \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x08location\x12\x37\n\x0bmac_address\x18) \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\nmacAddress\x12<\n\x0cmanufacturer\x18* \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x0cmanufacturer\x12*\n\x06module\x18+ \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x12\x34\n\nmodule_bay\x18, \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\tmoduleBay\x12\x37\n\x0bmodule_type\x18- \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\nmoduleType\x12\x30\n\x08platform\x18. \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x08platform\x12\x34\n\npower_feed\x18/ \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\tpowerFeed\x12:\n\x0cpower_outlet\x18\x30 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x0bpowerOutlet\x12\x37\n\x0bpower_panel\x18\x31 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\npowerPanel\x12\x34\n\npower_port\x18\x32 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\tpowerPort\x12*\n\x06prefix\x18\x33 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x06prefix\x12\x30\n\x08provider\x18\x34 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x08provider\x12\x46\n\x10provider_account\x18\x35 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x0fproviderAccount\x12\x46\n\x10provider_network\x18\x36 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x0fproviderNetwork\x12!\n\x03rir\x18\x37 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x03rir\x12$\n\x04rack\x18\x38 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x04rack\x12\x46\n\x10rack_reservation\x18\x39 \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x0frackReservation\x12\x31\n\track_role\x18: \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x08rackRole\x12\x31\n\track_type\x18; \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x08rackType\x12\x31\n\trear_port\x18< \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x08rearPort\x12*\n\x06region\x18= \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x06region\x12$\n\x04role\x18> \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\x04role\x12:\n\x0croute_target\x18? \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x0brouteTarget\x12-\n\x07service\x18@ \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x07service\x12$\n\x04site\x18\x41 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x04site\x12\x34\n\nsite_group\x18\x42 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\tsiteGroup\x12!\n\x03tag\x18\x43 \x01(\x0b\x32\r.diode.v1.TagH\x00R\x03tag\x12*\n\x06tenant\x18\x44 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x12:\n\x0ctenant_group\x18\x45 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x0btenantGroup\x12*\n\x06tunnel\x18\x46 \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x06tunnel\x12:\n\x0ctunnel_group\x18G \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x0btunnelGroup\x12L\n\x12tunnel_termination\x18H \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x11tunnelTermination\x12$\n\x04vlan\x18I \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\x04vlan\x12\x34\n\nvlan_group\x18J \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\tvlanGroup\x12Y\n\x17vlan_translation_policy\x18K \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R\x15vlanTranslationPolicy\x12S\n\x15vlan_translation_rule\x18L \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x13vlanTranslationRule\x12:\n\x0cvm_interface\x18M \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x0bvmInterface\x12!\n\x03vrf\x18N \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x03vrf\x12\x43\n\x0fvirtual_chassis\x18O \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x0evirtualChassis\x12\x43\n\x0fvirtual_circuit\x18P \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x0evirtualCircuit\x12\x65\n\x1bvirtual_circuit_termination\x18Q \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\x19virtualCircuitTermination\x12P\n\x14virtual_circuit_type\x18R \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x12virtualCircuitType\x12V\n\x16virtual_device_context\x18S \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x14virtualDeviceContext\x12:\n\x0cvirtual_disk\x18T \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x0bvirtualDisk\x12\x43\n\x0fvirtual_machine\x18U \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x0evirtualMachine\x12:\n\x0cwireless_lan\x18V \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x0bwirelessLan\x12J\n\x12wireless_lan_group\x18W \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x10wirelessLanGroup\x12=\n\rwireless_link\x18X \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x0cwirelessLink\x12:\n\x0c\x63ustom_field\x18Y \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x0b\x63ustomField\x12W\n\x17\x63ustom_field_choice_set\x18Z \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x14\x63ustomFieldChoiceSet\x12=\n\rjournal_entry\x18[ \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x0cjournalEntry\x12M\n\x13module_type_profile\x18\\ \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x11moduleTypeProfile\x12\x37\n\x0b\x63ustom_link\x18] \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\ncustomLinkB\x08\n\x06object\"\x9a\x04\n\x10\x43ustomFieldValue\x12-\n\x12multiple_selection\x18\x01 \x03(\tR\x11multipleSelection\x12O\n\x10multiple_objects\x18\x02 \x03(\x0b\x32$.diode.v1.CustomFieldObjectReferenceR\x0fmultipleObjects\x12\x14\n\x04text\x18\x03 \x01(\tH\x00R\x04text\x12\x1d\n\tlong_text\x18\x04 \x01(\tH\x00R\x08longText\x12\x1a\n\x07integer\x18\x05 \x01(\x03H\x00R\x07integer\x12\x1a\n\x07\x64\x65\x63imal\x18\x06 \x01(\x01H\x00R\x07\x64\x65\x63imal\x12\x1a\n\x07\x62oolean\x18\x07 \x01(\x08H\x00R\x07\x62oolean\x12\x30\n\x04\x64\x61te\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x04\x64\x61te\x12\x38\n\x08\x64\x61tetime\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08\x64\x61tetime\x12\x12\n\x03url\x18\n \x01(\tH\x00R\x03url\x12\x14\n\x04json\x18\x0b \x01(\tH\x00R\x04json\x12\x1e\n\tselection\x18\x0c \x01(\tH\x00R\tselection\x12>\n\x06object\x18\r \x01(\x0b\x32$.diode.v1.CustomFieldObjectReferenceH\x00R\x06objectB\x07\n\x05value\"\xf1\r\n\x06\x44\x65vice\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12\x35\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0b\x32\x14.diode.v1.DeviceTypeR\ndeviceType\x12(\n\x04role\x18\x03 \x01(\x0b\x32\x14.diode.v1.DeviceRoleR\x04role\x12-\n\x06tenant\x18\x04 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12\x33\n\x08platform\x18\x05 \x01(\x0b\x32\x12.diode.v1.PlatformH\x02R\x08platform\x88\x01\x01\x12\x1b\n\x06serial\x18\x06 \x01(\tH\x03R\x06serial\x88\x01\x01\x12 \n\tasset_tag\x18\x07 \x01(\tH\x04R\x08\x61ssetTag\x88\x01\x01\x12\"\n\x04site\x18\x08 \x01(\x0b\x32\x0e.diode.v1.SiteR\x04site\x12\x33\n\x08location\x18\t \x01(\x0b\x32\x12.diode.v1.LocationH\x05R\x08location\x88\x01\x01\x12\'\n\x04rack\x18\n \x01(\x0b\x32\x0e.diode.v1.RackH\x06R\x04rack\x88\x01\x01\x12\x1f\n\x08position\x18\x0b \x01(\x01H\x07R\x08position\x88\x01\x01\x12+\n\x04\x66\x61\x63\x65\x18\x0c \x01(\tB\x12\xfa\x42\x0fr\rR\x05\x66rontR\x04rearH\x08R\x04\x66\x61\x63\x65\x88\x01\x01\x12\x1f\n\x08latitude\x18\r \x01(\x01H\tR\x08latitude\x88\x01\x01\x12!\n\tlongitude\x18\x0e \x01(\x01H\nR\tlongitude\x88\x01\x01\x12h\n\x06status\x18\x0f \x01(\tBK\xfa\x42HrFR\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x06\x66\x61iledR\tinventoryR\x07offlineR\x07plannedR\x06stagedH\x0bR\x06status\x88\x01\x01\x12\xad\x01\n\x07\x61irflow\x18\x10 \x01(\tB\x8d\x01\xfa\x42\x89\x01r\x86\x01R\rbottom-to-topR\rfront-to-rearR\rleft-to-rightR\x05mixedR\x07passiveR\rrear-to-frontR\x0crear-to-sideR\rright-to-leftR\x0cside-to-rearR\rtop-to-bottomH\x0cR\x07\x61irflow\x88\x01\x01\x12\x39\n\x0bprimary_ip4\x18\x11 \x01(\x0b\x32\x13.diode.v1.IPAddressH\rR\nprimaryIp4\x88\x01\x01\x12\x39\n\x0bprimary_ip6\x18\x12 \x01(\x0b\x32\x13.diode.v1.IPAddressH\x0eR\nprimaryIp6\x88\x01\x01\x12/\n\x06oob_ip\x18\x13 \x01(\x0b\x32\x13.diode.v1.IPAddressH\x0fR\x05oobIp\x88\x01\x01\x12\x30\n\x07\x63luster\x18\x14 \x01(\x0b\x32\x11.diode.v1.ClusterH\x10R\x07\x63luster\x88\x01\x01\x12\x46\n\x0fvirtual_chassis\x18\x15 \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x11R\x0evirtualChassis\x88\x01\x01\x12$\n\x0bvc_position\x18\x16 \x01(\x03H\x12R\nvcPosition\x88\x01\x01\x12$\n\x0bvc_priority\x18\x17 \x01(\x03H\x13R\nvcPriority\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x18 \x01(\tH\x14R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x19 \x01(\tH\x15R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x1a \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\x1b \x03(\x0b\x32\".diode.v1.Device.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\t\n\x07_tenantB\x0b\n\t_platformB\t\n\x07_serialB\x0c\n\n_asset_tagB\x0b\n\t_locationB\x07\n\x05_rackB\x0b\n\t_positionB\x07\n\x05_faceB\x0b\n\t_latitudeB\x0c\n\n_longitudeB\t\n\x07_statusB\n\n\x08_airflowB\x0e\n\x0c_primary_ip4B\x0e\n\x0c_primary_ip6B\t\n\x07_oob_ipB\n\n\x08_clusterB\x12\n\x10_virtual_chassisB\x0e\n\x0c_vc_positionB\x0e\n\x0c_vc_priorityB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xc8\x03\n\tDeviceBay\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x19\n\x05label\x18\x03 \x01(\tH\x00R\x05label\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12@\n\x10installed_device\x18\x05 \x01(\x0b\x32\x10.diode.v1.DeviceH\x02R\x0finstalledDevice\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x07 \x03(\x0b\x32%.diode.v1.DeviceBay.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_labelB\x0e\n\x0c_descriptionB\x13\n\x11_installed_device\"\xf3\x03\n\nDeviceRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12\x1c\n\x07vm_role\x18\x04 \x01(\x08H\x01R\x06vmRole\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12K\n\rcustom_fields\x18\x07 \x03(\x0b\x32&.diode.v1.DeviceRole.CustomFieldsEntryR\x0c\x63ustomFields\x12\x31\n\x06parent\x18\x08 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x03R\x06parent\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\t \x01(\tH\x04R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_colorB\n\n\x08_vm_roleB\x0e\n\x0c_descriptionB\t\n\x07_parentB\x0b\n\t_comments\"\xfc\x08\n\nDeviceType\x12:\n\x0cmanufacturer\x18\x01 \x01(\x0b\x32\x16.diode.v1.ManufacturerR\x0cmanufacturer\x12\x42\n\x10\x64\x65\x66\x61ult_platform\x18\x02 \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x0f\x64\x65\x66\x61ultPlatform\x88\x01\x01\x12\x14\n\x05model\x18\x03 \x01(\tR\x05model\x12\x12\n\x04slug\x18\x04 \x01(\tR\x04slug\x12$\n\x0bpart_number\x18\x05 \x01(\tH\x01R\npartNumber\x88\x01\x01\x12\x1e\n\x08u_height\x18\x06 \x01(\x01H\x02R\x07uHeight\x88\x01\x01\x12=\n\x18\x65xclude_from_utilization\x18\x07 \x01(\x08H\x03R\x16\x65xcludeFromUtilization\x88\x01\x01\x12\'\n\ris_full_depth\x18\x08 \x01(\x08H\x04R\x0bisFullDepth\x88\x01\x01\x12@\n\x0esubdevice_role\x18\t \x01(\tB\x14\xfa\x42\x11r\x0fR\x05\x63hildR\x06parentH\x05R\rsubdeviceRole\x88\x01\x01\x12\xad\x01\n\x07\x61irflow\x18\n \x01(\tB\x8d\x01\xfa\x42\x89\x01r\x86\x01R\rbottom-to-topR\rfront-to-rearR\rleft-to-rightR\x05mixedR\x07passiveR\rrear-to-frontR\x0crear-to-sideR\rright-to-leftR\x0cside-to-rearR\rtop-to-bottomH\x06R\x07\x61irflow\x88\x01\x01\x12\x1b\n\x06weight\x18\x0b \x01(\x01H\x07R\x06weight\x88\x01\x01\x12:\n\x0bweight_unit\x18\x0c \x01(\tB\x14\xfa\x42\x11r\x0fR\x01gR\x02kgR\x02lbR\x02ozH\x08R\nweightUnit\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\r \x01(\tH\tR\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0e \x01(\tH\nR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12K\n\rcustom_fields\x18\x10 \x03(\x0b\x32&.diode.v1.DeviceType.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x13\n\x11_default_platformB\x0e\n\x0c_part_numberB\x0b\n\t_u_heightB\x1b\n\x19_exclude_from_utilizationB\x10\n\x0e_is_full_depthB\x11\n\x0f_subdevice_roleB\n\n\x08_airflowB\t\n\x07_weightB\x0e\n\x0c_weight_unitB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xc2\x04\n\tFHRPGroup\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12S\n\x08protocol\x18\x02 \x01(\tB7\xfa\x42\x34r2R\x04\x63\x61rpR\tclusterxlR\x04glbpR\x04hsrpR\x05otherR\x05vrrp2R\x05vrrp3R\x08protocol\x12\x19\n\x08group_id\x18\x03 \x01(\x03R\x07groupId\x12\x37\n\tauth_type\x18\x04 \x01(\tB\x15\xfa\x42\x12r\x10R\x03md5R\tplaintextH\x01R\x08\x61uthType\x88\x01\x01\x12\x1e\n\x08\x61uth_key\x18\x05 \x01(\tH\x02R\x07\x61uthKey\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x03R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x04R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\t \x03(\x0b\x32%.diode.v1.FHRPGroup.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0c\n\n_auth_typeB\x0b\n\t_auth_keyB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xe5\x39\n\x13\x46HRPGroupAssignment\x12)\n\x05group\x18\x01 \x01(\x0b\x32\x13.diode.v1.FHRPGroupR\x05group\x12\x34\n\rinterface_asn\x18\x02 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x0cinterfaceAsn\x12\x44\n\x13interface_asn_range\x18\x03 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x11interfaceAsnRange\x12\x46\n\x13interface_aggregate\x18\x04 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x12interfaceAggregate\x12:\n\x0finterface_cable\x18\x05 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x0einterfaceCable\x12G\n\x14interface_cable_path\x18\x06 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x12interfaceCablePath\x12\\\n\x1binterface_cable_termination\x18\x07 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x19interfaceCableTermination\x12@\n\x11interface_circuit\x18\x08 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x10interfaceCircuit\x12P\n\x17interface_circuit_group\x18\t \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x15interfaceCircuitGroup\x12o\n\"interface_circuit_group_assignment\x18\n \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R\x1finterfaceCircuitGroupAssignment\x12\x62\n\x1dinterface_circuit_termination\x18\x0b \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x1binterfaceCircuitTermination\x12M\n\x16interface_circuit_type\x18\x0c \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x14interfaceCircuitType\x12@\n\x11interface_cluster\x18\r \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x10interfaceCluster\x12P\n\x17interface_cluster_group\x18\x0e \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x15interfaceClusterGroup\x12M\n\x16interface_cluster_type\x18\x0f \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x14interfaceClusterType\x12M\n\x16interface_console_port\x18\x10 \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x14interfaceConsolePort\x12`\n\x1dinterface_console_server_port\x18\x11 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1ainterfaceConsoleServerPort\x12@\n\x11interface_contact\x18\x12 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x10interfaceContact\x12_\n\x1cinterface_contact_assignment\x18\x13 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x1ainterfaceContactAssignment\x12P\n\x17interface_contact_group\x18\x14 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x15interfaceContactGroup\x12M\n\x16interface_contact_role\x18\x15 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x14interfaceContactRole\x12=\n\x10interface_device\x18\x16 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x0finterfaceDevice\x12G\n\x14interface_device_bay\x18\x17 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x12interfaceDeviceBay\x12J\n\x15interface_device_role\x18\x18 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x13interfaceDeviceRole\x12J\n\x15interface_device_type\x18\x19 \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x13interfaceDeviceType\x12G\n\x14interface_fhrp_group\x18\x1a \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x12interfaceFhrpGroup\x12\x66\n\x1finterface_fhrp_group_assignment\x18\x1b \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x1cinterfaceFhrpGroupAssignment\x12G\n\x14interface_front_port\x18\x1c \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x12interfaceFrontPort\x12G\n\x14interface_ike_policy\x18\x1d \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x12interfaceIkePolicy\x12M\n\x16interface_ike_proposal\x18\x1e \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x14interfaceIkeProposal\x12G\n\x14interface_ip_address\x18\x1f \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x12interfaceIpAddress\x12\x41\n\x12interface_ip_range\x18  \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x10interfaceIpRange\x12N\n\x17interface_ip_sec_policy\x18! \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x14interfaceIpSecPolicy\x12Q\n\x18interface_ip_sec_profile\x18\" \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x15interfaceIpSecProfile\x12T\n\x19interface_ip_sec_proposal\x18# \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x16interfaceIpSecProposal\x12\x46\n\x13interface_interface\x18$ \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x12interfaceInterface\x12S\n\x18interface_inventory_item\x18% \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x16interfaceInventoryItem\x12`\n\x1dinterface_inventory_item_role\x18& \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x1ainterfaceInventoryItemRole\x12:\n\x0finterface_l2vpn\x18\' \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x0einterfaceL2vpn\x12\\\n\x1binterface_l2vpn_termination\x18( \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x19interfaceL2vpnTermination\x12\x43\n\x12interface_location\x18) \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x11interfaceLocation\x12J\n\x15interface_mac_address\x18* \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x13interfaceMacAddress\x12O\n\x16interface_manufacturer\x18+ \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x15interfaceManufacturer\x12=\n\x10interface_module\x18, \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x0finterfaceModule\x12G\n\x14interface_module_bay\x18- \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x12interfaceModuleBay\x12J\n\x15interface_module_type\x18. \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x13interfaceModuleType\x12\x43\n\x12interface_platform\x18/ \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x11interfacePlatform\x12G\n\x14interface_power_feed\x18\x30 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x12interfacePowerFeed\x12M\n\x16interface_power_outlet\x18\x31 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x14interfacePowerOutlet\x12J\n\x15interface_power_panel\x18\x32 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x13interfacePowerPanel\x12G\n\x14interface_power_port\x18\x33 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x12interfacePowerPort\x12=\n\x10interface_prefix\x18\x34 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x0finterfacePrefix\x12\x43\n\x12interface_provider\x18\x35 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x11interfaceProvider\x12Y\n\x1ainterface_provider_account\x18\x36 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x18interfaceProviderAccount\x12Y\n\x1ainterface_provider_network\x18\x37 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x18interfaceProviderNetwork\x12\x34\n\rinterface_rir\x18\x38 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x0cinterfaceRir\x12\x37\n\x0einterface_rack\x18\x39 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\rinterfaceRack\x12Y\n\x1ainterface_rack_reservation\x18: \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x18interfaceRackReservation\x12\x44\n\x13interface_rack_role\x18; \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x11interfaceRackRole\x12\x44\n\x13interface_rack_type\x18< \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x11interfaceRackType\x12\x44\n\x13interface_rear_port\x18= \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x11interfaceRearPort\x12=\n\x10interface_region\x18> \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0finterfaceRegion\x12\x37\n\x0einterface_role\x18? \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\rinterfaceRole\x12M\n\x16interface_route_target\x18@ \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x14interfaceRouteTarget\x12@\n\x11interface_service\x18\x41 \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x10interfaceService\x12\x37\n\x0einterface_site\x18\x42 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\rinterfaceSite\x12G\n\x14interface_site_group\x18\x43 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x12interfaceSiteGroup\x12\x34\n\rinterface_tag\x18\x44 \x01(\x0b\x32\r.diode.v1.TagH\x00R\x0cinterfaceTag\x12=\n\x10interface_tenant\x18\x45 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x0finterfaceTenant\x12M\n\x16interface_tenant_group\x18\x46 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x14interfaceTenantGroup\x12=\n\x10interface_tunnel\x18G \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x0finterfaceTunnel\x12M\n\x16interface_tunnel_group\x18H \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x14interfaceTunnelGroup\x12_\n\x1cinterface_tunnel_termination\x18I \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x1ainterfaceTunnelTermination\x12\x37\n\x0einterface_vlan\x18J \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\rinterfaceVlan\x12G\n\x14interface_vlan_group\x18K \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x12interfaceVlanGroup\x12l\n!interface_vlan_translation_policy\x18L \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R\x1einterfaceVlanTranslationPolicy\x12\x66\n\x1finterface_vlan_translation_rule\x18M \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x1cinterfaceVlanTranslationRule\x12M\n\x16interface_vm_interface\x18N \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x14interfaceVmInterface\x12\x34\n\rinterface_vrf\x18O \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x0cinterfaceVrf\x12V\n\x19interface_virtual_chassis\x18P \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x17interfaceVirtualChassis\x12V\n\x19interface_virtual_circuit\x18Q \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x17interfaceVirtualCircuit\x12x\n%interface_virtual_circuit_termination\x18R \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\"interfaceVirtualCircuitTermination\x12\x63\n\x1einterface_virtual_circuit_type\x18S \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x1binterfaceVirtualCircuitType\x12i\n interface_virtual_device_context\x18T \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x1dinterfaceVirtualDeviceContext\x12M\n\x16interface_virtual_disk\x18U \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x14interfaceVirtualDisk\x12V\n\x19interface_virtual_machine\x18V \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x17interfaceVirtualMachine\x12M\n\x16interface_wireless_lan\x18W \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x14interfaceWirelessLan\x12]\n\x1cinterface_wireless_lan_group\x18X \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x19interfaceWirelessLanGroup\x12P\n\x17interface_wireless_link\x18Y \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x15interfaceWirelessLink\x12M\n\x16interface_custom_field\x18[ \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x14interfaceCustomField\x12j\n!interface_custom_field_choice_set\x18\\ \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x1dinterfaceCustomFieldChoiceSet\x12P\n\x17interface_journal_entry\x18] \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x15interfaceJournalEntry\x12`\n\x1dinterface_module_type_profile\x18^ \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x1ainterfaceModuleTypeProfile\x12J\n\x15interface_custom_link\x18_ \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x13interfaceCustomLink\x12\x1a\n\x08priority\x18Z \x01(\x03R\x08priorityB\x0b\n\tinterface\"\xd1\x08\n\tFrontPort\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xc4\x03\n\x04type\x18\x05 \x01(\tB\xaf\x03\xfa\x42\xab\x03r\xa8\x03R\t110-punchR\x04\x34p2cR\x04\x34p4cR\x04\x36p2cR\x04\x36p4cR\x04\x36p6cR\x04\x38p2cR\x04\x38p4cR\x04\x38p6cR\x04\x38p8cR\x03\x62ncR\x02\x63sR\x01\x66R\x02\x66\x63R\x06\x66\x63-apcR\x05\x66\x63-pcR\x06\x66\x63-upcR\x04gg45R\x02lcR\x06lc-apcR\x05lc-pcR\x06lc-upcR\x03lshR\x07lsh-apcR\x06lsh-pcR\x07lsh-upcR\x03lx5R\x07lx5-apcR\x06lx5-pcR\x07lx5-upcR\x03mpoR\x05mrj21R\x04mtrjR\x01nR\x05otherR\x02scR\x06sc-apcR\x05sc-pcR\x06sc-upcR\x07sma-905R\x07sma-906R\x02snR\x06spliceR\x02stR\x07tera-1pR\x07tera-2pR\x07tera-4pR\x06urm-p2R\x06urm-p4R\x06urm-p8R\x05usb-aR\x05usb-bR\x05usb-cR\x0busb-micro-aR\x0cusb-micro-abR\x0busb-micro-bR\nusb-mini-aR\nusb-mini-bR\x04type\x12\x19\n\x05\x63olor\x18\x06 \x01(\tH\x02R\x05\x63olor\x88\x01\x01\x12/\n\trear_port\x18\x07 \x01(\x0b\x32\x12.diode.v1.RearPortR\x08rearPort\x12\x31\n\x12rear_port_position\x18\x08 \x01(\x03H\x03R\x10rearPortPosition\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\n \x01(\x08H\x05R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\x0b \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x0c \x03(\x0b\x32%.diode.v1.FrontPort.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x08\n\x06_colorB\x15\n\x13_rear_port_positionB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\xe7\x34\n\rGenericObject\x12.\n\nobject_asn\x18\x01 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\tobjectAsn\x12>\n\x10object_asn_range\x18\x02 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x0eobjectAsnRange\x12@\n\x10object_aggregate\x18\x03 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x0fobjectAggregate\x12\x34\n\x0cobject_cable\x18\x04 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x0bobjectCable\x12\x41\n\x11object_cable_path\x18\x05 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x0fobjectCablePath\x12V\n\x18object_cable_termination\x18\x06 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x16objectCableTermination\x12:\n\x0eobject_circuit\x18\x07 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\robjectCircuit\x12J\n\x14object_circuit_group\x18\x08 \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x12objectCircuitGroup\x12i\n\x1fobject_circuit_group_assignment\x18\t \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R\x1cobjectCircuitGroupAssignment\x12\\\n\x1aobject_circuit_termination\x18\n \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x18objectCircuitTermination\x12G\n\x13object_circuit_type\x18\x0b \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x11objectCircuitType\x12:\n\x0eobject_cluster\x18\x0c \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\robjectCluster\x12J\n\x14object_cluster_group\x18\r \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x12objectClusterGroup\x12G\n\x13object_cluster_type\x18\x0e \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x11objectClusterType\x12G\n\x13object_console_port\x18\x0f \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x11objectConsolePort\x12Z\n\x1aobject_console_server_port\x18\x10 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x17objectConsoleServerPort\x12:\n\x0eobject_contact\x18\x11 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\robjectContact\x12Y\n\x19object_contact_assignment\x18\x12 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x17objectContactAssignment\x12J\n\x14object_contact_group\x18\x13 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x12objectContactGroup\x12G\n\x13object_contact_role\x18\x14 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x11objectContactRole\x12\x37\n\robject_device\x18\x15 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x0cobjectDevice\x12\x41\n\x11object_device_bay\x18\x16 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x0fobjectDeviceBay\x12\x44\n\x12object_device_role\x18\x17 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x10objectDeviceRole\x12\x44\n\x12object_device_type\x18\x18 \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x10objectDeviceType\x12\x41\n\x11object_fhrp_group\x18\x19 \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x0fobjectFhrpGroup\x12`\n\x1cobject_fhrp_group_assignment\x18\x1a \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x19objectFhrpGroupAssignment\x12\x41\n\x11object_front_port\x18\x1b \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x0fobjectFrontPort\x12\x41\n\x11object_ike_policy\x18\x1c \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x0fobjectIkePolicy\x12G\n\x13object_ike_proposal\x18\x1d \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x11objectIkeProposal\x12\x41\n\x11object_ip_address\x18\x1e \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x0fobjectIpAddress\x12;\n\x0fobject_ip_range\x18\x1f \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\robjectIpRange\x12H\n\x14object_ip_sec_policy\x18  \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x11objectIpSecPolicy\x12K\n\x15object_ip_sec_profile\x18! \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x12objectIpSecProfile\x12N\n\x16object_ip_sec_proposal\x18\" \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x13objectIpSecProposal\x12@\n\x10object_interface\x18# \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x0fobjectInterface\x12M\n\x15object_inventory_item\x18$ \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x13objectInventoryItem\x12Z\n\x1aobject_inventory_item_role\x18% \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x17objectInventoryItemRole\x12\x34\n\x0cobject_l2vpn\x18& \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x0bobjectL2vpn\x12V\n\x18object_l2vpn_termination\x18\' \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x16objectL2vpnTermination\x12=\n\x0fobject_location\x18( \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x0eobjectLocation\x12\x44\n\x12object_mac_address\x18) \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x10objectMacAddress\x12I\n\x13object_manufacturer\x18* \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x12objectManufacturer\x12\x37\n\robject_module\x18+ \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x0cobjectModule\x12\x41\n\x11object_module_bay\x18, \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x0fobjectModuleBay\x12\x44\n\x12object_module_type\x18- \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x10objectModuleType\x12=\n\x0fobject_platform\x18. \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x0eobjectPlatform\x12\x41\n\x11object_power_feed\x18/ \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x0fobjectPowerFeed\x12G\n\x13object_power_outlet\x18\x30 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x11objectPowerOutlet\x12\x44\n\x12object_power_panel\x18\x31 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x10objectPowerPanel\x12\x41\n\x11object_power_port\x18\x32 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x0fobjectPowerPort\x12\x37\n\robject_prefix\x18\x33 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x0cobjectPrefix\x12=\n\x0fobject_provider\x18\x34 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x0eobjectProvider\x12S\n\x17object_provider_account\x18\x35 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x15objectProviderAccount\x12S\n\x17object_provider_network\x18\x36 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x15objectProviderNetwork\x12.\n\nobject_rir\x18\x37 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\tobjectRir\x12\x31\n\x0bobject_rack\x18\x38 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\nobjectRack\x12S\n\x17object_rack_reservation\x18\x39 \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x15objectRackReservation\x12>\n\x10object_rack_role\x18: \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x0eobjectRackRole\x12>\n\x10object_rack_type\x18; \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x0eobjectRackType\x12>\n\x10object_rear_port\x18< \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x0eobjectRearPort\x12\x37\n\robject_region\x18= \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0cobjectRegion\x12\x31\n\x0bobject_role\x18> \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\nobjectRole\x12G\n\x13object_route_target\x18? \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x11objectRouteTarget\x12:\n\x0eobject_service\x18@ \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\robjectService\x12\x31\n\x0bobject_site\x18\x41 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\nobjectSite\x12\x41\n\x11object_site_group\x18\x42 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0fobjectSiteGroup\x12.\n\nobject_tag\x18\x43 \x01(\x0b\x32\r.diode.v1.TagH\x00R\tobjectTag\x12\x37\n\robject_tenant\x18\x44 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x0cobjectTenant\x12G\n\x13object_tenant_group\x18\x45 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x11objectTenantGroup\x12\x37\n\robject_tunnel\x18\x46 \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x0cobjectTunnel\x12G\n\x13object_tunnel_group\x18G \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x11objectTunnelGroup\x12Y\n\x19object_tunnel_termination\x18H \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x17objectTunnelTermination\x12\x31\n\x0bobject_vlan\x18I \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\nobjectVlan\x12\x41\n\x11object_vlan_group\x18J \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x0fobjectVlanGroup\x12\x66\n\x1eobject_vlan_translation_policy\x18K \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R\x1bobjectVlanTranslationPolicy\x12`\n\x1cobject_vlan_translation_rule\x18L \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x19objectVlanTranslationRule\x12G\n\x13object_vm_interface\x18M \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x11objectVmInterface\x12.\n\nobject_vrf\x18N \x01(\x0b\x32\r.diode.v1.VRFH\x00R\tobjectVrf\x12P\n\x16object_virtual_chassis\x18O \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x14objectVirtualChassis\x12P\n\x16object_virtual_circuit\x18P \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x14objectVirtualCircuit\x12r\n\"object_virtual_circuit_termination\x18Q \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\x1fobjectVirtualCircuitTermination\x12]\n\x1bobject_virtual_circuit_type\x18R \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x18objectVirtualCircuitType\x12\x63\n\x1dobject_virtual_device_context\x18S \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x1aobjectVirtualDeviceContext\x12G\n\x13object_virtual_disk\x18T \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x11objectVirtualDisk\x12P\n\x16object_virtual_machine\x18U \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x14objectVirtualMachine\x12G\n\x13object_wireless_lan\x18V \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x11objectWirelessLan\x12W\n\x19object_wireless_lan_group\x18W \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x16objectWirelessLanGroup\x12J\n\x14object_wireless_link\x18X \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x12objectWirelessLink\x12G\n\x13object_custom_field\x18Y \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x11objectCustomField\x12\x64\n\x1eobject_custom_field_choice_set\x18Z \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x1aobjectCustomFieldChoiceSet\x12J\n\x14object_journal_entry\x18[ \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x12objectJournalEntry\x12Z\n\x1aobject_module_type_profile\x18\\ \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x17objectModuleTypeProfile\x12\x44\n\x12object_custom_link\x18] \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x10objectCustomLinkB\x08\n\x06object\"\xa1\x04\n\tIKEPolicy\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12#\n\x07version\x18\x03 \x01(\x03\x42\t\xfa\x42\x06\"\x04\x30\x01\x30\x02R\x07version\x12\x30\n\x04mode\x18\x04 \x01(\tB\x17\xfa\x42\x14r\x12R\naggressiveR\x04mainH\x01R\x04mode\x88\x01\x01\x12(\n\rpreshared_key\x18\x05 \x01(\tH\x02R\x0cpresharedKey\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x06 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x08 \x03(\x0b\x32%.diode.v1.IKEPolicy.CustomFieldsEntryR\x0c\x63ustomFields\x12\x33\n\tproposals\x18\t \x03(\x0b\x32\x15.diode.v1.IKEProposalR\tproposals\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x07\n\x05_modeB\x10\n\x0e_preshared_keyB\x0b\n\t_comments\"\x8e\x07\n\x0bIKEProposal\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12x\n\x15\x61uthentication_method\x18\x03 \x01(\tBC\xfa\x42@r>R\x0c\x63\x65rtificatesR\x0e\x64sa-signaturesR\x0epreshared-keysR\x0ersa-signaturesR\x14\x61uthenticationMethod\x12\x99\x01\n\x14\x65ncryption_algorithm\x18\x04 \x01(\tBf\xfa\x42\x63raR\x08\x33\x64\x65s-cbcR\x0b\x61\x65s-128-cbcR\x0b\x61\x65s-128-gcmR\x0b\x61\x65s-192-cbcR\x0b\x61\x65s-192-gcmR\x0b\x61\x65s-256-cbcR\x0b\x61\x65s-256-gcmR\x07\x64\x65s-cbcR\x13\x65ncryptionAlgorithm\x12\x81\x01\n\x18\x61uthentication_algorithm\x18\x05 \x01(\tBA\xfa\x42>r<R\x08hmac-md5R\thmac-sha1R\x0bhmac-sha256R\x0bhmac-sha384R\x0bhmac-sha512H\x01R\x17\x61uthenticationAlgorithm\x88\x01\x01\x12K\n\x05group\x18\x06 \x01(\x03\x42\x35\xfa\x42\x32\"00\x01\x30\x02\x30\x05\x30\x0e\x30\x0f\x30\x10\x30\x11\x30\x12\x30\x13\x30\x14\x30\x15\x30\x16\x30\x17\x30\x18\x30\x19\x30\x1a\x30\x1b\x30\x1c\x30\x1d\x30\x1e\x30\x1f\x30 0!0\"R\x05group\x12$\n\x0bsa_lifetime\x18\x07 \x01(\x03H\x02R\nsaLifetime\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x08 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\n \x03(\x0b\x32\'.diode.v1.IKEProposal.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x1b\n\x19_authentication_algorithmB\x0e\n\x0c_sa_lifetimeB\x0b\n\t_comments\"\x85\x08\n\tIPAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12$\n\x03vrf\x18\x02 \x01(\x0b\x32\r.diode.v1.VRFH\x01R\x03vrf\x88\x01\x01\x12-\n\x06tenant\x18\x03 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12M\n\x06status\x18\x04 \x01(\tB0\xfa\x42-r+R\x06\x61\x63tiveR\ndeprecatedR\x04\x64hcpR\x08reservedR\x05slaacH\x03R\x06status\x88\x01\x01\x12Y\n\x04role\x18\x05 \x01(\tB@\xfa\x42=r;R\x07\x61nycastR\x04\x63\x61rpR\x04glbpR\x04hsrpR\x08loopbackR\tsecondaryR\x03vipR\x04vrrpH\x04R\x04role\x88\x01\x01\x12R\n\x1a\x61ssigned_object_fhrp_group\x18\x06 \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x17\x61ssignedObjectFhrpGroup\x12Q\n\x19\x61ssigned_object_interface\x18\x07 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x17\x61ssignedObjectInterface\x12X\n\x1c\x61ssigned_object_vm_interface\x18\x08 \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x19\x61ssignedObjectVmInterface\x12\x37\n\nnat_inside\x18\t \x01(\x0b\x32\x13.diode.v1.IPAddressH\x05R\tnatInside\x88\x01\x01\x12\x1e\n\x08\x64ns_name\x18\n \x01(\tH\x06R\x07\x64nsName\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x07R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0c \x01(\tH\x08R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\r \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x0e \x03(\x0b\x32%.diode.v1.IPAddress.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x11\n\x0f\x61ssigned_objectB\x06\n\x04_vrfB\t\n\x07_tenantB\t\n\x07_statusB\x07\n\x05_roleB\r\n\x0b_nat_insideB\x0b\n\t_dns_nameB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xe0\x05\n\x07IPRange\x12#\n\rstart_address\x18\x01 \x01(\tR\x0cstartAddress\x12\x1f\n\x0b\x65nd_address\x18\x02 \x01(\tR\nendAddress\x12$\n\x03vrf\x18\x03 \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x03vrf\x88\x01\x01\x12-\n\x06tenant\x18\x04 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12@\n\x06status\x18\x05 \x01(\tB#\xfa\x42 r\x1eR\x06\x61\x63tiveR\ndeprecatedR\x08reservedH\x02R\x06status\x88\x01\x01\x12\'\n\x04role\x18\x06 \x01(\x0b\x32\x0e.diode.v1.RoleH\x03R\x04role\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x08 \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12(\n\rmark_utilized\x18\n \x01(\x08H\x06R\x0cmarkUtilized\x88\x01\x01\x12H\n\rcustom_fields\x18\x0b \x03(\x0b\x32#.diode.v1.IPRange.CustomFieldsEntryR\x0c\x63ustomFields\x12*\n\x0emark_populated\x18\x0c \x01(\x08H\x07R\rmarkPopulated\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x06\n\x04_vrfB\t\n\x07_tenantB\t\n\x07_statusB\x07\n\x05_roleB\x0e\n\x0c_descriptionB\x0b\n\t_commentsB\x10\n\x0e_mark_utilizedB\x11\n\x0f_mark_populated\"\xf2\x03\n\x0bIPSecPolicy\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12W\n\tpfs_group\x18\x03 \x01(\x03\x42\x35\xfa\x42\x32\"00\x01\x30\x02\x30\x05\x30\x0e\x30\x0f\x30\x10\x30\x11\x30\x12\x30\x13\x30\x14\x30\x15\x30\x16\x30\x17\x30\x18\x30\x19\x30\x1a\x30\x1b\x30\x1c\x30\x1d\x30\x1e\x30\x1f\x30 0!0\"H\x01R\x08pfsGroup\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x04 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x06 \x03(\x0b\x32\'.diode.v1.IPSecPolicy.CustomFieldsEntryR\x0c\x63ustomFields\x12\x35\n\tproposals\x18\x07 \x03(\x0b\x32\x17.diode.v1.IPSecProposalR\tproposals\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x0c\n\n_pfs_groupB\x0b\n\t_comments\"\xe8\x03\n\x0cIPSecProfile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\"\n\x04mode\x18\x03 \x01(\tB\x0e\xfa\x42\x0br\tR\x02\x61hR\x03\x65spR\x04mode\x12\x32\n\nike_policy\x18\x04 \x01(\x0b\x32\x13.diode.v1.IKEPolicyR\tikePolicy\x12\x38\n\x0cipsec_policy\x18\x05 \x01(\x0b\x32\x15.diode.v1.IPSecPolicyR\x0bipsecPolicy\x12\x1f\n\x08\x63omments\x18\x06 \x01(\tH\x01R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x08 \x03(\x0b\x32(.diode.v1.IPSecProfile.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xc4\x06\n\rIPSecProposal\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x9e\x01\n\x14\x65ncryption_algorithm\x18\x03 \x01(\tBf\xfa\x42\x63raR\x08\x33\x64\x65s-cbcR\x0b\x61\x65s-128-cbcR\x0b\x61\x65s-128-gcmR\x0b\x61\x65s-192-cbcR\x0b\x61\x65s-192-gcmR\x0b\x61\x65s-256-cbcR\x0b\x61\x65s-256-gcmR\x07\x64\x65s-cbcH\x01R\x13\x65ncryptionAlgorithm\x88\x01\x01\x12\x81\x01\n\x18\x61uthentication_algorithm\x18\x04 \x01(\tBA\xfa\x42>r<R\x08hmac-md5R\thmac-sha1R\x0bhmac-sha256R\x0bhmac-sha384R\x0bhmac-sha512H\x02R\x17\x61uthenticationAlgorithm\x88\x01\x01\x12\x33\n\x13sa_lifetime_seconds\x18\x05 \x01(\x03H\x03R\x11saLifetimeSeconds\x88\x01\x01\x12-\n\x10sa_lifetime_data\x18\x06 \x01(\x03H\x04R\x0esaLifetimeData\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12N\n\rcustom_fields\x18\t \x03(\x0b\x32).diode.v1.IPSecProposal.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x17\n\x15_encryption_algorithmB\x1b\n\x19_authentication_algorithmB\x16\n\x14_sa_lifetime_secondsB\x13\n\x11_sa_lifetime_dataB\x0b\n\t_comments\"\xe6\x37\n\tInterface\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xaf\x0e\n\x04type\x18\x05 \x01(\tB\x9a\x0e\xfa\x42\x96\x0er\x93\x0eR\x0b\x31\x30\x30\x30\x62\x61se-kxR\x0b\x31\x30\x30\x30\x62\x61se-lxR\x0b\x31\x30\x30\x30\x62\x61se-sxR\n1000base-tR\x0b\x31\x30\x30\x30\x62\x61se-txR\x0f\x31\x30\x30\x30\x62\x61se-x-gbicR\x0e\x31\x30\x30\x30\x62\x61se-x-sfpR\n100base-fxR\x0b\x31\x30\x30\x62\x61se-lfxR\n100base-t1R\n100base-txR\r100base-x-sfpR\x0c\x31\x30\x30gbase-kp4R\x0c\x31\x30\x30gbase-kr2R\x0c\x31\x30\x30gbase-kr4R\x0e\x31\x30\x30gbase-x-cfpR\x0f\x31\x30\x30gbase-x-cfp2R\x0f\x31\x30\x30gbase-x-cfp4R\x0f\x31\x30\x30gbase-x-cpakR\x0e\x31\x30\x30gbase-x-cxpR\x0f\x31\x30\x30gbase-x-dsfpR\x11\x31\x30\x30gbase-x-qsfp28R\x11\x31\x30\x30gbase-x-qsfpddR\x10\x31\x30\x30gbase-x-sfpddR\x08\x31\x30g-eponR\x0b\x31\x30gbase-cx4R\n10gbase-krR\x0b\x31\x30gbase-kx4R\t10gbase-tR\x0e\x31\x30gbase-x-sfppR\x0c\x31\x30gbase-x-x2R\x10\x31\x30gbase-x-xenpakR\r10gbase-x-xfpR\r128gfc-qsfp28R\n16gfc-sfppR\x08\x31gfc-sfpR\x0b\x32.5gbase-kxR\n2.5gbase-tR\x0f\x32\x30\x30gbase-x-cfp2R\x11\x32\x30\x30gbase-x-qsfp56R\x11\x32\x30\x30gbase-x-qsfpddR\x07\x32\x35g-ponR\n25gbase-krR\x0f\x32\x35gbase-x-sfp28R\x08\x32gfc-sfpR\x0b\x33\x32gfc-sfp28R\n32gfc-sfppR\x0f\x34\x30\x30gbase-x-cdfpR\x0f\x34\x30\x30gbase-x-cfp2R\x0f\x34\x30\x30gbase-x-cfp8R\x0f\x34\x30\x30gbase-x-osfpR\x13\x34\x30\x30gbase-x-osfp-rhsR\x12\x34\x30\x30gbase-x-qsfp112R\x11\x34\x30\x30gbase-x-qsfpddR\x0b\x34\x30gbase-kr4R\x0f\x34\x30gbase-x-qsfppR\x02\x34gR\x08\x34gfc-sfpR\x07\x35\x30g-ponR\n50gbase-krR\x0f\x35\x30gbase-x-sfp28R\x0f\x35\x30gbase-x-sfp56R\x02\x35gR\t5gbase-krR\x08\x35gbase-tR\x0b\x36\x34gfc-qsfppR\x0b\x36\x34gfc-sfpddR\n64gfc-sfppR\x0f\x38\x30\x30gbase-x-osfpR\x11\x38\x30\x30gbase-x-qsfpddR\t8gfc-sfppR\x04\x62ponR\x06\x62ridgeR\x04\x63\x64maR\x0f\x63isco-flexstackR\x14\x63isco-flexstack-plusR\x0f\x63isco-stackwiseR\x13\x63isco-stackwise-160R\x12\x63isco-stackwise-1tR\x13\x63isco-stackwise-320R\x13\x63isco-stackwise-480R\x12\x63isco-stackwise-80R\x14\x63isco-stackwise-plusR\x06\x64ocsisR\x02\x65\x31R\x02\x65\x33R\x04\x65ponR\x13\x65xtreme-summitstackR\x17\x65xtreme-summitstack-128R\x17\x65xtreme-summitstack-256R\x17\x65xtreme-summitstack-512R\x04gponR\x03gsmR\x0bieee802.11aR\x0cieee802.11acR\x0cieee802.11adR\x0cieee802.11axR\x0cieee802.11ayR\x0cieee802.11beR\x0bieee802.11gR\x0bieee802.11nR\x0cieee802.15.1R\x0cieee802.15.4R\x0einfiniband-ddrR\x0einfiniband-edrR\x0einfiniband-fdrR\x10infiniband-fdr10R\x0einfiniband-hdrR\x0einfiniband-ndrR\x0einfiniband-qdrR\x0einfiniband-sdrR\x0einfiniband-xdrR\x0bjuniper-vcpR\x03lagR\x03lteR\x04mocaR\x07ng-pon2R\x05otherR\x0eother-wirelessR\nsonet-oc12R\x0bsonet-oc192R\x0csonet-oc1920R\tsonet-oc3R\x0csonet-oc3840R\nsonet-oc48R\x0bsonet-oc768R\x02t1R\x02t3R\x07virtualR\x04xdslR\x06xg-ponR\x07xgs-ponR\x04type\x12\x1d\n\x07\x65nabled\x18\x06 \x01(\x08H\x02R\x07\x65nabled\x88\x01\x01\x12\x30\n\x06parent\x18\x07 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x03R\x06parent\x88\x01\x01\x12\x30\n\x06\x62ridge\x18\x08 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x04R\x06\x62ridge\x88\x01\x01\x12*\n\x03lag\x18\t \x01(\x0b\x32\x13.diode.v1.InterfaceH\x05R\x03lag\x88\x01\x01\x12\x15\n\x03mtu\x18\n \x01(\x03H\x06R\x03mtu\x88\x01\x01\x12I\n\x13primary_mac_address\x18\x0b \x01(\x0b\x32\x14.diode.v1.MACAddressH\x07R\x11primaryMacAddress\x88\x01\x01\x12\x19\n\x05speed\x18\x0c \x01(\x03H\x08R\x05speed\x88\x01\x01\x12\x34\n\x06\x64uplex\x18\r \x01(\tB\x17\xfa\x42\x14r\x12R\x04\x61utoR\x04\x66ullR\x04halfH\tR\x06\x64uplex\x88\x01\x01\x12\x15\n\x03wwn\x18\x0e \x01(\tH\nR\x03wwn\x88\x01\x01\x12 \n\tmgmt_only\x18\x0f \x01(\x08H\x0bR\x08mgmtOnly\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x10 \x01(\tH\x0cR\x0b\x64\x65scription\x88\x01\x01\x12\x42\n\x04mode\x18\x11 \x01(\tB)\xfa\x42&r$R\x06\x61\x63\x63\x65ssR\x06q-in-qR\x06taggedR\ntagged-allH\rR\x04mode\x88\x01\x01\x12\x30\n\x07rf_role\x18\x12 \x01(\tB\x12\xfa\x42\x0fr\rR\x02\x61pR\x07stationH\x0eR\x06rfRole\x88\x01\x01\x12\xf5\x18\n\nrf_channel\x18\x13 \x01(\tB\xd0\x18\xfa\x42\xcc\x18r\xc9\x18R\x0e\x32.4g-1-2412-22R\x0f\x32.4g-10-2457-22R\x0f\x32.4g-11-2462-22R\x0f\x32.4g-12-2467-22R\x0f\x32.4g-13-2472-22R\x0e\x32.4g-2-2417-22R\x0e\x32.4g-3-2422-22R\x0e\x32.4g-4-2427-22R\x0e\x32.4g-5-2432-22R\x0e\x32.4g-6-2437-22R\x0e\x32.4g-7-2442-22R\x0e\x32.4g-8-2447-22R\x0e\x32.4g-9-2452-22R\x0e\x35g-100-5500-20R\x0e\x35g-102-5510-40R\x0e\x35g-104-5520-20R\x0e\x35g-106-5530-80R\x0e\x35g-108-5540-20R\x0e\x35g-110-5550-40R\x0e\x35g-112-5560-20R\x0f\x35g-114-5570-160R\x0e\x35g-116-5580-20R\x0e\x35g-118-5590-40R\x0e\x35g-120-5600-20R\x0e\x35g-122-5610-80R\x0e\x35g-124-5620-20R\x0e\x35g-126-5630-40R\x0e\x35g-128-5640-20R\x0e\x35g-132-5660-20R\x0e\x35g-134-5670-40R\x0e\x35g-136-5680-20R\x0e\x35g-138-5690-80R\x0e\x35g-140-5700-20R\x0e\x35g-142-5710-40R\x0e\x35g-144-5720-20R\x0e\x35g-149-5745-20R\x0e\x35g-151-5755-40R\x0e\x35g-153-5765-20R\x0e\x35g-155-5775-80R\x0e\x35g-157-5785-20R\x0e\x35g-159-5795-40R\x0e\x35g-161-5805-20R\x0f\x35g-163-5815-160R\x0e\x35g-165-5825-20R\x0e\x35g-167-5835-40R\x0e\x35g-169-5845-20R\x0e\x35g-171-5855-80R\x0e\x35g-173-5865-20R\x0e\x35g-175-5875-40R\x0e\x35g-177-5885-20R\r5g-32-5160-20R\r5g-34-5170-40R\r5g-36-5180-20R\r5g-38-5190-40R\r5g-40-5200-20R\r5g-42-5210-80R\r5g-44-5220-20R\r5g-46-5230-40R\r5g-48-5240-20R\x0e\x35g-50-5250-160R\r5g-52-5260-20R\r5g-54-5270-40R\r5g-56-5280-20R\r5g-58-5290-80R\r5g-60-5300-20R\r5g-62-5310-40R\r5g-64-5320-20R\x10\x36\x30g-1-58320-2160R\x11\x36\x30g-10-61560-4320R\x11\x36\x30g-11-63720-4320R\x11\x36\x30g-12-65880-4320R\x11\x36\x30g-13-68040-4320R\x11\x36\x30g-17-60480-6480R\x11\x36\x30g-18-62640-6480R\x11\x36\x30g-19-64800-6480R\x10\x36\x30g-2-60480-2160R\x11\x36\x30g-20-66960-6480R\x11\x36\x30g-25-61560-6480R\x11\x36\x30g-26-63720-6480R\x11\x36\x30g-27-65880-6480R\x10\x36\x30g-3-62640-2160R\x10\x36\x30g-4-64800-2160R\x10\x36\x30g-5-66960-2160R\x10\x36\x30g-6-69120-2160R\x10\x36\x30g-9-59400-4320R\x0c\x36g-1-5955-20R\x0e\x36g-101-6455-20R\x0e\x36g-103-6465-80R\x0e\x36g-105-6475-20R\x0e\x36g-107-6485-40R\x0e\x36g-109-6495-20R\r6g-11-6005-40R\x0f\x36g-111-6505-160R\x0e\x36g-113-6515-20R\x0e\x36g-115-6525-40R\x0e\x36g-117-6535-20R\x0e\x36g-119-6545-80R\x0e\x36g-121-6555-20R\x0e\x36g-123-6565-40R\x0e\x36g-125-6575-20R\x0e\x36g-129-6595-20R\r6g-13-6015-20R\x0e\x36g-131-6605-40R\x0e\x36g-133-6615-20R\x0e\x36g-135-6625-80R\x0e\x36g-137-6635-20R\x0e\x36g-139-6645-40R\x0e\x36g-141-6655-20R\x0f\x36g-143-6665-160R\x0e\x36g-145-6675-20R\x0e\x36g-147-6685-40R\x0e\x36g-149-6695-20R\x0e\x36g-15-6025-160R\x0e\x36g-151-6705-80R\x0e\x36g-153-6715-20R\x0e\x36g-155-6725-40R\x0e\x36g-157-6735-20R\x0f\x36g-159-6745-320R\x0e\x36g-161-6755-20R\x0e\x36g-163-6765-40R\x0e\x36g-165-6775-20R\x0e\x36g-167-6785-80R\x0e\x36g-169-6795-20R\r6g-17-6035-20R\x0e\x36g-171-6805-40R\x0e\x36g-173-6815-20R\x0f\x36g-175-6825-160R\x0e\x36g-177-6835-20R\x0e\x36g-179-6845-40R\x0e\x36g-181-6855-20R\x0e\x36g-183-6865-80R\x0e\x36g-185-6875-20R\x0e\x36g-187-6885-40R\x0e\x36g-189-6895-20R\r6g-19-6045-40R\x0e\x36g-193-6915-20R\x0e\x36g-195-6925-40R\x0e\x36g-197-6935-20R\x0e\x36g-199-6945-80R\x0e\x36g-201-6955-20R\x0e\x36g-203-6965-40R\x0e\x36g-205-6975-20R\x0f\x36g-207-6985-160R\x0e\x36g-209-6995-20R\r6g-21-6055-20R\x0e\x36g-211-7005-40R\x0e\x36g-213-7015-20R\x0e\x36g-215-7025-80R\x0e\x36g-217-7035-20R\x0e\x36g-219-7045-40R\x0e\x36g-221-7055-20R\x0e\x36g-225-7075-20R\x0e\x36g-227-7085-40R\x0e\x36g-229-7095-20R\r6g-23-6065-80R\x0e\x36g-233-7115-20R\r6g-25-6075-20R\r6g-27-6085-40R\r6g-29-6095-20R\x0c\x36g-3-5965-40R\x0e\x36g-31-6105-320R\r6g-33-6115-20R\r6g-35-6125-40R\r6g-37-6135-20R\r6g-39-6145-80R\r6g-41-6155-20R\r6g-43-6165-40R\r6g-45-6175-20R\x0e\x36g-47-6185-160R\r6g-49-6195-20R\x0c\x36g-5-5975-20R\r6g-51-6205-40R\r6g-53-6215-20R\r6g-55-6225-80R\r6g-57-6235-20R\r6g-59-6245-40R\r6g-61-6255-20R\r6g-65-6275-20R\r6g-67-6285-40R\r6g-69-6295-20R\x0c\x36g-7-5985-80R\r6g-71-6305-80R\r6g-73-6315-20R\r6g-75-6325-40R\r6g-77-6335-20R\x0e\x36g-79-6345-160R\r6g-81-6355-20R\r6g-83-6365-40R\r6g-85-6375-20R\r6g-87-6385-80R\r6g-89-6395-20R\x0c\x36g-9-5995-20R\r6g-91-6405-40R\r6g-93-6415-20R\x0e\x36g-95-6425-320R\r6g-97-6435-20R\r6g-99-6445-40H\x0fR\trfChannel\x88\x01\x01\x12.\n\x08poe_mode\x18\x14 \x01(\tB\x0e\xfa\x42\x0br\tR\x02pdR\x03pseH\x10R\x07poeMode\x88\x01\x01\x12\xc0\x01\n\x08poe_type\x18\x15 \x01(\tB\x9f\x01\xfa\x42\x9b\x01r\x98\x01R\x11passive-24v-2pairR\x11passive-24v-4pairR\x11passive-48v-2pairR\x11passive-48v-4pairR\x11type1-ieee802.3afR\x11type2-ieee802.3atR\x11type3-ieee802.3btR\x11type4-ieee802.3btH\x11R\x07poeType\x88\x01\x01\x12\x35\n\x14rf_channel_frequency\x18\x16 \x01(\x01H\x12R\x12rfChannelFrequency\x88\x01\x01\x12-\n\x10rf_channel_width\x18\x17 \x01(\x01H\x13R\x0erfChannelWidth\x88\x01\x01\x12\x1e\n\x08tx_power\x18\x18 \x01(\x03H\x14R\x07txPower\x88\x01\x01\x12\x38\n\runtagged_vlan\x18\x19 \x01(\x0b\x32\x0e.diode.v1.VLANH\x15R\x0cuntaggedVlan\x88\x01\x01\x12\x32\n\nqinq_svlan\x18\x1a \x01(\x0b\x32\x0e.diode.v1.VLANH\x16R\tqinqSvlan\x88\x01\x01\x12\\\n\x17vlan_translation_policy\x18\x1b \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x17R\x15vlanTranslationPolicy\x88\x01\x01\x12*\n\x0emark_connected\x18\x1c \x01(\x08H\x18R\rmarkConnected\x88\x01\x01\x12$\n\x03vrf\x18\x1d \x01(\x0b\x32\r.diode.v1.VRFH\x19R\x03vrf\x88\x01\x01\x12!\n\x04tags\x18\x1e \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x1f \x03(\x0b\x32%.diode.v1.Interface.CustomFieldsEntryR\x0c\x63ustomFields\x12\x32\n\x04vdcs\x18  \x03(\x0b\x32\x1e.diode.v1.VirtualDeviceContextR\x04vdcs\x12\x31\n\x0ctagged_vlans\x18! \x03(\x0b\x32\x0e.diode.v1.VLANR\x0btaggedVlans\x12:\n\rwireless_lans\x18\" \x03(\x0b\x32\x15.diode.v1.WirelessLANR\x0cwirelessLans\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\n\n\x08_enabledB\t\n\x07_parentB\t\n\x07_bridgeB\x06\n\x04_lagB\x06\n\x04_mtuB\x16\n\x14_primary_mac_addressB\x08\n\x06_speedB\t\n\x07_duplexB\x06\n\x04_wwnB\x0c\n\n_mgmt_onlyB\x0e\n\x0c_descriptionB\x07\n\x05_modeB\n\n\x08_rf_roleB\r\n\x0b_rf_channelB\x0b\n\t_poe_modeB\x0b\n\t_poe_typeB\x17\n\x15_rf_channel_frequencyB\x13\n\x11_rf_channel_widthB\x0b\n\t_tx_powerB\x10\n\x0e_untagged_vlanB\r\n\x0b_qinq_svlanB\x1a\n\x18_vlan_translation_policyB\x11\n\x0f_mark_connectedB\x06\n\x04_vrf\"\x98\x0b\n\rInventoryItem\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12\x34\n\x06parent\x18\x02 \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x01R\x06parent\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x02R\x05label\x88\x01\x01\x12]\n\x06status\x18\x05 \x01(\tB@\xfa\x42=r;R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x06\x66\x61iledR\x07offlineR\x07plannedR\x06stagedH\x03R\x06status\x88\x01\x01\x12\x34\n\x04role\x18\x06 \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x04R\x04role\x88\x01\x01\x12?\n\x0cmanufacturer\x18\x07 \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x05R\x0cmanufacturer\x88\x01\x01\x12\x1c\n\x07part_id\x18\x08 \x01(\tH\x06R\x06partId\x88\x01\x01\x12\x1b\n\x06serial\x18\t \x01(\tH\x07R\x06serial\x88\x01\x01\x12 \n\tasset_tag\x18\n \x01(\tH\x08R\x08\x61ssetTag\x88\x01\x01\x12#\n\ndiscovered\x18\x0b \x01(\x08H\tR\ndiscovered\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0c \x01(\tH\nR\x0b\x64\x65scription\x88\x01\x01\x12M\n\x16\x63omponent_console_port\x18\r \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x14\x63omponentConsolePort\x12`\n\x1d\x63omponent_console_server_port\x18\x0e \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1a\x63omponentConsoleServerPort\x12G\n\x14\x63omponent_front_port\x18\x0f \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x12\x63omponentFrontPort\x12\x46\n\x13\x63omponent_interface\x18\x10 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x12\x63omponentInterface\x12M\n\x16\x63omponent_power_outlet\x18\x11 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x14\x63omponentPowerOutlet\x12G\n\x14\x63omponent_power_port\x18\x12 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x12\x63omponentPowerPort\x12\x44\n\x13\x63omponent_rear_port\x18\x13 \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x11\x63omponentRearPort\x12!\n\x04tags\x18\x14 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12N\n\rcustom_fields\x18\x15 \x03(\x0b\x32).diode.v1.InventoryItem.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0b\n\tcomponentB\t\n\x07_parentB\x08\n\x06_labelB\t\n\x07_statusB\x07\n\x05_roleB\x0f\n\r_manufacturerB\n\n\x08_part_idB\t\n\x07_serialB\x0c\n\n_asset_tagB\r\n\x0b_discoveredB\x0e\n\x0c_description\"\xeb\x02\n\x11InventoryItemRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12R\n\rcustom_fields\x18\x06 \x03(\x0b\x32-.diode.v1.InventoryItemRole.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_colorB\x0e\n\x0c_description\"\xb4\x06\n\x05L2VPN\x12#\n\nidentifier\x18\x01 \x01(\x03H\x00R\nidentifier\x88\x01\x01\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x03 \x01(\tR\x04slug\x12\x91\x01\n\x04type\x18\x04 \x01(\tBx\xfa\x42ursR\x06\x65p-lanR\x07\x65p-treeR\x03\x65plR\x07\x65vp-lanR\x08\x65vp-treeR\x04\x65vplR\tevpn-vpwsR\tmpls-evpnR\x08pbb-evpnR\x03spbR\x04vplsR\x04vpwsR\x05vxlanR\nvxlan-evpnH\x01R\x04type\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x06 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12-\n\x06tenant\x18\x07 \x01(\x0b\x32\x10.diode.v1.TenantH\x04R\x06tenant\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x46\n\rcustom_fields\x18\t \x03(\x0b\x32!.diode.v1.L2VPN.CustomFieldsEntryR\x0c\x63ustomFields\x12<\n\x0eimport_targets\x18\n \x03(\x0b\x32\x15.diode.v1.RouteTargetR\rimportTargets\x12<\n\x0e\x65xport_targets\x18\x0b \x03(\x0b\x32\x15.diode.v1.RouteTargetR\rexportTargets\x12\x44\n\x06status\x18\x0c \x01(\tB\'\xfa\x42$r\"R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x07plannedH\x05R\x06status\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0b_identifierB\x07\n\x05_typeB\x0e\n\x0c_descriptionB\x0b\n\t_commentsB\t\n\x07_tenantB\t\n\x07_status\"\x9b\x43\n\x10L2VPNTermination\x12%\n\x05l2vpn\x18\x01 \x01(\x0b\x32\x0f.diode.v1.L2VPNR\x05l2vpn\x12Q\n\x19\x61ssigned_object_interface\x18\x02 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x17\x61ssignedObjectInterface\x12\x42\n\x14\x61ssigned_object_vlan\x18\x03 \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\x12\x61ssignedObjectVlan\x12X\n\x1c\x61ssigned_object_vm_interface\x18\x04 \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x19\x61ssignedObjectVmInterface\x12?\n\x13\x61ssigned_object_asn\x18\x07 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x11\x61ssignedObjectAsn\x12O\n\x19\x61ssigned_object_asn_range\x18\x08 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x16\x61ssignedObjectAsnRange\x12Q\n\x19\x61ssigned_object_aggregate\x18\t \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x17\x61ssignedObjectAggregate\x12\x45\n\x15\x61ssigned_object_cable\x18\n \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x13\x61ssignedObjectCable\x12R\n\x1a\x61ssigned_object_cable_path\x18\x0b \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x17\x61ssignedObjectCablePath\x12g\n!assigned_object_cable_termination\x18\x0c \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x1e\x61ssignedObjectCableTermination\x12K\n\x17\x61ssigned_object_circuit\x18\r \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x15\x61ssignedObjectCircuit\x12[\n\x1d\x61ssigned_object_circuit_group\x18\x0e \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x1a\x61ssignedObjectCircuitGroup\x12z\n(assigned_object_circuit_group_assignment\x18\x0f \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R$assignedObjectCircuitGroupAssignment\x12m\n#assigned_object_circuit_termination\x18\x10 \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R assignedObjectCircuitTermination\x12X\n\x1c\x61ssigned_object_circuit_type\x18\x11 \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x19\x61ssignedObjectCircuitType\x12K\n\x17\x61ssigned_object_cluster\x18\x12 \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x15\x61ssignedObjectCluster\x12[\n\x1d\x61ssigned_object_cluster_group\x18\x13 \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x1a\x61ssignedObjectClusterGroup\x12X\n\x1c\x61ssigned_object_cluster_type\x18\x14 \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x19\x61ssignedObjectClusterType\x12X\n\x1c\x61ssigned_object_console_port\x18\x15 \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x19\x61ssignedObjectConsolePort\x12k\n#assigned_object_console_server_port\x18\x16 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1f\x61ssignedObjectConsoleServerPort\x12K\n\x17\x61ssigned_object_contact\x18\x17 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x15\x61ssignedObjectContact\x12j\n\"assigned_object_contact_assignment\x18\x18 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x1f\x61ssignedObjectContactAssignment\x12[\n\x1d\x61ssigned_object_contact_group\x18\x19 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x1a\x61ssignedObjectContactGroup\x12X\n\x1c\x61ssigned_object_contact_role\x18\x1a \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x19\x61ssignedObjectContactRole\x12X\n\x1c\x61ssigned_object_custom_field\x18\x1b \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x19\x61ssignedObjectCustomField\x12u\n\'assigned_object_custom_field_choice_set\x18\x1c \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\"assignedObjectCustomFieldChoiceSet\x12H\n\x16\x61ssigned_object_device\x18\x1d \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x14\x61ssignedObjectDevice\x12R\n\x1a\x61ssigned_object_device_bay\x18\x1e \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x17\x61ssignedObjectDeviceBay\x12U\n\x1b\x61ssigned_object_device_role\x18\x1f \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x18\x61ssignedObjectDeviceRole\x12U\n\x1b\x61ssigned_object_device_type\x18  \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x18\x61ssignedObjectDeviceType\x12R\n\x1a\x61ssigned_object_fhrp_group\x18! \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x17\x61ssignedObjectFhrpGroup\x12q\n%assigned_object_fhrp_group_assignment\x18\" \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R!assignedObjectFhrpGroupAssignment\x12R\n\x1a\x61ssigned_object_front_port\x18# \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x17\x61ssignedObjectFrontPort\x12R\n\x1a\x61ssigned_object_ike_policy\x18$ \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x17\x61ssignedObjectIkePolicy\x12X\n\x1c\x61ssigned_object_ike_proposal\x18% \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x19\x61ssignedObjectIkeProposal\x12R\n\x1a\x61ssigned_object_ip_address\x18& \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x17\x61ssignedObjectIpAddress\x12L\n\x18\x61ssigned_object_ip_range\x18\' \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x15\x61ssignedObjectIpRange\x12Y\n\x1d\x61ssigned_object_ip_sec_policy\x18( \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x19\x61ssignedObjectIpSecPolicy\x12\\\n\x1e\x61ssigned_object_ip_sec_profile\x18) \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x1a\x61ssignedObjectIpSecProfile\x12_\n\x1f\x61ssigned_object_ip_sec_proposal\x18* \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x1b\x61ssignedObjectIpSecProposal\x12^\n\x1e\x61ssigned_object_inventory_item\x18+ \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x1b\x61ssignedObjectInventoryItem\x12k\n#assigned_object_inventory_item_role\x18, \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x1f\x61ssignedObjectInventoryItemRole\x12[\n\x1d\x61ssigned_object_journal_entry\x18- \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x1a\x61ssignedObjectJournalEntry\x12\x45\n\x15\x61ssigned_object_l2vpn\x18. \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x13\x61ssignedObjectL2vpn\x12g\n!assigned_object_l2vpn_termination\x18/ \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x1e\x61ssignedObjectL2vpnTermination\x12N\n\x18\x61ssigned_object_location\x18\x30 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x16\x61ssignedObjectLocation\x12U\n\x1b\x61ssigned_object_mac_address\x18\x31 \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x18\x61ssignedObjectMacAddress\x12Z\n\x1c\x61ssigned_object_manufacturer\x18\x32 \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x1a\x61ssignedObjectManufacturer\x12H\n\x16\x61ssigned_object_module\x18\x33 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x14\x61ssignedObjectModule\x12R\n\x1a\x61ssigned_object_module_bay\x18\x34 \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x17\x61ssignedObjectModuleBay\x12U\n\x1b\x61ssigned_object_module_type\x18\x35 \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x18\x61ssignedObjectModuleType\x12k\n#assigned_object_module_type_profile\x18\x36 \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x1f\x61ssignedObjectModuleTypeProfile\x12N\n\x18\x61ssigned_object_platform\x18\x37 \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x16\x61ssignedObjectPlatform\x12R\n\x1a\x61ssigned_object_power_feed\x18\x38 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x17\x61ssignedObjectPowerFeed\x12X\n\x1c\x61ssigned_object_power_outlet\x18\x39 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x19\x61ssignedObjectPowerOutlet\x12U\n\x1b\x61ssigned_object_power_panel\x18: \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x18\x61ssignedObjectPowerPanel\x12R\n\x1a\x61ssigned_object_power_port\x18; \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x17\x61ssignedObjectPowerPort\x12H\n\x16\x61ssigned_object_prefix\x18< \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x14\x61ssignedObjectPrefix\x12N\n\x18\x61ssigned_object_provider\x18= \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x16\x61ssignedObjectProvider\x12\x64\n assigned_object_provider_account\x18> \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x1d\x61ssignedObjectProviderAccount\x12\x64\n assigned_object_provider_network\x18? \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x1d\x61ssignedObjectProviderNetwork\x12?\n\x13\x61ssigned_object_rir\x18@ \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x11\x61ssignedObjectRir\x12\x42\n\x14\x61ssigned_object_rack\x18\x41 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x12\x61ssignedObjectRack\x12\x64\n assigned_object_rack_reservation\x18\x42 \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x1d\x61ssignedObjectRackReservation\x12O\n\x19\x61ssigned_object_rack_role\x18\x43 \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x16\x61ssignedObjectRackRole\x12O\n\x19\x61ssigned_object_rack_type\x18\x44 \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x16\x61ssignedObjectRackType\x12O\n\x19\x61ssigned_object_rear_port\x18\x45 \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x16\x61ssignedObjectRearPort\x12H\n\x16\x61ssigned_object_region\x18\x46 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x14\x61ssignedObjectRegion\x12\x42\n\x14\x61ssigned_object_role\x18G \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\x12\x61ssignedObjectRole\x12X\n\x1c\x61ssigned_object_route_target\x18H \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x19\x61ssignedObjectRouteTarget\x12K\n\x17\x61ssigned_object_service\x18I \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x15\x61ssignedObjectService\x12\x42\n\x14\x61ssigned_object_site\x18J \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x12\x61ssignedObjectSite\x12R\n\x1a\x61ssigned_object_site_group\x18K \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x17\x61ssignedObjectSiteGroup\x12?\n\x13\x61ssigned_object_tag\x18L \x01(\x0b\x32\r.diode.v1.TagH\x00R\x11\x61ssignedObjectTag\x12H\n\x16\x61ssigned_object_tenant\x18M \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x14\x61ssignedObjectTenant\x12X\n\x1c\x61ssigned_object_tenant_group\x18N \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x19\x61ssignedObjectTenantGroup\x12H\n\x16\x61ssigned_object_tunnel\x18O \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x14\x61ssignedObjectTunnel\x12X\n\x1c\x61ssigned_object_tunnel_group\x18P \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x19\x61ssignedObjectTunnelGroup\x12j\n\"assigned_object_tunnel_termination\x18Q \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x1f\x61ssignedObjectTunnelTermination\x12R\n\x1a\x61ssigned_object_vlan_group\x18R \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x17\x61ssignedObjectVlanGroup\x12w\n\'assigned_object_vlan_translation_policy\x18S \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R#assignedObjectVlanTranslationPolicy\x12q\n%assigned_object_vlan_translation_rule\x18T \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R!assignedObjectVlanTranslationRule\x12?\n\x13\x61ssigned_object_vrf\x18U \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x11\x61ssignedObjectVrf\x12\x61\n\x1f\x61ssigned_object_virtual_chassis\x18V \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x1c\x61ssignedObjectVirtualChassis\x12\x61\n\x1f\x61ssigned_object_virtual_circuit\x18W \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x1c\x61ssignedObjectVirtualCircuit\x12\x83\x01\n+assigned_object_virtual_circuit_termination\x18X \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\'assignedObjectVirtualCircuitTermination\x12n\n$assigned_object_virtual_circuit_type\x18Y \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R assignedObjectVirtualCircuitType\x12t\n&assigned_object_virtual_device_context\x18Z \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\"assignedObjectVirtualDeviceContext\x12X\n\x1c\x61ssigned_object_virtual_disk\x18[ \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x19\x61ssignedObjectVirtualDisk\x12\x61\n\x1f\x61ssigned_object_virtual_machine\x18\\ \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x1c\x61ssignedObjectVirtualMachine\x12X\n\x1c\x61ssigned_object_wireless_lan\x18] \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x19\x61ssignedObjectWirelessLan\x12h\n\"assigned_object_wireless_lan_group\x18^ \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x1e\x61ssignedObjectWirelessLanGroup\x12[\n\x1d\x61ssigned_object_wireless_link\x18_ \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x1a\x61ssignedObjectWirelessLink\x12U\n\x1b\x61ssigned_object_custom_link\x18` \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x18\x61ssignedObjectCustomLink\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12Q\n\rcustom_fields\x18\x06 \x03(\x0b\x32,.diode.v1.L2VPNTermination.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x11\n\x0f\x61ssigned_object\"\x8d\x05\n\x08Location\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\"\n\x04site\x18\x03 \x01(\x0b\x32\x0e.diode.v1.SiteR\x04site\x12/\n\x06parent\x18\x04 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x06parent\x88\x01\x01\x12V\n\x06status\x18\x05 \x01(\tB9\xfa\x42\x36r4R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x07plannedR\x07retiredR\x07stagingH\x01R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12\x1f\n\x08\x66\x61\x63ility\x18\x07 \x01(\tH\x03R\x08\x66\x61\x63ility\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\n \x03(\x0b\x32$.diode.v1.Location.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x0b \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\t\n\x07_statusB\t\n\x07_tenantB\x0b\n\t_facilityB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\x9f\x04\n\nMACAddress\x12\x1f\n\x0bmac_address\x18\x01 \x01(\tR\nmacAddress\x12Q\n\x19\x61ssigned_object_interface\x18\x02 \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x17\x61ssignedObjectInterface\x12X\n\x1c\x61ssigned_object_vm_interface\x18\x03 \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x19\x61ssignedObjectVmInterface\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12K\n\rcustom_fields\x18\x07 \x03(\x0b\x32&.diode.v1.MACAddress.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x11\n\x0f\x61ssigned_objectB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xbc\x02\n\x0cManufacturer\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x04 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x05 \x03(\x0b\x32(.diode.v1.Manufacturer.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\x8d\x05\n\x06Module\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12\x32\n\nmodule_bay\x18\x02 \x01(\x0b\x32\x13.diode.v1.ModuleBayR\tmoduleBay\x12\x35\n\x0bmodule_type\x18\x03 \x01(\x0b\x32\x14.diode.v1.ModuleTypeR\nmoduleType\x12]\n\x06status\x18\x04 \x01(\tB@\xfa\x42=r;R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x06\x66\x61iledR\x07offlineR\x07plannedR\x06stagedH\x00R\x06status\x88\x01\x01\x12\x1b\n\x06serial\x18\x05 \x01(\tH\x01R\x06serial\x88\x01\x01\x12 \n\tasset_tag\x18\x06 \x01(\tH\x02R\x08\x61ssetTag\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x03R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x08 \x01(\tH\x04R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\n \x03(\x0b\x32\".diode.v1.Module.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_statusB\t\n\x07_serialB\x0c\n\n_asset_tagB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xb0\x04\n\tModuleBay\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12@\n\x10installed_module\x18\x04 \x01(\x0b\x32\x10.diode.v1.ModuleH\x01R\x0finstalledModule\x88\x01\x01\x12\x19\n\x05label\x18\x05 \x01(\tH\x02R\x05label\x88\x01\x01\x12\x1f\n\x08position\x18\x06 \x01(\tH\x03R\x08position\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\t \x03(\x0b\x32%.diode.v1.ModuleBay.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x13\n\x11_installed_moduleB\x08\n\x06_labelB\x0b\n\t_positionB\x0e\n\x0c_description\"\xbb\x06\n\nModuleType\x12:\n\x0cmanufacturer\x18\x01 \x01(\x0b\x32\x16.diode.v1.ManufacturerR\x0cmanufacturer\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12$\n\x0bpart_number\x18\x03 \x01(\tH\x00R\npartNumber\x88\x01\x01\x12w\n\x07\x61irflow\x18\x04 \x01(\tBX\xfa\x42UrSR\rfront-to-rearR\rleft-to-rightR\x07passiveR\rrear-to-frontR\rright-to-leftR\x0cside-to-rearH\x01R\x07\x61irflow\x88\x01\x01\x12\x1b\n\x06weight\x18\x05 \x01(\x01H\x02R\x06weight\x88\x01\x01\x12:\n\x0bweight_unit\x18\x06 \x01(\tB\x14\xfa\x42\x11r\x0fR\x01gR\x02kgR\x02lbR\x02ozH\x03R\nweightUnit\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x08 \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12K\n\rcustom_fields\x18\n \x03(\x0b\x32&.diode.v1.ModuleType.CustomFieldsEntryR\x0c\x63ustomFields\x12:\n\x07profile\x18\x0b \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x06R\x07profile\x88\x01\x01\x12#\n\nattributes\x18\x0c \x01(\tH\x07R\nattributes\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_part_numberB\n\n\x08_airflowB\t\n\x07_weightB\x0e\n\x0c_weight_unitB\x0e\n\x0c_descriptionB\x0b\n\t_commentsB\n\n\x08_profileB\r\n\x0b_attributes\"\x86\x03\n\x08Platform\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12?\n\x0cmanufacturer\x18\x03 \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x0cmanufacturer\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\x06 \x03(\x0b\x32$.diode.v1.Platform.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0f\n\r_manufacturerB\x0e\n\x0c_description\"\xd9\x07\n\tPowerFeed\x12\x35\n\x0bpower_panel\x18\x01 \x01(\x0b\x32\x14.diode.v1.PowerPanelR\npowerPanel\x12\'\n\x04rack\x18\x02 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x04rack\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x44\n\x06status\x18\x04 \x01(\tB\'\xfa\x42$r\"R\x06\x61\x63tiveR\x06\x66\x61iledR\x07offlineR\x07plannedH\x01R\x06status\x88\x01\x01\x12\x32\n\x04type\x18\x05 \x01(\tB\x19\xfa\x42\x16r\x14R\x07primaryR\tredundantH\x02R\x04type\x88\x01\x01\x12*\n\x06supply\x18\x06 \x01(\tB\r\xfa\x42\nr\x08R\x02\x61\x63R\x02\x64\x63H\x03R\x06supply\x88\x01\x01\x12;\n\x05phase\x18\x07 \x01(\tB \xfa\x42\x1dr\x1bR\x0csingle-phaseR\x0bthree-phaseH\x04R\x05phase\x88\x01\x01\x12\x1d\n\x07voltage\x18\x08 \x01(\x03H\x05R\x07voltage\x88\x01\x01\x12\x1f\n\x08\x61mperage\x18\t \x01(\x03H\x06R\x08\x61mperage\x88\x01\x01\x12,\n\x0fmax_utilization\x18\n \x01(\x03H\x07R\x0emaxUtilization\x88\x01\x01\x12*\n\x0emark_connected\x18\x0b \x01(\x08H\x08R\rmarkConnected\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0c \x01(\tH\tR\x0b\x64\x65scription\x88\x01\x01\x12-\n\x06tenant\x18\r \x01(\x0b\x32\x10.diode.v1.TenantH\nR\x06tenant\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0e \x01(\tH\x0bR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x10 \x03(\x0b\x32%.diode.v1.PowerFeed.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_rackB\t\n\x07_statusB\x07\n\x05_typeB\t\n\x07_supplyB\x08\n\x06_phaseB\n\n\x08_voltageB\x0b\n\t_amperageB\x12\n\x10_max_utilizationB\x11\n\x0f_mark_connectedB\x0e\n\x0c_descriptionB\t\n\x07_tenantB\x0b\n\t_comments\"\xc9\x10\n\x0bPowerOutlet\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xdb\n\n\x04type\x18\x05 \x01(\tB\xc1\n\xfa\x42\xbd\nr\xba\nR\x07\x43S6360CR\x07\x43S6364CR\x07\x43S8164CR\x07\x43S8264CR\x07\x43S8364CR\x07\x43S8464CR\x0b\x64\x63-terminalR\teaton-c39R\thardwiredR\x07hdot-cxR\x11iec-60309-2p-e-4hR\x11iec-60309-2p-e-6hR\x11iec-60309-2p-e-9hR\x11iec-60309-3p-e-4hR\x11iec-60309-3p-e-6hR\x11iec-60309-3p-e-9hR\x13iec-60309-3p-n-e-4hR\x13iec-60309-3p-n-e-6hR\x13iec-60309-3p-n-e-9hR\x12iec-60309-p-n-e-4hR\x12iec-60309-p-n-e-6hR\x12iec-60309-p-n-e-9hR\riec-60320-c13R\riec-60320-c15R\riec-60320-c19R\riec-60320-c21R\x0ciec-60320-c5R\x0ciec-60320-c7R\x0biec-60906-1R\x05ita-eR\x05ita-fR\x05ita-gR\x05ita-hR\x05ita-iR\x05ita-jR\x05ita-kR\x05ita-lR\x05ita-mR\x11ita-multistandardR\x05ita-nR\x05ita-oR\x13molex-micro-fit-1x2R\x13molex-micro-fit-2x2R\x13molex-micro-fit-2x4R\rnbr-14136-10aR\rnbr-14136-20aR\nnema-1-15rR\x0bnema-10-30rR\x0bnema-10-50rR\x0bnema-14-20rR\x0bnema-14-30rR\x0bnema-14-50rR\x0bnema-14-60rR\x0bnema-15-15rR\x0bnema-15-20rR\x0bnema-15-30rR\x0bnema-15-50rR\x0bnema-15-60rR\nnema-5-15rR\nnema-5-20rR\nnema-5-30rR\nnema-5-50rR\nnema-6-15rR\nnema-6-20rR\nnema-6-30rR\nnema-6-50rR\x0bnema-l1-15rR\x0cnema-l10-30rR\x0cnema-l14-20rR\x0cnema-l14-30rR\x0cnema-l14-50rR\x0cnema-l14-60rR\x0cnema-l15-20rR\x0cnema-l15-30rR\x0cnema-l15-50rR\x0cnema-l15-60rR\x0cnema-l21-20rR\x0cnema-l21-30rR\x0cnema-l22-20rR\x0cnema-l22-30rR\x0bnema-l5-15rR\x0bnema-l5-20rR\x0bnema-l5-30rR\x0bnema-l5-50rR\x0bnema-l6-15rR\x0bnema-l6-20rR\x0bnema-l6-30rR\x0bnema-l6-50rR\x14neutrik-powercon-20aR\x14neutrik-powercon-32aR\x16neutrik-powercon-true1R\x1aneutrik-powercon-true1-topR\x05otherR\nsaf-d-gridR\x13ubiquiti-smartpowerR\x05usb-aR\x05usb-cR\x0busb-micro-bH\x02R\x04type\x88\x01\x01\x12\x19\n\x05\x63olor\x18\x06 \x01(\tH\x03R\x05\x63olor\x88\x01\x01\x12\x37\n\npower_port\x18\x07 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x04R\tpowerPort\x88\x01\x01\x12.\n\x08\x66\x65\x65\x64_leg\x18\x08 \x01(\tB\x0e\xfa\x42\x0br\tR\x01\x41R\x01\x42R\x01\x43H\x05R\x07\x66\x65\x65\x64Leg\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x06R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\n \x01(\x08H\x07R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\x0b \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x0c \x03(\x0b\x32\'.diode.v1.PowerOutlet.CustomFieldsEntryR\x0c\x63ustomFields\x12=\n\x06status\x18\r \x01(\tB \xfa\x42\x1dr\x1bR\x08\x64isabledR\x07\x65nabledR\x06\x66\x61ultyH\x08R\x06status\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x07\n\x05_typeB\x08\n\x06_colorB\r\n\x0b_power_portB\x0b\n\t_feed_legB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connectedB\t\n\x07_status\"\xb8\x03\n\nPowerPanel\x12\"\n\x04site\x18\x01 \x01(\x0b\x32\x0e.diode.v1.SiteR\x04site\x12\x33\n\x08location\x18\x02 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x08location\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12K\n\rcustom_fields\x18\x07 \x03(\x0b\x32&.diode.v1.PowerPanel.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0b\n\t_locationB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\x81\x10\n\tPowerPort\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\x93\x0b\n\x04type\x18\x05 \x01(\tB\xf9\n\xfa\x42\xf5\nr\xf2\nR\x07\x63s6361cR\x07\x63s6365cR\x07\x63s8165cR\x07\x63s8265cR\x07\x63s8365cR\x07\x63s8465cR\x0b\x64\x63-terminalR\thardwiredR\x11iec-60309-2p-e-4hR\x11iec-60309-2p-e-6hR\x11iec-60309-2p-e-9hR\x11iec-60309-3p-e-4hR\x11iec-60309-3p-e-6hR\x11iec-60309-3p-e-9hR\x13iec-60309-3p-n-e-4hR\x13iec-60309-3p-n-e-6hR\x13iec-60309-3p-n-e-9hR\x12iec-60309-p-n-e-4hR\x12iec-60309-p-n-e-6hR\x12iec-60309-p-n-e-9hR\riec-60320-c14R\riec-60320-c16R\riec-60320-c20R\riec-60320-c22R\x0ciec-60320-c6R\x0ciec-60320-c8R\x0biec-60906-1R\x05ita-cR\x05ita-eR\x06ita-efR\x05ita-fR\x05ita-gR\x05ita-hR\x05ita-iR\x05ita-jR\x05ita-kR\x05ita-lR\x05ita-mR\x05ita-nR\x05ita-oR\x13molex-micro-fit-1x2R\x13molex-micro-fit-2x2R\x13molex-micro-fit-2x4R\rnbr-14136-10aR\rnbr-14136-20aR\nnema-1-15pR\x0bnema-10-30pR\x0bnema-10-50pR\x0bnema-14-20pR\x0bnema-14-30pR\x0bnema-14-50pR\x0bnema-14-60pR\x0bnema-15-15pR\x0bnema-15-20pR\x0bnema-15-30pR\x0bnema-15-50pR\x0bnema-15-60pR\nnema-5-15pR\nnema-5-20pR\nnema-5-30pR\nnema-5-50pR\nnema-6-15pR\nnema-6-20pR\nnema-6-30pR\nnema-6-50pR\x0bnema-l1-15pR\x0cnema-l10-30pR\x0cnema-l14-20pR\x0cnema-l14-30pR\x0cnema-l14-50pR\x0cnema-l14-60pR\x0cnema-l15-20pR\x0cnema-l15-30pR\x0cnema-l15-50pR\x0cnema-l15-60pR\x0cnema-l21-20pR\x0cnema-l21-30pR\x0cnema-l22-20pR\x0cnema-l22-30pR\x0bnema-l5-15pR\x0bnema-l5-20pR\x0bnema-l5-30pR\x0bnema-l5-50pR\x0bnema-l6-15pR\x0bnema-l6-20pR\x0bnema-l6-30pR\x0bnema-l6-50pR\x13neutrik-powercon-20R\x13neutrik-powercon-32R\x16neutrik-powercon-true1R\x1aneutrik-powercon-true1-topR\x05otherR\nsaf-d-gridR\x13ubiquiti-smartpowerR\x07usb-3-bR\rusb-3-micro-bR\x05usb-aR\x05usb-bR\x05usb-cR\x0busb-micro-aR\x0cusb-micro-abR\x0busb-micro-bR\nusb-mini-aR\nusb-mini-bH\x02R\x04type\x88\x01\x01\x12&\n\x0cmaximum_draw\x18\x06 \x01(\x03H\x03R\x0bmaximumDraw\x88\x01\x01\x12*\n\x0e\x61llocated_draw\x18\x07 \x01(\x03H\x04R\rallocatedDraw\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\t \x01(\x08H\x06R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\n \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x0b \x03(\x0b\x32%.diode.v1.PowerPort.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x07\n\x05_typeB\x0f\n\r_maximum_drawB\x11\n\x0f_allocated_drawB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\xc7\x07\n\x06Prefix\x12\x16\n\x06prefix\x18\x01 \x01(\tR\x06prefix\x12$\n\x03vrf\x18\x02 \x01(\x0b\x32\r.diode.v1.VRFH\x01R\x03vrf\x88\x01\x01\x12;\n\x0escope_location\x18\x03 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\rscopeLocation\x12\x35\n\x0cscope_region\x18\x04 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0bscopeRegion\x12/\n\nscope_site\x18\x05 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\tscopeSite\x12?\n\x10scope_site_group\x18\x06 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0escopeSiteGroup\x12-\n\x06tenant\x18\x07 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12\'\n\x04vlan\x18\x08 \x01(\x0b\x32\x0e.diode.v1.VLANH\x03R\x04vlan\x88\x01\x01\x12K\n\x06status\x18\t \x01(\tB.\xfa\x42+r)R\x06\x61\x63tiveR\tcontainerR\ndeprecatedR\x08reservedH\x04R\x06status\x88\x01\x01\x12\'\n\x04role\x18\n \x01(\x0b\x32\x0e.diode.v1.RoleH\x05R\x04role\x88\x01\x01\x12\x1c\n\x07is_pool\x18\x0b \x01(\x08H\x06R\x06isPool\x88\x01\x01\x12(\n\rmark_utilized\x18\x0c \x01(\x08H\x07R\x0cmarkUtilized\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\r \x01(\tH\x08R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0e \x01(\tH\tR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\x10 \x03(\x0b\x32\".diode.v1.Prefix.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05scopeB\x06\n\x04_vrfB\t\n\x07_tenantB\x07\n\x05_vlanB\t\n\x07_statusB\x07\n\x05_roleB\n\n\x08_is_poolB\x10\n\x0e_mark_utilizedB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xbc\x03\n\x08Provider\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x04 \x01(\tH\x01R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\x06 \x03(\x0b\x32$.diode.v1.Provider.CustomFieldsEntryR\x0c\x63ustomFields\x12\x35\n\x08\x61\x63\x63ounts\x18\x07 \x03(\x0b\x32\x19.diode.v1.ProviderAccountR\x08\x61\x63\x63ounts\x12!\n\x04\x61sns\x18\x08 \x03(\x0b\x32\r.diode.v1.ASNR\x04\x61sns\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xb4\x03\n\x0fProviderAccount\x12.\n\x08provider\x18\x01 \x01(\x0b\x32\x12.diode.v1.ProviderR\x08provider\x12\x17\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x88\x01\x01\x12\x18\n\x07\x61\x63\x63ount\x18\x03 \x01(\tR\x07\x61\x63\x63ount\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12P\n\rcustom_fields\x18\x07 \x03(\x0b\x32+.diode.v1.ProviderAccount.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xbf\x03\n\x0fProviderNetwork\x12.\n\x08provider\x18\x01 \x01(\x0b\x32\x12.diode.v1.ProviderR\x08provider\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\"\n\nservice_id\x18\x03 \x01(\tH\x00R\tserviceId\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12P\n\rcustom_fields\x18\x07 \x03(\x0b\x32+.diode.v1.ProviderNetwork.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0b_service_idB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xdd\x02\n\x03RIR\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\"\n\nis_private\x18\x03 \x01(\x08H\x00R\tisPrivate\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x44\n\rcustom_fields\x18\x06 \x03(\x0b\x32\x1f.diode.v1.RIR.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0b_is_privateB\x0e\n\x0c_description\"\xec\r\n\x04Rack\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12$\n\x0b\x66\x61\x63ility_id\x18\x02 \x01(\tH\x00R\nfacilityId\x88\x01\x01\x12\"\n\x04site\x18\x03 \x01(\x0b\x32\x0e.diode.v1.SiteR\x04site\x12\x33\n\x08location\x18\x04 \x01(\x0b\x32\x12.diode.v1.LocationH\x01R\x08location\x88\x01\x01\x12-\n\x06tenant\x18\x05 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12T\n\x06status\x18\x06 \x01(\tB7\xfa\x42\x34r2R\x06\x61\x63tiveR\tavailableR\ndeprecatedR\x07plannedR\x08reservedH\x03R\x06status\x88\x01\x01\x12+\n\x04role\x18\x07 \x01(\x0b\x32\x12.diode.v1.RackRoleH\x04R\x04role\x88\x01\x01\x12\x1b\n\x06serial\x18\x08 \x01(\tH\x05R\x06serial\x88\x01\x01\x12 \n\tasset_tag\x18\t \x01(\tH\x06R\x08\x61ssetTag\x88\x01\x01\x12\x34\n\track_type\x18\n \x01(\x0b\x32\x12.diode.v1.RackTypeH\x07R\x08rackType\x88\x01\x01\x12\x9d\x01\n\x0b\x66orm_factor\x18\x0b \x01(\tBw\xfa\x42trrR\x0c\x32-post-frameR\x0e\x34-post-cabinetR\x0c\x34-post-frameR\x0cwall-cabinetR\x15wall-cabinet-verticalR\nwall-frameR\x13wall-frame-verticalH\x08R\nformFactor\x88\x01\x01\x12(\n\x05width\x18\x0c \x01(\x03\x42\r\xfa\x42\n\"\x08\x30\n0\x13\x30\x15\x30\x17H\tR\x05width\x88\x01\x01\x12\x1e\n\x08u_height\x18\r \x01(\x03H\nR\x07uHeight\x88\x01\x01\x12(\n\rstarting_unit\x18\x0e \x01(\x03H\x0bR\x0cstartingUnit\x88\x01\x01\x12\x1b\n\x06weight\x18\x0f \x01(\x01H\x0cR\x06weight\x88\x01\x01\x12\"\n\nmax_weight\x18\x10 \x01(\x03H\rR\tmaxWeight\x88\x01\x01\x12:\n\x0bweight_unit\x18\x11 \x01(\tB\x14\xfa\x42\x11r\x0fR\x01gR\x02kgR\x02lbR\x02ozH\x0eR\nweightUnit\x88\x01\x01\x12\"\n\ndesc_units\x18\x12 \x01(\x08H\x0fR\tdescUnits\x88\x01\x01\x12$\n\x0bouter_width\x18\x13 \x01(\x03H\x10R\nouterWidth\x88\x01\x01\x12$\n\x0bouter_depth\x18\x14 \x01(\x03H\x11R\nouterDepth\x88\x01\x01\x12\x31\n\nouter_unit\x18\x15 \x01(\tB\r\xfa\x42\nr\x08R\x02inR\x02mmH\x12R\touterUnit\x88\x01\x01\x12*\n\x0emounting_depth\x18\x16 \x01(\x03H\x13R\rmountingDepth\x88\x01\x01\x12\x42\n\x07\x61irflow\x18\x17 \x01(\tB#\xfa\x42 r\x1eR\rfront-to-rearR\rrear-to-frontH\x14R\x07\x61irflow\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x18 \x01(\tH\x15R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x19 \x01(\tH\x16R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x1a \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x45\n\rcustom_fields\x18\x1b \x03(\x0b\x32 .diode.v1.Rack.CustomFieldsEntryR\x0c\x63ustomFields\x12&\n\x0couter_height\x18\x1c \x01(\x03H\x17R\x0bouterHeight\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_facility_idB\x0b\n\t_locationB\t\n\x07_tenantB\t\n\x07_statusB\x07\n\x05_roleB\t\n\x07_serialB\x0c\n\n_asset_tagB\x0c\n\n_rack_typeB\x0e\n\x0c_form_factorB\x08\n\x06_widthB\x0b\n\t_u_heightB\x10\n\x0e_starting_unitB\t\n\x07_weightB\r\n\x0b_max_weightB\x0e\n\x0c_weight_unitB\r\n\x0b_desc_unitsB\x0e\n\x0c_outer_widthB\x0e\n\x0c_outer_depthB\r\n\x0b_outer_unitB\x11\n\x0f_mounting_depthB\n\n\x08_airflowB\x0e\n\x0c_descriptionB\x0b\n\t_commentsB\x0f\n\r_outer_height\"\xa7\x03\n\x0fRackReservation\x12\"\n\x04rack\x18\x01 \x01(\x0b\x32\x0e.diode.v1.RackR\x04rack\x12\x14\n\x05units\x18\x02 \x03(\x03R\x05units\x12-\n\x06tenant\x18\x03 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x88\x01\x01\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x01R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12P\n\rcustom_fields\x18\x07 \x03(\x0b\x32+.diode.v1.RackReservation.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_tenantB\x0b\n\t_comments\"\xd9\x02\n\x08RackRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\x06 \x03(\x0b\x32$.diode.v1.RackRole.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_colorB\x0e\n\x0c_description\"\xed\t\n\x08RackType\x12:\n\x0cmanufacturer\x18\x01 \x01(\x0b\x32\x16.diode.v1.ManufacturerR\x0cmanufacturer\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x12\n\x04slug\x18\x03 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x9d\x01\n\x0b\x66orm_factor\x18\x05 \x01(\tBw\xfa\x42trrR\x0c\x32-post-frameR\x0e\x34-post-cabinetR\x0c\x34-post-frameR\x0cwall-cabinetR\x15wall-cabinet-verticalR\nwall-frameR\x13wall-frame-verticalH\x01R\nformFactor\x88\x01\x01\x12(\n\x05width\x18\x06 \x01(\x03\x42\r\xfa\x42\n\"\x08\x30\n0\x13\x30\x15\x30\x17H\x02R\x05width\x88\x01\x01\x12\x1e\n\x08u_height\x18\x07 \x01(\x03H\x03R\x07uHeight\x88\x01\x01\x12(\n\rstarting_unit\x18\x08 \x01(\x03H\x04R\x0cstartingUnit\x88\x01\x01\x12\"\n\ndesc_units\x18\t \x01(\x08H\x05R\tdescUnits\x88\x01\x01\x12$\n\x0bouter_width\x18\n \x01(\x03H\x06R\nouterWidth\x88\x01\x01\x12$\n\x0bouter_depth\x18\x0b \x01(\x03H\x07R\nouterDepth\x88\x01\x01\x12\x31\n\nouter_unit\x18\x0c \x01(\tB\r\xfa\x42\nr\x08R\x02inR\x02mmH\x08R\touterUnit\x88\x01\x01\x12\x1b\n\x06weight\x18\r \x01(\x01H\tR\x06weight\x88\x01\x01\x12\"\n\nmax_weight\x18\x0e \x01(\x03H\nR\tmaxWeight\x88\x01\x01\x12:\n\x0bweight_unit\x18\x0f \x01(\tB\x14\xfa\x42\x11r\x0fR\x01gR\x02kgR\x02lbR\x02ozH\x0bR\nweightUnit\x88\x01\x01\x12*\n\x0emounting_depth\x18\x10 \x01(\x03H\x0cR\rmountingDepth\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x11 \x01(\tH\rR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x12 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\x13 \x03(\x0b\x32$.diode.v1.RackType.CustomFieldsEntryR\x0c\x63ustomFields\x12&\n\x0couter_height\x18\x14 \x01(\x03H\x0eR\x0bouterHeight\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\x0e\n\x0c_form_factorB\x08\n\x06_widthB\x0b\n\t_u_heightB\x10\n\x0e_starting_unitB\r\n\x0b_desc_unitsB\x0e\n\x0c_outer_widthB\x0e\n\x0c_outer_depthB\r\n\x0b_outer_unitB\t\n\x07_weightB\r\n\x0b_max_weightB\x0e\n\x0c_weight_unitB\x11\n\x0f_mounting_depthB\x0b\n\t_commentsB\x0f\n\r_outer_height\"\x85\x08\n\x08RearPort\x12(\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12-\n\x06module\x18\x02 \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x06module\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\xc4\x03\n\x04type\x18\x05 \x01(\tB\xaf\x03\xfa\x42\xab\x03r\xa8\x03R\t110-punchR\x04\x34p2cR\x04\x34p4cR\x04\x36p2cR\x04\x36p4cR\x04\x36p6cR\x04\x38p2cR\x04\x38p4cR\x04\x38p6cR\x04\x38p8cR\x03\x62ncR\x02\x63sR\x01\x66R\x02\x66\x63R\x06\x66\x63-apcR\x05\x66\x63-pcR\x06\x66\x63-upcR\x04gg45R\x02lcR\x06lc-apcR\x05lc-pcR\x06lc-upcR\x03lshR\x07lsh-apcR\x06lsh-pcR\x07lsh-upcR\x03lx5R\x07lx5-apcR\x06lx5-pcR\x07lx5-upcR\x03mpoR\x05mrj21R\x04mtrjR\x01nR\x05otherR\x02scR\x06sc-apcR\x05sc-pcR\x06sc-upcR\x07sma-905R\x07sma-906R\x02snR\x06spliceR\x02stR\x07tera-1pR\x07tera-2pR\x07tera-4pR\x06urm-p2R\x06urm-p4R\x06urm-p8R\x05usb-aR\x05usb-bR\x05usb-cR\x0busb-micro-aR\x0cusb-micro-abR\x0busb-micro-bR\nusb-mini-aR\nusb-mini-bR\x04type\x12\x19\n\x05\x63olor\x18\x06 \x01(\tH\x02R\x05\x63olor\x88\x01\x01\x12!\n\tpositions\x18\x07 \x01(\x03H\x03R\tpositions\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x0emark_connected\x18\t \x01(\x08H\x05R\rmarkConnected\x88\x01\x01\x12!\n\x04tags\x18\n \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12I\n\rcustom_fields\x18\x0b \x03(\x0b\x32$.diode.v1.RearPort.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_moduleB\x08\n\x06_labelB\x08\n\x06_colorB\x0c\n\n_positionsB\x0e\n\x0c_descriptionB\x11\n\x0f_mark_connected\"\x98\x03\n\x06Region\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12-\n\x06parent\x18\x03 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x06parent\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\x06 \x03(\x0b\x32\".diode.v1.Region.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xd4\x02\n\x04Role\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x1b\n\x06weight\x18\x03 \x01(\x03H\x00R\x06weight\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x45\n\rcustom_fields\x18\x06 \x03(\x0b\x32 .diode.v1.Role.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_weightB\x0e\n\x0c_description\"\x8e\x03\n\x0bRouteTarget\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12-\n\x06tenant\x18\x02 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x06tenant\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x04 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x06 \x03(\x0b\x32\'.diode.v1.RouteTarget.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_tenantB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\x82\x07\n\x07Service\x12\x31\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x10.diode.v1.DeviceB\x02\x18\x01H\x01R\x06\x64\x65vice\x88\x01\x01\x12J\n\x0fvirtual_machine\x18\x02 \x01(\x0b\x32\x18.diode.v1.VirtualMachineB\x02\x18\x01H\x02R\x0evirtualMachine\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x36\n\x08protocol\x18\x04 \x01(\tB\x15\xfa\x42\x12r\x10R\x04sctpR\x03tcpR\x03udpH\x03R\x08protocol\x88\x01\x01\x12\x14\n\x05ports\x18\x05 \x03(\x03R\x05ports\x12%\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x08 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12H\n\rcustom_fields\x18\t \x03(\x0b\x32#.diode.v1.Service.CustomFieldsEntryR\x0c\x63ustomFields\x12\x35\n\x0bipaddresses\x18\n \x03(\x0b\x32\x13.diode.v1.IPAddressR\x0bipaddresses\x12\x44\n\x14parent_object_device\x18\x0b \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x12parentObjectDevice\x12N\n\x18parent_object_fhrp_group\x18\x0c \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x15parentObjectFhrpGroup\x12]\n\x1dparent_object_virtual_machine\x18\r \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x1aparentObjectVirtualMachine\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0f\n\rparent_objectB\t\n\x07_deviceB\x12\n\x10_virtual_machineB\x0b\n\t_protocolB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xd5\x07\n\x04Site\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12V\n\x06status\x18\x03 \x01(\tB9\xfa\x42\x36r4R\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x07plannedR\x07retiredR\x07stagingH\x00R\x06status\x88\x01\x01\x12-\n\x06region\x18\x04 \x01(\x0b\x32\x10.diode.v1.RegionH\x01R\x06region\x88\x01\x01\x12.\n\x05group\x18\x05 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x02R\x05group\x88\x01\x01\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x03R\x06tenant\x88\x01\x01\x12\x1f\n\x08\x66\x61\x63ility\x18\x07 \x01(\tH\x04R\x08\x66\x61\x63ility\x88\x01\x01\x12 \n\ttime_zone\x18\x08 \x01(\tH\x05R\x08timeZone\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\t \x01(\tH\x06R\x0b\x64\x65scription\x88\x01\x01\x12.\n\x10physical_address\x18\n \x01(\tH\x07R\x0fphysicalAddress\x88\x01\x01\x12.\n\x10shipping_address\x18\x0b \x01(\tH\x08R\x0fshippingAddress\x88\x01\x01\x12\x1f\n\x08latitude\x18\x0c \x01(\x01H\tR\x08latitude\x88\x01\x01\x12!\n\tlongitude\x18\r \x01(\x01H\nR\tlongitude\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0e \x01(\tH\x0bR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x45\n\rcustom_fields\x18\x10 \x03(\x0b\x32 .diode.v1.Site.CustomFieldsEntryR\x0c\x63ustomFields\x12!\n\x04\x61sns\x18\x11 \x03(\x0b\x32\r.diode.v1.ASNR\x04\x61sns\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_statusB\t\n\x07_regionB\x08\n\x06_groupB\t\n\x07_tenantB\x0b\n\t_facilityB\x0c\n\n_time_zoneB\x0e\n\x0c_descriptionB\x13\n\x11_physical_addressB\x13\n\x11_shipping_addressB\x0b\n\t_latitudeB\x0c\n\n_longitudeB\x0b\n\t_comments\"\xa1\x03\n\tSiteGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x30\n\x06parent\x18\x03 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x06parent\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\x06 \x03(\x0b\x32%.diode.v1.SiteGroup.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xd6\x0e\n\x03Tag\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1b\n\x06weight\x18\x05 \x01(\x03H\x02R\x06weight\x88\x01\x01\x12\xa2\r\n\x0cobject_types\x18\x06 \x03(\tB\xfe\x0c\xfa\x42\xfa\x0c\x92\x01\xf6\x0c\"\xf3\x0cr\xf0\x0cR\x10\x63ircuits.circuitR\x15\x63ircuits.circuitgroupR\x1f\x63ircuits.circuitgroupassignmentR\x1b\x63ircuits.circuitterminationR\x14\x63ircuits.circuittypeR\x11\x63ircuits.providerR\x18\x63ircuits.provideraccountR\x18\x63ircuits.providernetworkR\x17\x63ircuits.virtualcircuitR\"circuits.virtualcircuitterminationR\x1b\x63ircuits.virtualcircuittypeR\ndcim.cableR\x10\x64\x63im.consoleportR\x16\x64\x63im.consoleserverportR\x0b\x64\x63im.deviceR\x0e\x64\x63im.devicebayR\x0f\x64\x63im.deviceroleR\x0f\x64\x63im.devicetypeR\x0e\x64\x63im.frontportR\x0e\x64\x63im.interfaceR\x12\x64\x63im.inventoryitemR\x16\x64\x63im.inventoryitemroleR\rdcim.locationR\x0f\x64\x63im.macaddressR\x11\x64\x63im.manufacturerR\x0b\x64\x63im.moduleR\x0e\x64\x63im.modulebayR\x0f\x64\x63im.moduletypeR\x16\x64\x63im.moduletypeprofileR\rdcim.platformR\x0e\x64\x63im.powerfeedR\x10\x64\x63im.poweroutletR\x0f\x64\x63im.powerpanelR\x0e\x64\x63im.powerportR\tdcim.rackR\x14\x64\x63im.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\x0b\x64\x63im.regionR\tdcim.siteR\x0e\x64\x63im.sitegroupR\x13\x64\x63im.virtualchassisR\x19\x64\x63im.virtualdevicecontextR\x13\x65xtras.journalentryR\x0eipam.aggregateR\x08ipam.asnR\ripam.asnrangeR\x0eipam.fhrpgroupR\x0eipam.ipaddressR\x0cipam.iprangeR\x0bipam.prefixR\x08ipam.rirR\tipam.roleR\x10ipam.routetargetR\x0cipam.serviceR\tipam.vlanR\x0eipam.vlangroupR\x1aipam.vlantranslationpolicyR\x18ipam.vlantranslationruleR\x08ipam.vrfR\x0ftenancy.contactR\x19tenancy.contactassignmentR\x14tenancy.contactgroupR\x13tenancy.contactroleR\x0etenancy.tenantR\x13tenancy.tenantgroupR\x16virtualization.clusterR\x1bvirtualization.clustergroupR\x1avirtualization.clustertypeR\x1avirtualization.virtualdiskR\x1dvirtualization.virtualmachineR\x1avirtualization.vminterfaceR\rvpn.ikepolicyR\x0fvpn.ikeproposalR\x0fvpn.ipsecpolicyR\x10vpn.ipsecprofileR\x11vpn.ipsecproposalR\tvpn.l2vpnR\x14vpn.l2vpnterminationR\nvpn.tunnelR\x0fvpn.tunnelgroupR\x15vpn.tunnelterminationR\x14wireless.wirelesslanR\x19wireless.wirelesslangroupR\x15wireless.wirelesslinkR\x0bobjectTypesB\x08\n\x06_colorB\x0e\n\x0c_descriptionB\t\n\x07_weight\"\x9a\x03\n\x06Tenant\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x30\n\x05group\x18\x03 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x05group\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\x07 \x03(\x0b\x32\".diode.v1.Tenant.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_groupB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xa7\x03\n\x0bTenantGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x32\n\x06parent\x18\x03 \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x06parent\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x06 \x03(\x0b\x32\'.diode.v1.TenantGroup.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xf6\x05\n\x06Tunnel\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x38\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x08\x64isabledR\x07plannedR\x06status\x12\x30\n\x05group\x18\x03 \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x05group\x88\x01\x01\x12v\n\rencapsulation\x18\x04 \x01(\tBP\xfa\x42MrKR\x03greR\x05ip-ipR\x0fipsec-transportR\x0cipsec-tunnelR\x04l2tpR\x07openvpnR\x04pptpR\twireguardR\rencapsulation\x12@\n\ripsec_profile\x18\x05 \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x01R\x0cipsecProfile\x88\x01\x01\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12 \n\ttunnel_id\x18\x07 \x01(\x03H\x03R\x08tunnelId\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\t \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\n \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12G\n\rcustom_fields\x18\x0b \x03(\x0b\x32\".diode.v1.Tunnel.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_groupB\x10\n\x0e_ipsec_profileB\t\n\x07_tenantB\x0c\n\n_tunnel_idB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xba\x02\n\x0bTunnelGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x04 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x05 \x03(\x0b\x32\'.diode.v1.TunnelGroup.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\x85?\n\x11TunnelTermination\x12(\n\x06tunnel\x18\x01 \x01(\x0b\x32\x10.diode.v1.TunnelR\x06tunnel\x12+\n\x04role\x18\x02 \x01(\tB\x17\xfa\x42\x14r\x12R\x03hubR\x04peerR\x05spokeR\x04role\x12\x38\n\x0ftermination_asn\x18\x03 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x0eterminationAsn\x12H\n\x15termination_asn_range\x18\x04 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x13terminationAsnRange\x12J\n\x15termination_aggregate\x18\x05 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x14terminationAggregate\x12>\n\x11termination_cable\x18\x06 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x10terminationCable\x12K\n\x16termination_cable_path\x18\x07 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x14terminationCablePath\x12`\n\x1dtermination_cable_termination\x18\x08 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x1bterminationCableTermination\x12\x44\n\x13termination_circuit\x18\t \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x12terminationCircuit\x12T\n\x19termination_circuit_group\x18\n \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x17terminationCircuitGroup\x12s\n$termination_circuit_group_assignment\x18\x0b \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R!terminationCircuitGroupAssignment\x12\x66\n\x1ftermination_circuit_termination\x18\x0c \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R\x1dterminationCircuitTermination\x12Q\n\x18termination_circuit_type\x18\r \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x16terminationCircuitType\x12\x44\n\x13termination_cluster\x18\x0e \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x12terminationCluster\x12T\n\x19termination_cluster_group\x18\x0f \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x17terminationClusterGroup\x12Q\n\x18termination_cluster_type\x18\x10 \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x16terminationClusterType\x12Q\n\x18termination_console_port\x18\x11 \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x16terminationConsolePort\x12\x64\n\x1ftermination_console_server_port\x18\x12 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1cterminationConsoleServerPort\x12\x44\n\x13termination_contact\x18\x13 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x12terminationContact\x12\x63\n\x1etermination_contact_assignment\x18\x14 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x1cterminationContactAssignment\x12T\n\x19termination_contact_group\x18\x15 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x17terminationContactGroup\x12Q\n\x18termination_contact_role\x18\x16 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x16terminationContactRole\x12\x41\n\x12termination_device\x18\x17 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x11terminationDevice\x12K\n\x16termination_device_bay\x18\x18 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x14terminationDeviceBay\x12N\n\x17termination_device_role\x18\x19 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x15terminationDeviceRole\x12N\n\x17termination_device_type\x18\x1a \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x15terminationDeviceType\x12K\n\x16termination_fhrp_group\x18\x1b \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x14terminationFhrpGroup\x12j\n!termination_fhrp_group_assignment\x18\x1c \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R\x1eterminationFhrpGroupAssignment\x12K\n\x16termination_front_port\x18\x1d \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x14terminationFrontPort\x12K\n\x16termination_ike_policy\x18\x1e \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x14terminationIkePolicy\x12Q\n\x18termination_ike_proposal\x18\x1f \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x16terminationIkeProposal\x12K\n\x16termination_ip_address\x18  \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x14terminationIpAddress\x12\x45\n\x14termination_ip_range\x18! \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x12terminationIpRange\x12R\n\x19termination_ip_sec_policy\x18\" \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x16terminationIpSecPolicy\x12U\n\x1atermination_ip_sec_profile\x18# \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x17terminationIpSecProfile\x12X\n\x1btermination_ip_sec_proposal\x18$ \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x18terminationIpSecProposal\x12J\n\x15termination_interface\x18% \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x14terminationInterface\x12W\n\x1atermination_inventory_item\x18& \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x18terminationInventoryItem\x12\x64\n\x1ftermination_inventory_item_role\x18\' \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x1cterminationInventoryItemRole\x12>\n\x11termination_l2vpn\x18( \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x10terminationL2vpn\x12`\n\x1dtermination_l2vpn_termination\x18) \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x1bterminationL2vpnTermination\x12G\n\x14termination_location\x18* \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x13terminationLocation\x12N\n\x17termination_mac_address\x18+ \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x15terminationMacAddress\x12S\n\x18termination_manufacturer\x18, \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x17terminationManufacturer\x12\x41\n\x12termination_module\x18- \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x11terminationModule\x12K\n\x16termination_module_bay\x18. \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x14terminationModuleBay\x12N\n\x17termination_module_type\x18/ \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x15terminationModuleType\x12G\n\x14termination_platform\x18\x30 \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x13terminationPlatform\x12K\n\x16termination_power_feed\x18\x31 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x14terminationPowerFeed\x12Q\n\x18termination_power_outlet\x18\x32 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x16terminationPowerOutlet\x12N\n\x17termination_power_panel\x18\x33 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x15terminationPowerPanel\x12K\n\x16termination_power_port\x18\x34 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x14terminationPowerPort\x12\x41\n\x12termination_prefix\x18\x35 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x11terminationPrefix\x12G\n\x14termination_provider\x18\x36 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x13terminationProvider\x12]\n\x1ctermination_provider_account\x18\x37 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x1aterminationProviderAccount\x12]\n\x1ctermination_provider_network\x18\x38 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x1aterminationProviderNetwork\x12\x38\n\x0ftermination_rir\x18\x39 \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x0eterminationRir\x12;\n\x10termination_rack\x18: \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x0fterminationRack\x12]\n\x1ctermination_rack_reservation\x18; \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x1aterminationRackReservation\x12H\n\x15termination_rack_role\x18< \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x13terminationRackRole\x12H\n\x15termination_rack_type\x18= \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x13terminationRackType\x12H\n\x15termination_rear_port\x18> \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x13terminationRearPort\x12\x41\n\x12termination_region\x18? \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x11terminationRegion\x12;\n\x10termination_role\x18@ \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\x0fterminationRole\x12Q\n\x18termination_route_target\x18\x41 \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x16terminationRouteTarget\x12\x44\n\x13termination_service\x18\x42 \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x12terminationService\x12;\n\x10termination_site\x18\x43 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x0fterminationSite\x12K\n\x16termination_site_group\x18\x44 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x14terminationSiteGroup\x12\x38\n\x0ftermination_tag\x18\x45 \x01(\x0b\x32\r.diode.v1.TagH\x00R\x0eterminationTag\x12\x41\n\x12termination_tenant\x18\x46 \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x11terminationTenant\x12Q\n\x18termination_tenant_group\x18G \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x16terminationTenantGroup\x12\x41\n\x12termination_tunnel\x18H \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x11terminationTunnel\x12Q\n\x18termination_tunnel_group\x18I \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x16terminationTunnelGroup\x12\x63\n\x1etermination_tunnel_termination\x18J \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x1cterminationTunnelTermination\x12;\n\x10termination_vlan\x18K \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\x0fterminationVlan\x12K\n\x16termination_vlan_group\x18L \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x14terminationVlanGroup\x12p\n#termination_vlan_translation_policy\x18M \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R terminationVlanTranslationPolicy\x12j\n!termination_vlan_translation_rule\x18N \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R\x1eterminationVlanTranslationRule\x12Q\n\x18termination_vm_interface\x18O \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x16terminationVmInterface\x12\x38\n\x0ftermination_vrf\x18P \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x0eterminationVrf\x12Z\n\x1btermination_virtual_chassis\x18Q \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x19terminationVirtualChassis\x12Z\n\x1btermination_virtual_circuit\x18R \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x19terminationVirtualCircuit\x12|\n\'termination_virtual_circuit_termination\x18S \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R$terminationVirtualCircuitTermination\x12g\n termination_virtual_circuit_type\x18T \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R\x1dterminationVirtualCircuitType\x12m\n\"termination_virtual_device_context\x18U \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\x1fterminationVirtualDeviceContext\x12Q\n\x18termination_virtual_disk\x18V \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x16terminationVirtualDisk\x12Z\n\x1btermination_virtual_machine\x18W \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x19terminationVirtualMachine\x12Q\n\x18termination_wireless_lan\x18X \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x16terminationWirelessLan\x12\x61\n\x1etermination_wireless_lan_group\x18Y \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x1bterminationWirelessLanGroup\x12T\n\x19termination_wireless_link\x18Z \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x17terminationWirelessLink\x12Q\n\x18termination_custom_field\x18^ \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x16terminationCustomField\x12n\n#termination_custom_field_choice_set\x18_ \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\x1fterminationCustomFieldChoiceSet\x12T\n\x19termination_journal_entry\x18` \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x17terminationJournalEntry\x12\x64\n\x1ftermination_module_type_profile\x18\x61 \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x1cterminationModuleTypeProfile\x12N\n\x17termination_custom_link\x18\x62 \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x15terminationCustomLink\x12\x37\n\noutside_ip\x18[ \x01(\x0b\x32\x13.diode.v1.IPAddressH\x01R\toutsideIp\x88\x01\x01\x12!\n\x04tags\x18\\ \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12R\n\rcustom_fields\x18] \x03(\x0b\x32-.diode.v1.TunnelTermination.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0bterminationB\r\n\x0b_outside_ip\"\x85\x06\n\x04VLAN\x12\'\n\x04site\x18\x01 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x04site\x88\x01\x01\x12.\n\x05group\x18\x02 \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x01R\x05group\x88\x01\x01\x12\x10\n\x03vid\x18\x03 \x01(\x03R\x03vid\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12-\n\x06tenant\x18\x05 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12@\n\x06status\x18\x06 \x01(\tB#\xfa\x42 r\x1eR\x06\x61\x63tiveR\ndeprecatedR\x08reservedH\x03R\x06status\x88\x01\x01\x12\'\n\x04role\x18\x07 \x01(\x0b\x32\x0e.diode.v1.RoleH\x04R\x04role\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12\x35\n\tqinq_role\x18\t \x01(\tB\x13\xfa\x42\x10r\x0eR\x05\x63vlanR\x05svlanH\x06R\x08qinqRole\x88\x01\x01\x12\x32\n\nqinq_svlan\x18\n \x01(\x0b\x32\x0e.diode.v1.VLANH\x07R\tqinqSvlan\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0b \x01(\tH\x08R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0c \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x45\n\rcustom_fields\x18\r \x03(\x0b\x32 .diode.v1.VLAN.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_siteB\x08\n\x06_groupB\t\n\x07_tenantB\t\n\x07_statusB\x07\n\x05_roleB\x0e\n\x0c_descriptionB\x0c\n\n_qinq_roleB\r\n\x0b_qinq_svlanB\x0b\n\t_comments\"\xb3\x06\n\tVLANGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x38\n\rscope_cluster\x18\x03 \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x0cscopeCluster\x12H\n\x13scope_cluster_group\x18\x04 \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x11scopeClusterGroup\x12;\n\x0escope_location\x18\x05 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\rscopeLocation\x12/\n\nscope_rack\x18\x06 \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\tscopeRack\x12\x35\n\x0cscope_region\x18\x07 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0bscopeRegion\x12/\n\nscope_site\x18\x08 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\tscopeSite\x12?\n\x10scope_site_group\x18\t \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0escopeSiteGroup\x12\x1d\n\nvid_ranges\x18\n \x03(\x03R\tvidRanges\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x0c \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12J\n\rcustom_fields\x18\r \x03(\x0b\x32%.diode.v1.VLANGroup.CustomFieldsEntryR\x0c\x63ustomFields\x12-\n\x06tenant\x18\x0e \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05scopeB\x0e\n\x0c_descriptionB\t\n\x07_tenant\"b\n\x15VLANTranslationPolicy\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_description\"\xc1\x01\n\x13VLANTranslationRule\x12\x37\n\x06policy\x18\x01 \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyR\x06policy\x12\x1b\n\tlocal_vid\x18\x02 \x01(\x03R\x08localVid\x12\x1d\n\nremote_vid\x18\x03 \x01(\x03R\tremoteVid\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_description\"\xcb\x08\n\x0bVMInterface\x12\x41\n\x0fvirtual_machine\x18\x01 \x01(\x0b\x32\x18.diode.v1.VirtualMachineR\x0evirtualMachine\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\x07\x65nabled\x18\x03 \x01(\x08H\x00R\x07\x65nabled\x88\x01\x01\x12\x32\n\x06parent\x18\x04 \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x01R\x06parent\x88\x01\x01\x12\x32\n\x06\x62ridge\x18\x05 \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x02R\x06\x62ridge\x88\x01\x01\x12\x15\n\x03mtu\x18\x06 \x01(\x03H\x03R\x03mtu\x88\x01\x01\x12I\n\x13primary_mac_address\x18\x07 \x01(\x0b\x32\x14.diode.v1.MACAddressH\x04R\x11primaryMacAddress\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x05R\x0b\x64\x65scription\x88\x01\x01\x12\x42\n\x04mode\x18\t \x01(\tB)\xfa\x42&r$R\x06\x61\x63\x63\x65ssR\x06q-in-qR\x06taggedR\ntagged-allH\x06R\x04mode\x88\x01\x01\x12\x38\n\runtagged_vlan\x18\n \x01(\x0b\x32\x0e.diode.v1.VLANH\x07R\x0cuntaggedVlan\x88\x01\x01\x12\x32\n\nqinq_svlan\x18\x0b \x01(\x0b\x32\x0e.diode.v1.VLANH\x08R\tqinqSvlan\x88\x01\x01\x12\\\n\x17vlan_translation_policy\x18\x0c \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\tR\x15vlanTranslationPolicy\x88\x01\x01\x12$\n\x03vrf\x18\r \x01(\x0b\x32\r.diode.v1.VRFH\nR\x03vrf\x88\x01\x01\x12!\n\x04tags\x18\x0e \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x0f \x03(\x0b\x32\'.diode.v1.VMInterface.CustomFieldsEntryR\x0c\x63ustomFields\x12\x31\n\x0ctagged_vlans\x18\x10 \x03(\x0b\x32\x0e.diode.v1.VLANR\x0btaggedVlans\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\n\n\x08_enabledB\t\n\x07_parentB\t\n\x07_bridgeB\x06\n\x04_mtuB\x16\n\x14_primary_mac_addressB\x0e\n\x0c_descriptionB\x07\n\x05_modeB\x10\n\x0e_untagged_vlanB\r\n\x0b_qinq_svlanB\x1a\n\x18_vlan_translation_policyB\x06\n\x04_vrf\"\xd5\x04\n\x03VRF\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x13\n\x02rd\x18\x02 \x01(\tH\x00R\x02rd\x88\x01\x01\x12-\n\x06tenant\x18\x03 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12*\n\x0e\x65nforce_unique\x18\x04 \x01(\x08H\x02R\renforceUnique\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x03R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x06 \x01(\tH\x04R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12\x44\n\rcustom_fields\x18\x08 \x03(\x0b\x32\x1f.diode.v1.VRF.CustomFieldsEntryR\x0c\x63ustomFields\x12<\n\x0eimport_targets\x18\t \x03(\x0b\x32\x15.diode.v1.RouteTargetR\rimportTargets\x12<\n\x0e\x65xport_targets\x18\n \x03(\x0b\x32\x15.diode.v1.RouteTargetR\rexportTargets\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x05\n\x03_rdB\t\n\x07_tenantB\x11\n\x0f_enforce_uniqueB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xbc\x03\n\x0eVirtualChassis\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1b\n\x06\x64omain\x18\x02 \x01(\tH\x00R\x06\x64omain\x88\x01\x01\x12-\n\x06master\x18\x03 \x01(\x0b\x32\x10.diode.v1.DeviceH\x01R\x06master\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x02R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x05 \x01(\tH\x03R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x06 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12O\n\rcustom_fields\x18\x07 \x03(\x0b\x32*.diode.v1.VirtualChassis.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_domainB\t\n\x07_masterB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xe1\x05\n\x0eVirtualCircuit\x12\x10\n\x03\x63id\x18\x01 \x01(\tR\x03\x63id\x12\x44\n\x10provider_network\x18\x02 \x01(\x0b\x32\x19.diode.v1.ProviderNetworkR\x0fproviderNetwork\x12I\n\x10provider_account\x18\x03 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x0fproviderAccount\x88\x01\x01\x12\x30\n\x04type\x18\x04 \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeR\x04type\x12j\n\x06status\x18\x05 \x01(\tBM\xfa\x42JrHR\x06\x61\x63tiveR\x0e\x64\x65\x63ommissionedR\x0e\x64\x65provisioningR\x07offlineR\x07plannedR\x0cprovisioningH\x01R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x06 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x03R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x08 \x01(\tH\x04R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\t \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12O\n\rcustom_fields\x18\n \x03(\x0b\x32*.diode.v1.VirtualCircuit.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x13\n\x11_provider_accountB\t\n\x07_statusB\t\n\x07_tenantB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xdf\x03\n\x19VirtualCircuitTermination\x12\x41\n\x0fvirtual_circuit\x18\x01 \x01(\x0b\x32\x18.diode.v1.VirtualCircuitR\x0evirtualCircuit\x12\x30\n\x04role\x18\x02 \x01(\tB\x17\xfa\x42\x14r\x12R\x03hubR\x04peerR\x05spokeH\x00R\x04role\x88\x01\x01\x12\x31\n\tinterface\x18\x03 \x01(\x0b\x32\x13.diode.v1.InterfaceR\tinterface\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12Z\n\rcustom_fields\x18\x06 \x03(\x0b\x32\x35.diode.v1.VirtualCircuitTermination.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_roleB\x0e\n\x0c_description\"\xed\x02\n\x12VirtualCircuitType\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x19\n\x05\x63olor\x18\x03 \x01(\tH\x00R\x05\x63olor\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12S\n\rcustom_fields\x18\x06 \x03(\x0b\x32..diode.v1.VirtualCircuitType.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x08\n\x06_colorB\x0e\n\x0c_description\"\xcd\x05\n\x14VirtualDeviceContext\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12(\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x10.diode.v1.DeviceR\x06\x64\x65vice\x12#\n\nidentifier\x18\x03 \x01(\x03H\x00R\nidentifier\x88\x01\x01\x12-\n\x06tenant\x18\x04 \x01(\x0b\x32\x10.diode.v1.TenantH\x01R\x06tenant\x88\x01\x01\x12\x39\n\x0bprimary_ip4\x18\x05 \x01(\x0b\x32\x13.diode.v1.IPAddressH\x02R\nprimaryIp4\x88\x01\x01\x12\x39\n\x0bprimary_ip6\x18\x06 \x01(\x0b\x32\x13.diode.v1.IPAddressH\x03R\nprimaryIp6\x88\x01\x01\x12\x37\n\x06status\x18\x07 \x01(\tB\x1f\xfa\x42\x1cr\x1aR\x06\x61\x63tiveR\x07offlineR\x07plannedR\x06status\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tH\x04R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\t \x01(\tH\x05R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\n \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12U\n\rcustom_fields\x18\x0b \x03(\x0b\x32\x30.diode.v1.VirtualDeviceContext.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\r\n\x0b_identifierB\t\n\x07_tenantB\x0e\n\x0c_primary_ip4B\x0e\n\x0c_primary_ip6B\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xfd\x02\n\x0bVirtualDisk\x12\x41\n\x0fvirtual_machine\x18\x01 \x01(\x0b\x32\x18.diode.v1.VirtualMachineR\x0evirtualMachine\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x12\n\x04size\x18\x04 \x01(\x03R\x04size\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x06 \x03(\x0b\x32\'.diode.v1.VirtualDisk.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\xd7\x08\n\x0eVirtualMachine\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x65\n\x06status\x18\x02 \x01(\tBH\xfa\x42\x45rCR\x06\x61\x63tiveR\x0f\x64\x65\x63ommissioningR\x06\x66\x61iledR\x07offlineR\x06pausedR\x07plannedR\x06stagedH\x00R\x06status\x88\x01\x01\x12\'\n\x04site\x18\x03 \x01(\x0b\x32\x0e.diode.v1.SiteH\x01R\x04site\x88\x01\x01\x12\x30\n\x07\x63luster\x18\x04 \x01(\x0b\x32\x11.diode.v1.ClusterH\x02R\x07\x63luster\x88\x01\x01\x12-\n\x06\x64\x65vice\x18\x05 \x01(\x0b\x32\x10.diode.v1.DeviceH\x03R\x06\x64\x65vice\x88\x01\x01\x12\x1b\n\x06serial\x18\x06 \x01(\tH\x04R\x06serial\x88\x01\x01\x12-\n\x04role\x18\x07 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x05R\x04role\x88\x01\x01\x12-\n\x06tenant\x18\x08 \x01(\x0b\x32\x10.diode.v1.TenantH\x06R\x06tenant\x88\x01\x01\x12\x33\n\x08platform\x18\t \x01(\x0b\x32\x12.diode.v1.PlatformH\x07R\x08platform\x88\x01\x01\x12\x39\n\x0bprimary_ip4\x18\n \x01(\x0b\x32\x13.diode.v1.IPAddressH\x08R\nprimaryIp4\x88\x01\x01\x12\x39\n\x0bprimary_ip6\x18\x0b \x01(\x0b\x32\x13.diode.v1.IPAddressH\tR\nprimaryIp6\x88\x01\x01\x12\x19\n\x05vcpus\x18\x0c \x01(\x01H\nR\x05vcpus\x88\x01\x01\x12\x1b\n\x06memory\x18\r \x01(\x03H\x0bR\x06memory\x88\x01\x01\x12\x17\n\x04\x64isk\x18\x0e \x01(\x03H\x0cR\x04\x64isk\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0f \x01(\tH\rR\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x10 \x01(\tH\x0eR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x11 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12O\n\rcustom_fields\x18\x12 \x03(\x0b\x32*.diode.v1.VirtualMachine.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_statusB\x07\n\x05_siteB\n\n\x08_clusterB\t\n\x07_deviceB\t\n\x07_serialB\x07\n\x05_roleB\t\n\x07_tenantB\x0b\n\t_platformB\x0e\n\x0c_primary_ip4B\x0e\n\x0c_primary_ip6B\x08\n\x06_vcpusB\t\n\x07_memoryB\x07\n\x05_diskB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xa2\x08\n\x0bWirelessLAN\x12\x12\n\x04ssid\x18\x01 \x01(\tR\x04ssid\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x35\n\x05group\x18\x03 \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x02R\x05group\x88\x01\x01\x12J\n\x06status\x18\x04 \x01(\tB-\xfa\x42*r(R\x06\x61\x63tiveR\ndeprecatedR\x08\x64isabledR\x08reservedH\x03R\x06status\x88\x01\x01\x12\'\n\x04vlan\x18\x05 \x01(\x0b\x32\x0e.diode.v1.VLANH\x04R\x04vlan\x88\x01\x01\x12;\n\x0escope_location\x18\x06 \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\rscopeLocation\x12\x35\n\x0cscope_region\x18\x07 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x0bscopeRegion\x12/\n\nscope_site\x18\x08 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\tscopeSite\x12?\n\x10scope_site_group\x18\t \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x0escopeSiteGroup\x12-\n\x06tenant\x18\n \x01(\x0b\x32\x10.diode.v1.TenantH\x05R\x06tenant\x88\x01\x01\x12P\n\tauth_type\x18\x0b \x01(\tB.\xfa\x42+r)R\x04openR\x03wepR\x0ewpa-enterpriseR\x0cwpa-personalH\x06R\x08\x61uthType\x88\x01\x01\x12<\n\x0b\x61uth_cipher\x18\x0c \x01(\tB\x16\xfa\x42\x13r\x11R\x03\x61\x65sR\x04\x61utoR\x04tkipH\x07R\nauthCipher\x88\x01\x01\x12\x1e\n\x08\x61uth_psk\x18\r \x01(\tH\x08R\x07\x61uthPsk\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0e \x01(\tH\tR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x0f \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12L\n\rcustom_fields\x18\x10 \x03(\x0b\x32\'.diode.v1.WirelessLAN.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05scopeB\x0e\n\x0c_descriptionB\x08\n\x06_groupB\t\n\x07_statusB\x07\n\x05_vlanB\t\n\x07_tenantB\x0c\n\n_auth_typeB\x0e\n\x0c_auth_cipherB\x0b\n\t_auth_pskB\x0b\n\t_comments\"\xb6\x03\n\x10WirelessLANGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x37\n\x06parent\x18\x03 \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x06parent\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12Q\n\rcustom_fields\x18\x06 \x03(\x0b\x32,.diode.v1.WirelessLANGroup.CustomFieldsEntryR\x0c\x63ustomFields\x12\x1f\n\x08\x63omments\x18\x07 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\t\n\x07_parentB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xb9\x07\n\x0cWirelessLink\x12\x34\n\x0binterface_a\x18\x01 \x01(\x0b\x32\x13.diode.v1.InterfaceR\ninterfaceA\x12\x34\n\x0binterface_b\x18\x02 \x01(\x0b\x32\x13.diode.v1.InterfaceR\ninterfaceB\x12\x17\n\x04ssid\x18\x03 \x01(\tH\x00R\x04ssid\x88\x01\x01\x12G\n\x06status\x18\x04 \x01(\tB*\xfa\x42\'r%R\tconnectedR\x0f\x64\x65\x63ommissioningR\x07plannedH\x01R\x06status\x88\x01\x01\x12-\n\x06tenant\x18\x05 \x01(\x0b\x32\x10.diode.v1.TenantH\x02R\x06tenant\x88\x01\x01\x12P\n\tauth_type\x18\x06 \x01(\tB.\xfa\x42+r)R\x04openR\x03wepR\x0ewpa-enterpriseR\x0cwpa-personalH\x03R\x08\x61uthType\x88\x01\x01\x12<\n\x0b\x61uth_cipher\x18\x07 \x01(\tB\x16\xfa\x42\x13r\x11R\x03\x61\x65sR\x04\x61utoR\x04tkipH\x04R\nauthCipher\x88\x01\x01\x12\x1e\n\x08\x61uth_psk\x18\x08 \x01(\tH\x05R\x07\x61uthPsk\x88\x01\x01\x12\x1f\n\x08\x64istance\x18\t \x01(\x01H\x06R\x08\x64istance\x88\x01\x01\x12>\n\rdistance_unit\x18\n \x01(\tB\x14\xfa\x42\x11r\x0fR\x02\x66tR\x02kmR\x01mR\x02miH\x07R\x0c\x64istanceUnit\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x08R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x0c \x01(\tH\tR\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\r \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18\x0e \x03(\x0b\x32(.diode.v1.WirelessLink.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x07\n\x05_ssidB\t\n\x07_statusB\t\n\x07_tenantB\x0c\n\n_auth_typeB\x0e\n\x0c_auth_cipherB\x0b\n\t_auth_pskB\x0b\n\t_distanceB\x10\n\x0e_distance_unitB\x0e\n\x0c_descriptionB\x0b\n\t_comments\"\xff%\n\x0b\x43ustomField\x12\x89\x01\n\x04type\x18\x01 \x01(\tBu\xfa\x42rrpR\x07\x62ooleanR\x04\x64\x61teR\x08\x64\x61tetimeR\x07\x64\x65\x63imalR\x07integerR\x04jsonR\x08longtextR\x0bmultiobjectR\x0bmultiselectR\x06objectR\x06selectR\x04textR\x03urlR\x04type\x12\xbe\x0e\n\x13related_object_type\x18\x02 \x01(\tB\x88\x0e\xfa\x42\x84\x0er\x81\x0eR\x10\x63ircuits.circuitR\x15\x63ircuits.circuitgroupR\x1f\x63ircuits.circuitgroupassignmentR\x1b\x63ircuits.circuitterminationR\x14\x63ircuits.circuittypeR\x11\x63ircuits.providerR\x18\x63ircuits.provideraccountR\x18\x63ircuits.providernetworkR\x17\x63ircuits.virtualcircuitR\"circuits.virtualcircuitterminationR\x1b\x63ircuits.virtualcircuittypeR\ndcim.cableR\x0e\x64\x63im.cablepathR\x15\x64\x63im.cableterminationR\x10\x64\x63im.consoleportR\x16\x64\x63im.consoleserverportR\x0b\x64\x63im.deviceR\x0e\x64\x63im.devicebayR\x0f\x64\x63im.deviceroleR\x0f\x64\x63im.devicetypeR\x0e\x64\x63im.frontportR\x0e\x64\x63im.interfaceR\x12\x64\x63im.inventoryitemR\x16\x64\x63im.inventoryitemroleR\rdcim.locationR\x0f\x64\x63im.macaddressR\x11\x64\x63im.manufacturerR\x0b\x64\x63im.moduleR\x0e\x64\x63im.modulebayR\x0f\x64\x63im.moduletypeR\x16\x64\x63im.moduletypeprofileR\rdcim.platformR\x0e\x64\x63im.powerfeedR\x10\x64\x63im.poweroutletR\x0f\x64\x63im.powerpanelR\x0e\x64\x63im.powerportR\tdcim.rackR\x14\x64\x63im.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\x0b\x64\x63im.regionR\tdcim.siteR\x0e\x64\x63im.sitegroupR\x13\x64\x63im.virtualchassisR\x19\x64\x63im.virtualdevicecontextR\x12\x65xtras.customfieldR\x1b\x65xtras.customfieldchoicesetR\x11\x65xtras.customlinkR\x13\x65xtras.journalentryR\nextras.tagR\x0eipam.aggregateR\x08ipam.asnR\ripam.asnrangeR\x0eipam.fhrpgroupR\x18ipam.fhrpgroupassignmentR\x0eipam.ipaddressR\x0cipam.iprangeR\x0bipam.prefixR\x08ipam.rirR\tipam.roleR\x10ipam.routetargetR\x0cipam.serviceR\tipam.vlanR\x0eipam.vlangroupR\x1aipam.vlantranslationpolicyR\x18ipam.vlantranslationruleR\x08ipam.vrfR\x0ftenancy.contactR\x19tenancy.contactassignmentR\x14tenancy.contactgroupR\x13tenancy.contactroleR\x0etenancy.tenantR\x13tenancy.tenantgroupR\x16virtualization.clusterR\x1bvirtualization.clustergroupR\x1avirtualization.clustertypeR\x1avirtualization.virtualdiskR\x1dvirtualization.virtualmachineR\x1avirtualization.vminterfaceR\rvpn.ikepolicyR\x0fvpn.ikeproposalR\x0fvpn.ipsecpolicyR\x10vpn.ipsecprofileR\x11vpn.ipsecproposalR\tvpn.l2vpnR\x14vpn.l2vpnterminationR\nvpn.tunnelR\x0fvpn.tunnelgroupR\x15vpn.tunnelterminationR\x14wireless.wirelesslanR\x19wireless.wirelesslangroupR\x15wireless.wirelesslinkH\x00R\x11relatedObjectType\x88\x01\x01\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x19\n\x05label\x18\x04 \x01(\tH\x01R\x05label\x88\x01\x01\x12\"\n\ngroup_name\x18\x05 \x01(\tH\x02R\tgroupName\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x03R\x0b\x64\x65scription\x88\x01\x01\x12\x1f\n\x08required\x18\x07 \x01(\x08H\x04R\x08required\x88\x01\x01\x12\x1b\n\x06unique\x18\x08 \x01(\x08H\x05R\x06unique\x88\x01\x01\x12(\n\rsearch_weight\x18\t \x01(\x03H\x06R\x0csearchWeight\x88\x01\x01\x12\x45\n\x0c\x66ilter_logic\x18\n \x01(\tB\x1d\xfa\x42\x1ar\x18R\x08\x64isabledR\x05\x65xactR\x05looseH\x07R\x0b\x66ilterLogic\x88\x01\x01\x12\x41\n\nui_visible\x18\x0b \x01(\tB\x1d\xfa\x42\x1ar\x18R\x06\x61lwaysR\x06hiddenR\x06if-setH\x08R\tuiVisible\x88\x01\x01\x12<\n\x0bui_editable\x18\x0c \x01(\tB\x16\xfa\x42\x13r\x11R\x06hiddenR\x02noR\x03yesH\tR\nuiEditable\x88\x01\x01\x12&\n\x0cis_cloneable\x18\r \x01(\x08H\nR\x0bisCloneable\x88\x01\x01\x12\x1d\n\x07\x64\x65\x66\x61ult\x18\x0e \x01(\tH\x0bR\x07\x64\x65\x66\x61ult\x88\x01\x01\x12\x37\n\x15related_object_filter\x18\x0f \x01(\tH\x0cR\x13relatedObjectFilter\x88\x01\x01\x12\x1b\n\x06weight\x18\x10 \x01(\x03H\rR\x06weight\x88\x01\x01\x12\x32\n\x12validation_minimum\x18\x11 \x01(\x03H\x0eR\x11validationMinimum\x88\x01\x01\x12\x32\n\x12validation_maximum\x18\x12 \x01(\x03H\x0fR\x11validationMaximum\x88\x01\x01\x12.\n\x10validation_regex\x18\x13 \x01(\tH\x10R\x0fvalidationRegex\x88\x01\x01\x12\x42\n\nchoice_set\x18\x14 \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x11R\tchoiceSet\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x15 \x01(\tH\x12R\x08\x63omments\x88\x01\x01\x12\xa2\r\n\x0cobject_types\x18\x16 \x03(\tB\xfe\x0c\xfa\x42\xfa\x0c\x92\x01\xf6\x0c\"\xf3\x0cr\xf0\x0cR\x10\x63ircuits.circuitR\x15\x63ircuits.circuitgroupR\x1f\x63ircuits.circuitgroupassignmentR\x1b\x63ircuits.circuitterminationR\x14\x63ircuits.circuittypeR\x11\x63ircuits.providerR\x18\x63ircuits.provideraccountR\x18\x63ircuits.providernetworkR\x17\x63ircuits.virtualcircuitR\"circuits.virtualcircuitterminationR\x1b\x63ircuits.virtualcircuittypeR\ndcim.cableR\x10\x64\x63im.consoleportR\x16\x64\x63im.consoleserverportR\x0b\x64\x63im.deviceR\x0e\x64\x63im.devicebayR\x0f\x64\x63im.deviceroleR\x0f\x64\x63im.devicetypeR\x0e\x64\x63im.frontportR\x0e\x64\x63im.interfaceR\x12\x64\x63im.inventoryitemR\x16\x64\x63im.inventoryitemroleR\rdcim.locationR\x0f\x64\x63im.macaddressR\x11\x64\x63im.manufacturerR\x0b\x64\x63im.moduleR\x0e\x64\x63im.modulebayR\x0f\x64\x63im.moduletypeR\x16\x64\x63im.moduletypeprofileR\rdcim.platformR\x0e\x64\x63im.powerfeedR\x10\x64\x63im.poweroutletR\x0f\x64\x63im.powerpanelR\x0e\x64\x63im.powerportR\tdcim.rackR\x14\x64\x63im.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\x0b\x64\x63im.regionR\tdcim.siteR\x0e\x64\x63im.sitegroupR\x13\x64\x63im.virtualchassisR\x19\x64\x63im.virtualdevicecontextR\x13\x65xtras.journalentryR\x0eipam.aggregateR\x08ipam.asnR\ripam.asnrangeR\x0eipam.fhrpgroupR\x0eipam.ipaddressR\x0cipam.iprangeR\x0bipam.prefixR\x08ipam.rirR\tipam.roleR\x10ipam.routetargetR\x0cipam.serviceR\tipam.vlanR\x0eipam.vlangroupR\x1aipam.vlantranslationpolicyR\x18ipam.vlantranslationruleR\x08ipam.vrfR\x0ftenancy.contactR\x19tenancy.contactassignmentR\x14tenancy.contactgroupR\x13tenancy.contactroleR\x0etenancy.tenantR\x13tenancy.tenantgroupR\x16virtualization.clusterR\x1bvirtualization.clustergroupR\x1avirtualization.clustertypeR\x1avirtualization.virtualdiskR\x1dvirtualization.virtualmachineR\x1avirtualization.vminterfaceR\rvpn.ikepolicyR\x0fvpn.ikeproposalR\x0fvpn.ipsecpolicyR\x10vpn.ipsecprofileR\x11vpn.ipsecproposalR\tvpn.l2vpnR\x14vpn.l2vpnterminationR\nvpn.tunnelR\x0fvpn.tunnelgroupR\x15vpn.tunnelterminationR\x14wireless.wirelesslanR\x19wireless.wirelesslangroupR\x15wireless.wirelesslinkR\x0bobjectTypesB\x16\n\x14_related_object_typeB\x08\n\x06_labelB\r\n\x0b_group_nameB\x0e\n\x0c_descriptionB\x0b\n\t_requiredB\t\n\x07_uniqueB\x10\n\x0e_search_weightB\x0f\n\r_filter_logicB\r\n\x0b_ui_visibleB\x0e\n\x0c_ui_editableB\x0f\n\r_is_cloneableB\n\n\x08_defaultB\x18\n\x16_related_object_filterB\t\n\x07_weightB\x15\n\x13_validation_minimumB\x15\n\x13_validation_maximumB\x13\n\x11_validation_regexB\r\n\x0b_choice_setB\x0b\n\t_comments\"\xb2\x02\n\x14\x43ustomFieldChoiceSet\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12H\n\x0c\x62\x61se_choices\x18\x03 \x01(\tB \xfa\x42\x1dr\x1bR\x04IATAR\x08ISO_3166R\tUN_LOCODEH\x01R\x0b\x62\x61seChoices\x88\x01\x01\x12\x36\n\x14order_alphabetically\x18\x04 \x01(\x08H\x02R\x13orderAlphabetically\x88\x01\x01\x12#\n\rextra_choices\x18\x05 \x03(\tR\x0c\x65xtraChoicesB\x0e\n\x0c_descriptionB\x0f\n\r_base_choicesB\x17\n\x15_order_alphabetically\"\xd1\x43\n\x0cJournalEntry\x12?\n\x13\x61ssigned_object_asn\x18\x01 \x01(\x0b\x32\r.diode.v1.ASNH\x00R\x11\x61ssignedObjectAsn\x12O\n\x19\x61ssigned_object_asn_range\x18\x02 \x01(\x0b\x32\x12.diode.v1.ASNRangeH\x00R\x16\x61ssignedObjectAsnRange\x12Q\n\x19\x61ssigned_object_aggregate\x18\x03 \x01(\x0b\x32\x13.diode.v1.AggregateH\x00R\x17\x61ssignedObjectAggregate\x12\x45\n\x15\x61ssigned_object_cable\x18\x04 \x01(\x0b\x32\x0f.diode.v1.CableH\x00R\x13\x61ssignedObjectCable\x12R\n\x1a\x61ssigned_object_cable_path\x18\x05 \x01(\x0b\x32\x13.diode.v1.CablePathH\x00R\x17\x61ssignedObjectCablePath\x12g\n!assigned_object_cable_termination\x18\x06 \x01(\x0b\x32\x1a.diode.v1.CableTerminationH\x00R\x1e\x61ssignedObjectCableTermination\x12K\n\x17\x61ssigned_object_circuit\x18\x07 \x01(\x0b\x32\x11.diode.v1.CircuitH\x00R\x15\x61ssignedObjectCircuit\x12[\n\x1d\x61ssigned_object_circuit_group\x18\x08 \x01(\x0b\x32\x16.diode.v1.CircuitGroupH\x00R\x1a\x61ssignedObjectCircuitGroup\x12z\n(assigned_object_circuit_group_assignment\x18\t \x01(\x0b\x32 .diode.v1.CircuitGroupAssignmentH\x00R$assignedObjectCircuitGroupAssignment\x12m\n#assigned_object_circuit_termination\x18\n \x01(\x0b\x32\x1c.diode.v1.CircuitTerminationH\x00R assignedObjectCircuitTermination\x12X\n\x1c\x61ssigned_object_circuit_type\x18\x0b \x01(\x0b\x32\x15.diode.v1.CircuitTypeH\x00R\x19\x61ssignedObjectCircuitType\x12K\n\x17\x61ssigned_object_cluster\x18\x0c \x01(\x0b\x32\x11.diode.v1.ClusterH\x00R\x15\x61ssignedObjectCluster\x12[\n\x1d\x61ssigned_object_cluster_group\x18\r \x01(\x0b\x32\x16.diode.v1.ClusterGroupH\x00R\x1a\x61ssignedObjectClusterGroup\x12X\n\x1c\x61ssigned_object_cluster_type\x18\x0e \x01(\x0b\x32\x15.diode.v1.ClusterTypeH\x00R\x19\x61ssignedObjectClusterType\x12X\n\x1c\x61ssigned_object_console_port\x18\x0f \x01(\x0b\x32\x15.diode.v1.ConsolePortH\x00R\x19\x61ssignedObjectConsolePort\x12k\n#assigned_object_console_server_port\x18\x10 \x01(\x0b\x32\x1b.diode.v1.ConsoleServerPortH\x00R\x1f\x61ssignedObjectConsoleServerPort\x12K\n\x17\x61ssigned_object_contact\x18\x11 \x01(\x0b\x32\x11.diode.v1.ContactH\x00R\x15\x61ssignedObjectContact\x12j\n\"assigned_object_contact_assignment\x18\x12 \x01(\x0b\x32\x1b.diode.v1.ContactAssignmentH\x00R\x1f\x61ssignedObjectContactAssignment\x12[\n\x1d\x61ssigned_object_contact_group\x18\x13 \x01(\x0b\x32\x16.diode.v1.ContactGroupH\x00R\x1a\x61ssignedObjectContactGroup\x12X\n\x1c\x61ssigned_object_contact_role\x18\x14 \x01(\x0b\x32\x15.diode.v1.ContactRoleH\x00R\x19\x61ssignedObjectContactRole\x12X\n\x1c\x61ssigned_object_custom_field\x18\x15 \x01(\x0b\x32\x15.diode.v1.CustomFieldH\x00R\x19\x61ssignedObjectCustomField\x12u\n\'assigned_object_custom_field_choice_set\x18\x16 \x01(\x0b\x32\x1e.diode.v1.CustomFieldChoiceSetH\x00R\"assignedObjectCustomFieldChoiceSet\x12H\n\x16\x61ssigned_object_device\x18\x17 \x01(\x0b\x32\x10.diode.v1.DeviceH\x00R\x14\x61ssignedObjectDevice\x12R\n\x1a\x61ssigned_object_device_bay\x18\x18 \x01(\x0b\x32\x13.diode.v1.DeviceBayH\x00R\x17\x61ssignedObjectDeviceBay\x12U\n\x1b\x61ssigned_object_device_role\x18\x19 \x01(\x0b\x32\x14.diode.v1.DeviceRoleH\x00R\x18\x61ssignedObjectDeviceRole\x12U\n\x1b\x61ssigned_object_device_type\x18\x1a \x01(\x0b\x32\x14.diode.v1.DeviceTypeH\x00R\x18\x61ssignedObjectDeviceType\x12R\n\x1a\x61ssigned_object_fhrp_group\x18\x1b \x01(\x0b\x32\x13.diode.v1.FHRPGroupH\x00R\x17\x61ssignedObjectFhrpGroup\x12q\n%assigned_object_fhrp_group_assignment\x18\x1c \x01(\x0b\x32\x1d.diode.v1.FHRPGroupAssignmentH\x00R!assignedObjectFhrpGroupAssignment\x12R\n\x1a\x61ssigned_object_front_port\x18\x1d \x01(\x0b\x32\x13.diode.v1.FrontPortH\x00R\x17\x61ssignedObjectFrontPort\x12R\n\x1a\x61ssigned_object_ike_policy\x18\x1e \x01(\x0b\x32\x13.diode.v1.IKEPolicyH\x00R\x17\x61ssignedObjectIkePolicy\x12X\n\x1c\x61ssigned_object_ike_proposal\x18\x1f \x01(\x0b\x32\x15.diode.v1.IKEProposalH\x00R\x19\x61ssignedObjectIkeProposal\x12R\n\x1a\x61ssigned_object_ip_address\x18  \x01(\x0b\x32\x13.diode.v1.IPAddressH\x00R\x17\x61ssignedObjectIpAddress\x12L\n\x18\x61ssigned_object_ip_range\x18! \x01(\x0b\x32\x11.diode.v1.IPRangeH\x00R\x15\x61ssignedObjectIpRange\x12Y\n\x1d\x61ssigned_object_ip_sec_policy\x18\" \x01(\x0b\x32\x15.diode.v1.IPSecPolicyH\x00R\x19\x61ssignedObjectIpSecPolicy\x12\\\n\x1e\x61ssigned_object_ip_sec_profile\x18# \x01(\x0b\x32\x16.diode.v1.IPSecProfileH\x00R\x1a\x61ssignedObjectIpSecProfile\x12_\n\x1f\x61ssigned_object_ip_sec_proposal\x18$ \x01(\x0b\x32\x17.diode.v1.IPSecProposalH\x00R\x1b\x61ssignedObjectIpSecProposal\x12Q\n\x19\x61ssigned_object_interface\x18% \x01(\x0b\x32\x13.diode.v1.InterfaceH\x00R\x17\x61ssignedObjectInterface\x12^\n\x1e\x61ssigned_object_inventory_item\x18& \x01(\x0b\x32\x17.diode.v1.InventoryItemH\x00R\x1b\x61ssignedObjectInventoryItem\x12k\n#assigned_object_inventory_item_role\x18\' \x01(\x0b\x32\x1b.diode.v1.InventoryItemRoleH\x00R\x1f\x61ssignedObjectInventoryItemRole\x12[\n\x1d\x61ssigned_object_journal_entry\x18( \x01(\x0b\x32\x16.diode.v1.JournalEntryH\x00R\x1a\x61ssignedObjectJournalEntry\x12\x45\n\x15\x61ssigned_object_l2vpn\x18) \x01(\x0b\x32\x0f.diode.v1.L2VPNH\x00R\x13\x61ssignedObjectL2vpn\x12g\n!assigned_object_l2vpn_termination\x18* \x01(\x0b\x32\x1a.diode.v1.L2VPNTerminationH\x00R\x1e\x61ssignedObjectL2vpnTermination\x12N\n\x18\x61ssigned_object_location\x18+ \x01(\x0b\x32\x12.diode.v1.LocationH\x00R\x16\x61ssignedObjectLocation\x12U\n\x1b\x61ssigned_object_mac_address\x18, \x01(\x0b\x32\x14.diode.v1.MACAddressH\x00R\x18\x61ssignedObjectMacAddress\x12Z\n\x1c\x61ssigned_object_manufacturer\x18- \x01(\x0b\x32\x16.diode.v1.ManufacturerH\x00R\x1a\x61ssignedObjectManufacturer\x12H\n\x16\x61ssigned_object_module\x18. \x01(\x0b\x32\x10.diode.v1.ModuleH\x00R\x14\x61ssignedObjectModule\x12R\n\x1a\x61ssigned_object_module_bay\x18/ \x01(\x0b\x32\x13.diode.v1.ModuleBayH\x00R\x17\x61ssignedObjectModuleBay\x12U\n\x1b\x61ssigned_object_module_type\x18\x30 \x01(\x0b\x32\x14.diode.v1.ModuleTypeH\x00R\x18\x61ssignedObjectModuleType\x12k\n#assigned_object_module_type_profile\x18\x31 \x01(\x0b\x32\x1b.diode.v1.ModuleTypeProfileH\x00R\x1f\x61ssignedObjectModuleTypeProfile\x12N\n\x18\x61ssigned_object_platform\x18\x32 \x01(\x0b\x32\x12.diode.v1.PlatformH\x00R\x16\x61ssignedObjectPlatform\x12R\n\x1a\x61ssigned_object_power_feed\x18\x33 \x01(\x0b\x32\x13.diode.v1.PowerFeedH\x00R\x17\x61ssignedObjectPowerFeed\x12X\n\x1c\x61ssigned_object_power_outlet\x18\x34 \x01(\x0b\x32\x15.diode.v1.PowerOutletH\x00R\x19\x61ssignedObjectPowerOutlet\x12U\n\x1b\x61ssigned_object_power_panel\x18\x35 \x01(\x0b\x32\x14.diode.v1.PowerPanelH\x00R\x18\x61ssignedObjectPowerPanel\x12R\n\x1a\x61ssigned_object_power_port\x18\x36 \x01(\x0b\x32\x13.diode.v1.PowerPortH\x00R\x17\x61ssignedObjectPowerPort\x12H\n\x16\x61ssigned_object_prefix\x18\x37 \x01(\x0b\x32\x10.diode.v1.PrefixH\x00R\x14\x61ssignedObjectPrefix\x12N\n\x18\x61ssigned_object_provider\x18\x38 \x01(\x0b\x32\x12.diode.v1.ProviderH\x00R\x16\x61ssignedObjectProvider\x12\x64\n assigned_object_provider_account\x18\x39 \x01(\x0b\x32\x19.diode.v1.ProviderAccountH\x00R\x1d\x61ssignedObjectProviderAccount\x12\x64\n assigned_object_provider_network\x18: \x01(\x0b\x32\x19.diode.v1.ProviderNetworkH\x00R\x1d\x61ssignedObjectProviderNetwork\x12?\n\x13\x61ssigned_object_rir\x18; \x01(\x0b\x32\r.diode.v1.RIRH\x00R\x11\x61ssignedObjectRir\x12\x42\n\x14\x61ssigned_object_rack\x18< \x01(\x0b\x32\x0e.diode.v1.RackH\x00R\x12\x61ssignedObjectRack\x12\x64\n assigned_object_rack_reservation\x18= \x01(\x0b\x32\x19.diode.v1.RackReservationH\x00R\x1d\x61ssignedObjectRackReservation\x12O\n\x19\x61ssigned_object_rack_role\x18> \x01(\x0b\x32\x12.diode.v1.RackRoleH\x00R\x16\x61ssignedObjectRackRole\x12O\n\x19\x61ssigned_object_rack_type\x18? \x01(\x0b\x32\x12.diode.v1.RackTypeH\x00R\x16\x61ssignedObjectRackType\x12O\n\x19\x61ssigned_object_rear_port\x18@ \x01(\x0b\x32\x12.diode.v1.RearPortH\x00R\x16\x61ssignedObjectRearPort\x12H\n\x16\x61ssigned_object_region\x18\x41 \x01(\x0b\x32\x10.diode.v1.RegionH\x00R\x14\x61ssignedObjectRegion\x12\x42\n\x14\x61ssigned_object_role\x18\x42 \x01(\x0b\x32\x0e.diode.v1.RoleH\x00R\x12\x61ssignedObjectRole\x12X\n\x1c\x61ssigned_object_route_target\x18\x43 \x01(\x0b\x32\x15.diode.v1.RouteTargetH\x00R\x19\x61ssignedObjectRouteTarget\x12K\n\x17\x61ssigned_object_service\x18\x44 \x01(\x0b\x32\x11.diode.v1.ServiceH\x00R\x15\x61ssignedObjectService\x12\x42\n\x14\x61ssigned_object_site\x18\x45 \x01(\x0b\x32\x0e.diode.v1.SiteH\x00R\x12\x61ssignedObjectSite\x12R\n\x1a\x61ssigned_object_site_group\x18\x46 \x01(\x0b\x32\x13.diode.v1.SiteGroupH\x00R\x17\x61ssignedObjectSiteGroup\x12?\n\x13\x61ssigned_object_tag\x18G \x01(\x0b\x32\r.diode.v1.TagH\x00R\x11\x61ssignedObjectTag\x12H\n\x16\x61ssigned_object_tenant\x18H \x01(\x0b\x32\x10.diode.v1.TenantH\x00R\x14\x61ssignedObjectTenant\x12X\n\x1c\x61ssigned_object_tenant_group\x18I \x01(\x0b\x32\x15.diode.v1.TenantGroupH\x00R\x19\x61ssignedObjectTenantGroup\x12H\n\x16\x61ssigned_object_tunnel\x18J \x01(\x0b\x32\x10.diode.v1.TunnelH\x00R\x14\x61ssignedObjectTunnel\x12X\n\x1c\x61ssigned_object_tunnel_group\x18K \x01(\x0b\x32\x15.diode.v1.TunnelGroupH\x00R\x19\x61ssignedObjectTunnelGroup\x12j\n\"assigned_object_tunnel_termination\x18L \x01(\x0b\x32\x1b.diode.v1.TunnelTerminationH\x00R\x1f\x61ssignedObjectTunnelTermination\x12\x42\n\x14\x61ssigned_object_vlan\x18M \x01(\x0b\x32\x0e.diode.v1.VLANH\x00R\x12\x61ssignedObjectVlan\x12R\n\x1a\x61ssigned_object_vlan_group\x18N \x01(\x0b\x32\x13.diode.v1.VLANGroupH\x00R\x17\x61ssignedObjectVlanGroup\x12w\n\'assigned_object_vlan_translation_policy\x18O \x01(\x0b\x32\x1f.diode.v1.VLANTranslationPolicyH\x00R#assignedObjectVlanTranslationPolicy\x12q\n%assigned_object_vlan_translation_rule\x18P \x01(\x0b\x32\x1d.diode.v1.VLANTranslationRuleH\x00R!assignedObjectVlanTranslationRule\x12X\n\x1c\x61ssigned_object_vm_interface\x18Q \x01(\x0b\x32\x15.diode.v1.VMInterfaceH\x00R\x19\x61ssignedObjectVmInterface\x12?\n\x13\x61ssigned_object_vrf\x18R \x01(\x0b\x32\r.diode.v1.VRFH\x00R\x11\x61ssignedObjectVrf\x12\x61\n\x1f\x61ssigned_object_virtual_chassis\x18S \x01(\x0b\x32\x18.diode.v1.VirtualChassisH\x00R\x1c\x61ssignedObjectVirtualChassis\x12\x61\n\x1f\x61ssigned_object_virtual_circuit\x18T \x01(\x0b\x32\x18.diode.v1.VirtualCircuitH\x00R\x1c\x61ssignedObjectVirtualCircuit\x12\x83\x01\n+assigned_object_virtual_circuit_termination\x18U \x01(\x0b\x32#.diode.v1.VirtualCircuitTerminationH\x00R\'assignedObjectVirtualCircuitTermination\x12n\n$assigned_object_virtual_circuit_type\x18V \x01(\x0b\x32\x1c.diode.v1.VirtualCircuitTypeH\x00R assignedObjectVirtualCircuitType\x12t\n&assigned_object_virtual_device_context\x18W \x01(\x0b\x32\x1e.diode.v1.VirtualDeviceContextH\x00R\"assignedObjectVirtualDeviceContext\x12X\n\x1c\x61ssigned_object_virtual_disk\x18X \x01(\x0b\x32\x15.diode.v1.VirtualDiskH\x00R\x19\x61ssignedObjectVirtualDisk\x12\x61\n\x1f\x61ssigned_object_virtual_machine\x18Y \x01(\x0b\x32\x18.diode.v1.VirtualMachineH\x00R\x1c\x61ssignedObjectVirtualMachine\x12X\n\x1c\x61ssigned_object_wireless_lan\x18Z \x01(\x0b\x32\x15.diode.v1.WirelessLANH\x00R\x19\x61ssignedObjectWirelessLan\x12h\n\"assigned_object_wireless_lan_group\x18[ \x01(\x0b\x32\x1a.diode.v1.WirelessLANGroupH\x00R\x1e\x61ssignedObjectWirelessLanGroup\x12[\n\x1d\x61ssigned_object_wireless_link\x18\\ \x01(\x0b\x32\x16.diode.v1.WirelessLinkH\x00R\x1a\x61ssignedObjectWirelessLink\x12U\n\x1b\x61ssigned_object_custom_link\x18\x61 \x01(\x0b\x32\x14.diode.v1.CustomLinkH\x00R\x18\x61ssignedObjectCustomLink\x12>\n\x04kind\x18] \x01(\tB%\xfa\x42\"r R\x06\x64\x61ngerR\x04infoR\x07successR\x07warningH\x01R\x04kind\x88\x01\x01\x12\x1a\n\x08\x63omments\x18^ \x01(\tR\x08\x63omments\x12!\n\x04tags\x18_ \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12M\n\rcustom_fields\x18` \x03(\x0b\x32(.diode.v1.JournalEntry.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x11\n\x0f\x61ssigned_objectB\x07\n\x05_kind\"\x88\x03\n\x11ModuleTypeProfile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x1b\n\x06schema\x18\x03 \x01(\tH\x01R\x06schema\x88\x01\x01\x12\x1f\n\x08\x63omments\x18\x04 \x01(\tH\x02R\x08\x63omments\x88\x01\x01\x12!\n\x04tags\x18\x05 \x03(\x0b\x32\r.diode.v1.TagR\x04tags\x12R\n\rcustom_fields\x18\x06 \x03(\x0b\x32-.diode.v1.ModuleTypeProfile.CustomFieldsEntryR\x0c\x63ustomFields\x1a[\n\x11\x43ustomFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.diode.v1.CustomFieldValueR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\t\n\x07_schemaB\x0b\n\t_comments\"\xa8\x10\n\nCustomLink\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\x07\x65nabled\x18\x02 \x01(\x08H\x00R\x07\x65nabled\x88\x01\x01\x12\x1b\n\tlink_text\x18\x03 \x01(\tR\x08linkText\x12\x19\n\x08link_url\x18\x04 \x01(\tR\x07linkUrl\x12\x1b\n\x06weight\x18\x05 \x01(\x03H\x01R\x06weight\x88\x01\x01\x12\"\n\ngroup_name\x18\x06 \x01(\tH\x02R\tgroupName\x88\x01\x01\x12\x9a\x01\n\x0c\x62utton_class\x18\x07 \x01(\tBr\xfa\x42ormR\x05\x62lackR\x04\x62lueR\x04\x63yanR\x07\x64\x65\x66\x61ultR\nghost-darkR\x04grayR\x05greenR\x06indigoR\x06orangeR\x04pinkR\x06purpleR\x03redR\x04tealR\x05whiteR\x06yellowH\x03R\x0b\x62uttonClass\x88\x01\x01\x12\"\n\nnew_window\x18\x08 \x01(\x08H\x04R\tnewWindow\x88\x01\x01\x12\xe6\x0c\n\x0cobject_types\x18\t \x03(\tB\xc2\x0c\xfa\x42\xbe\x0c\x92\x01\xba\x0c\"\xb7\x0cr\xb4\x0cR\x10\x63ircuits.circuitR\x15\x63ircuits.circuitgroupR\x1b\x63ircuits.circuitterminationR\x14\x63ircuits.circuittypeR\x11\x63ircuits.providerR\x18\x63ircuits.provideraccountR\x18\x63ircuits.providernetworkR\x17\x63ircuits.virtualcircuitR\"circuits.virtualcircuitterminationR\x1b\x63ircuits.virtualcircuittypeR\ndcim.cableR\x10\x64\x63im.consoleportR\x16\x64\x63im.consoleserverportR\x0b\x64\x63im.deviceR\x0e\x64\x63im.devicebayR\x0f\x64\x63im.deviceroleR\x0f\x64\x63im.devicetypeR\x0e\x64\x63im.frontportR\x0e\x64\x63im.interfaceR\x12\x64\x63im.inventoryitemR\x16\x64\x63im.inventoryitemroleR\rdcim.locationR\x0f\x64\x63im.macaddressR\x11\x64\x63im.manufacturerR\x0b\x64\x63im.moduleR\x0e\x64\x63im.modulebayR\x0f\x64\x63im.moduletypeR\x16\x64\x63im.moduletypeprofileR\rdcim.platformR\x0e\x64\x63im.powerfeedR\x10\x64\x63im.poweroutletR\x0f\x64\x63im.powerpanelR\x0e\x64\x63im.powerportR\tdcim.rackR\x14\x64\x63im.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\x0b\x64\x63im.regionR\tdcim.siteR\x0e\x64\x63im.sitegroupR\x13\x64\x63im.virtualchassisR\x19\x64\x63im.virtualdevicecontextR\x13\x65xtras.journalentryR\x0eipam.aggregateR\x08ipam.asnR\ripam.asnrangeR\x0eipam.fhrpgroupR\x0eipam.ipaddressR\x0cipam.iprangeR\x0bipam.prefixR\x08ipam.rirR\tipam.roleR\x10ipam.routetargetR\x0cipam.serviceR\tipam.vlanR\x0eipam.vlangroupR\x1aipam.vlantranslationpolicyR\x18ipam.vlantranslationruleR\x08ipam.vrfR\x0ftenancy.contactR\x14tenancy.contactgroupR\x13tenancy.contactroleR\x0etenancy.tenantR\x13tenancy.tenantgroupR\x16virtualization.clusterR\x1bvirtualization.clustergroupR\x1avirtualization.clustertypeR\x1avirtualization.virtualdiskR\x1dvirtualization.virtualmachineR\x1avirtualization.vminterfaceR\rvpn.ikepolicyR\x0fvpn.ikeproposalR\x0fvpn.ipsecpolicyR\x10vpn.ipsecprofileR\x11vpn.ipsecproposalR\tvpn.l2vpnR\x14vpn.l2vpnterminationR\nvpn.tunnelR\x0fvpn.tunnelgroupR\x15vpn.tunnelterminationR\x14wireless.wirelesslanR\x19wireless.wirelesslangroupR\x15wireless.wirelesslinkR\x0bobjectTypesB\n\n\x08_enabledB\t\n\x07_weightB\r\n\x0b_group_nameB\x0f\n\r_button_classB\r\n\x0b_new_window2N\n\x0fIngesterService\x12;\n\x06Ingest\x12\x17.diode.v1.IngestRequest\x1a\x18.diode.v1.IngestResponseB5Z3github.com/netboxlabs/diode-sdk-go/diode/v1/diodepbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'diode.v1.ingester_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/netboxlabs/diode-sdk-go/diode/v1/diodepb'
  _globals['_ENTITY'].fields_by_name['timestamp']._loaded_options = None
  _globals['_ENTITY'].fields_by_name['timestamp']._serialized_options = b'\372B\007\262\001\004\010\0018\001'
  _globals['_INGESTREQUEST'].fields_by_name['stream']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['stream']._serialized_options = b'\372B\007r\005\020\001\030\377\001'
  _globals['_INGESTREQUEST'].fields_by_name['entities']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['entities']._serialized_options = b'\372B\010\222\001\005\010\001\020\350\007'
  _globals['_INGESTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_INGESTREQUEST'].fields_by_name['producer_app_name']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['producer_app_name']._serialized_options = b'\372B\007r\005\020\001\030\377\001'
  _globals['_INGESTREQUEST'].fields_by_name['producer_app_version']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['producer_app_version']._serialized_options = b'\372B\007r\005\020\001\030\377\001'
  _globals['_INGESTREQUEST'].fields_by_name['sdk_name']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['sdk_name']._serialized_options = b'\372B\007r\005\020\001\030\377\001'
  _globals['_INGESTREQUEST'].fields_by_name['sdk_version']._loaded_options = None
  _globals['_INGESTREQUEST'].fields_by_name['sdk_version']._serialized_options = b'\372B\031r\0272\025^(\\d)+\\.(\\d)+\\.(\\d)+$'
  _globals['_ASN_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_ASN_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_ASNRANGE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_ASNRANGE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_AGGREGATE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_AGGREGATE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CABLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CABLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CABLE'].fields_by_name['type']._loaded_options = None
  _globals['_CABLE'].fields_by_name['type']._serialized_options = b'\372B\277\001r\274\001R\003aocR\004cat3R\004cat5R\005cat5eR\004cat6R\005cat6aR\004cat7R\005cat7aR\004cat8R\007coaxialR\ndac-activeR\013dac-passiveR\003mmfR\007mmf-om1R\007mmf-om2R\007mmf-om3R\007mmf-om4R\007mmf-om5R\013mrj21-trunkR\005powerR\003smfR\007smf-os1R\007smf-os2R\003usb'
  _globals['_CABLE'].fields_by_name['status']._loaded_options = None
  _globals['_CABLE'].fields_by_name['status']._serialized_options = b'\372B\'r%R\tconnectedR\017decommissioningR\007planned'
  _globals['_CABLE'].fields_by_name['length_unit']._loaded_options = None
  _globals['_CABLE'].fields_by_name['length_unit']._serialized_options = b'\372B\031r\027R\002cmR\002ftR\002inR\002kmR\001mR\002mi'
  _globals['_CABLETERMINATION'].fields_by_name['cable_end']._loaded_options = None
  _globals['_CABLETERMINATION'].fields_by_name['cable_end']._serialized_options = b'\372B\010r\006R\001AR\001B'
  _globals['_CIRCUIT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CIRCUIT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CIRCUIT'].fields_by_name['status']._loaded_options = None
  _globals['_CIRCUIT'].fields_by_name['status']._serialized_options = b'\372BJrHR\006activeR\016decommissionedR\016deprovisioningR\007offlineR\007plannedR\014provisioning'
  _globals['_CIRCUIT'].fields_by_name['distance_unit']._loaded_options = None
  _globals['_CIRCUIT'].fields_by_name['distance_unit']._serialized_options = b'\372B\021r\017R\002ftR\002kmR\001mR\002mi'
  _globals['_CIRCUITGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CIRCUITGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CIRCUITGROUPASSIGNMENT'].fields_by_name['priority']._loaded_options = None
  _globals['_CIRCUITGROUPASSIGNMENT'].fields_by_name['priority']._serialized_options = b'\372B*r(R\010inactiveR\007primaryR\tsecondaryR\010tertiary'
  _globals['_CIRCUITTERMINATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CIRCUITTERMINATION'].fields_by_name['term_side']._loaded_options = None
  _globals['_CIRCUITTERMINATION'].fields_by_name['term_side']._serialized_options = b'\372B\010r\006R\001AR\001Z'
  _globals['_CIRCUITTYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CLUSTER_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['status']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['status']._serialized_options = b'\372B6r4R\006activeR\017decommissioningR\007offlineR\007plannedR\007staging'
  _globals['_CLUSTERGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CLUSTERGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTERTYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CLUSTERTYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONSOLEPORT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONSOLEPORT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONSOLEPORT'].fields_by_name['type']._loaded_options = None
  _globals['_CONSOLEPORT'].fields_by_name['type']._serialized_options = b'\372B\215\001r\212\001R\005db-25R\004de-9R\nmini-din-8R\005otherR\005rj-11R\005rj-12R\005rj-45R\005usb-aR\005usb-bR\005usb-cR\013usb-micro-aR\014usb-micro-abR\013usb-micro-bR\nusb-mini-aR\nusb-mini-b'
  _globals['_CONSOLEPORT'].fields_by_name['speed']._loaded_options = None
  _globals['_CONSOLEPORT'].fields_by_name['speed']._serialized_options = b'\372B\036\"\0340\260\t0\340\0220\300%0\200K0\200\226\0010\200\254\0020\200\302\0030\200\204\007'
  _globals['_CONSOLESERVERPORT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONSOLESERVERPORT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONSOLESERVERPORT'].fields_by_name['type']._loaded_options = None
  _globals['_CONSOLESERVERPORT'].fields_by_name['type']._serialized_options = b'\372B\215\001r\212\001R\005db-25R\004de-9R\nmini-din-8R\005otherR\005rj-11R\005rj-12R\005rj-45R\005usb-aR\005usb-bR\005usb-cR\013usb-micro-aR\014usb-micro-abR\013usb-micro-bR\nusb-mini-aR\nusb-mini-b'
  _globals['_CONSOLESERVERPORT'].fields_by_name['speed']._loaded_options = None
  _globals['_CONSOLESERVERPORT'].fields_by_name['speed']._serialized_options = b'\372B\036\"\0340\260\t0\340\0220\300%0\200K0\200\226\0010\200\254\0020\200\302\0030\200\204\007'
  _globals['_CONTACT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONTACT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONTACT'].fields_by_name['group']._loaded_options = None
  _globals['_CONTACT'].fields_by_name['group']._serialized_options = b'\030\001'
  _globals['_CONTACTASSIGNMENT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONTACTASSIGNMENT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONTACTASSIGNMENT'].fields_by_name['priority']._loaded_options = None
  _globals['_CONTACTASSIGNMENT'].fields_by_name['priority']._serialized_options = b'\372B*r(R\010inactiveR\007primaryR\tsecondaryR\010tertiary'
  _globals['_CONTACTGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONTACTGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CONTACTROLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_CONTACTROLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_DEVICE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICE'].fields_by_name['face']._loaded_options = None
  _globals['_DEVICE'].fields_by_name['face']._serialized_options = b'\372B\017r\rR\005frontR\004rear'
  _globals['_DEVICE'].fields_by_name['status']._loaded_options = None
  _globals['_DEVICE'].fields_by_name['status']._serialized_options = b'\372BHrFR\006activeR\017decommissioningR\006failedR\tinventoryR\007offlineR\007plannedR\006staged'
  _globals['_DEVICE'].fields_by_name['airflow']._loaded_options = None
  _globals['_DEVICE'].fields_by_name['airflow']._serialized_options = b'\372B\211\001r\206\001R\rbottom-to-topR\rfront-to-rearR\rleft-to-rightR\005mixedR\007passiveR\rrear-to-frontR\014rear-to-sideR\rright-to-leftR\014side-to-rearR\rtop-to-bottom'
  _globals['_DEVICEBAY_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_DEVICEBAY_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICEROLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_DEVICEROLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICETYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_DEVICETYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_DEVICETYPE'].fields_by_name['subdevice_role']._loaded_options = None
  _globals['_DEVICETYPE'].fields_by_name['subdevice_role']._serialized_options = b'\372B\021r\017R\005childR\006parent'
  _globals['_DEVICETYPE'].fields_by_name['airflow']._loaded_options = None
  _globals['_DEVICETYPE'].fields_by_name['airflow']._serialized_options = b'\372B\211\001r\206\001R\rbottom-to-topR\rfront-to-rearR\rleft-to-rightR\005mixedR\007passiveR\rrear-to-frontR\014rear-to-sideR\rright-to-leftR\014side-to-rearR\rtop-to-bottom'
  _globals['_DEVICETYPE'].fields_by_name['weight_unit']._loaded_options = None
  _globals['_DEVICETYPE'].fields_by_name['weight_unit']._serialized_options = b'\372B\021r\017R\001gR\002kgR\002lbR\002oz'
  _globals['_FHRPGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_FHRPGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_FHRPGROUP'].fields_by_name['protocol']._loaded_options = None
  _globals['_FHRPGROUP'].fields_by_name['protocol']._serialized_options = b'\372B4r2R\004carpR\tclusterxlR\004glbpR\004hsrpR\005otherR\005vrrp2R\005vrrp3'
  _globals['_FHRPGROUP'].fields_by_name['auth_type']._loaded_options = None
  _globals['_FHRPGROUP'].fields_by_name['auth_type']._serialized_options = b'\372B\022r\020R\003md5R\tplaintext'
  _globals['_FRONTPORT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_FRONTPORT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_FRONTPORT'].fields_by_name['type']._loaded_options = None
  _globals['_FRONTPORT'].fields_by_name['type']._serialized_options = b'\372B\253\003r\250\003R\t110-punchR\0044p2cR\0044p4cR\0046p2cR\0046p4cR\0046p6cR\0048p2cR\0048p4cR\0048p6cR\0048p8cR\003bncR\002csR\001fR\002fcR\006fc-apcR\005fc-pcR\006fc-upcR\004gg45R\002lcR\006lc-apcR\005lc-pcR\006lc-upcR\003lshR\007lsh-apcR\006lsh-pcR\007lsh-upcR\003lx5R\007lx5-apcR\006lx5-pcR\007lx5-upcR\003mpoR\005mrj21R\004mtrjR\001nR\005otherR\002scR\006sc-apcR\005sc-pcR\006sc-upcR\007sma-905R\007sma-906R\002snR\006spliceR\002stR\007tera-1pR\007tera-2pR\007tera-4pR\006urm-p2R\006urm-p4R\006urm-p8R\005usb-aR\005usb-bR\005usb-cR\013usb-micro-aR\014usb-micro-abR\013usb-micro-bR\nusb-mini-aR\nusb-mini-b'
  _globals['_IKEPOLICY_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IKEPOLICY_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IKEPOLICY'].fields_by_name['version']._loaded_options = None
  _globals['_IKEPOLICY'].fields_by_name['version']._serialized_options = b'\372B\006\"\0040\0010\002'
  _globals['_IKEPOLICY'].fields_by_name['mode']._loaded_options = None
  _globals['_IKEPOLICY'].fields_by_name['mode']._serialized_options = b'\372B\024r\022R\naggressiveR\004main'
  _globals['_IKEPROPOSAL_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IKEPROPOSAL_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IKEPROPOSAL'].fields_by_name['authentication_method']._loaded_options = None
  _globals['_IKEPROPOSAL'].fields_by_name['authentication_method']._serialized_options = b'\372B@r>R\014certificatesR\016dsa-signaturesR\016preshared-keysR\016rsa-signatures'
  _globals['_IKEPROPOSAL'].fields_by_name['encryption_algorithm']._loaded_options = None
  _globals['_IKEPROPOSAL'].fields_by_name['encryption_algorithm']._serialized_options = b'\372BcraR\0103des-cbcR\013aes-128-cbcR\013aes-128-gcmR\013aes-192-cbcR\013aes-192-gcmR\013aes-256-cbcR\013aes-256-gcmR\007des-cbc'
  _globals['_IKEPROPOSAL'].fields_by_name['authentication_algorithm']._loaded_options = None
  _globals['_IKEPROPOSAL'].fields_by_name['authentication_algorithm']._serialized_options = b'\372B>r<R\010hmac-md5R\thmac-sha1R\013hmac-sha256R\013hmac-sha384R\013hmac-sha512'
  _globals['_IKEPROPOSAL'].fields_by_name['group']._loaded_options = None
  _globals['_IKEPROPOSAL'].fields_by_name['group']._serialized_options = b'\372B2\"00\0010\0020\0050\0160\0170\0200\0210\0220\0230\0240\0250\0260\0270\0300\0310\0320\0330\0340\0350\0360\0370 0!0\"'
  _globals['_IPADDRESS_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IPADDRESS_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IPADDRESS'].fields_by_name['status']._loaded_options = None
  _globals['_IPADDRESS'].fields_by_name['status']._serialized_options = b'\372B-r+R\006activeR\ndeprecatedR\004dhcpR\010reservedR\005slaac'
  _globals['_IPADDRESS'].fields_by_name['role']._loaded_options = None
  _globals['_IPADDRESS'].fields_by_name['role']._serialized_options = b'\372B=r;R\007anycastR\004carpR\004glbpR\004hsrpR\010loopbackR\tsecondaryR\003vipR\004vrrp'
  _globals['_IPRANGE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IPRANGE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IPRANGE'].fields_by_name['status']._loaded_options = None
  _globals['_IPRANGE'].fields_by_name['status']._serialized_options = b'\372B r\036R\006activeR\ndeprecatedR\010reserved'
  _globals['_IPSECPOLICY_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IPSECPOLICY_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IPSECPOLICY'].fields_by_name['pfs_group']._loaded_options = None
  _globals['_IPSECPOLICY'].fields_by_name['pfs_group']._serialized_options = b'\372B2\"00\0010\0020\0050\0160\0170\0200\0210\0220\0230\0240\0250\0260\0270\0300\0310\0320\0330\0340\0350\0360\0370 0!0\"'
  _globals['_IPSECPROFILE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IPSECPROFILE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IPSECPROFILE'].fields_by_name['mode']._loaded_options = None
  _globals['_IPSECPROFILE'].fields_by_name['mode']._serialized_options = b'\372B\013r\tR\002ahR\003esp'
  _globals['_IPSECPROPOSAL_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_IPSECPROPOSAL_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_IPSECPROPOSAL'].fields_by_name['encryption_algorithm']._loaded_options = None
  _globals['_IPSECPROPOSAL'].fields_by_name['encryption_algorithm']._serialized_options = b'\372BcraR\0103des-cbcR\013aes-128-cbcR\013aes-128-gcmR\013aes-192-cbcR\013aes-192-gcmR\013aes-256-cbcR\013aes-256-gcmR\007des-cbc'
  _globals['_IPSECPROPOSAL'].fields_by_name['authentication_algorithm']._loaded_options = None
  _globals['_IPSECPROPOSAL'].fields_by_name['authentication_algorithm']._serialized_options = b'\372B>r<R\010hmac-md5R\thmac-sha1R\013hmac-sha256R\013hmac-sha384R\013hmac-sha512'
  _globals['_INTERFACE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_INTERFACE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_INTERFACE'].fields_by_name['type']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['type']._serialized_options = b'\372B\226\016r\223\016R\0131000base-kxR\0131000base-lxR\0131000base-sxR\n1000base-tR\0131000base-txR\0171000base-x-gbicR\0161000base-x-sfpR\n100base-fxR\013100base-lfxR\n100base-t1R\n100base-txR\r100base-x-sfpR\014100gbase-kp4R\014100gbase-kr2R\014100gbase-kr4R\016100gbase-x-cfpR\017100gbase-x-cfp2R\017100gbase-x-cfp4R\017100gbase-x-cpakR\016100gbase-x-cxpR\017100gbase-x-dsfpR\021100gbase-x-qsfp28R\021100gbase-x-qsfpddR\020100gbase-x-sfpddR\01010g-eponR\01310gbase-cx4R\n10gbase-krR\01310gbase-kx4R\t10gbase-tR\01610gbase-x-sfppR\01410gbase-x-x2R\02010gbase-x-xenpakR\r10gbase-x-xfpR\r128gfc-qsfp28R\n16gfc-sfppR\0101gfc-sfpR\0132.5gbase-kxR\n2.5gbase-tR\017200gbase-x-cfp2R\021200gbase-x-qsfp56R\021200gbase-x-qsfpddR\00725g-ponR\n25gbase-krR\01725gbase-x-sfp28R\0102gfc-sfpR\01332gfc-sfp28R\n32gfc-sfppR\017400gbase-x-cdfpR\017400gbase-x-cfp2R\017400gbase-x-cfp8R\017400gbase-x-osfpR\023400gbase-x-osfp-rhsR\022400gbase-x-qsfp112R\021400gbase-x-qsfpddR\01340gbase-kr4R\01740gbase-x-qsfppR\0024gR\0104gfc-sfpR\00750g-ponR\n50gbase-krR\01750gbase-x-sfp28R\01750gbase-x-sfp56R\0025gR\t5gbase-krR\0105gbase-tR\01364gfc-qsfppR\01364gfc-sfpddR\n64gfc-sfppR\017800gbase-x-osfpR\021800gbase-x-qsfpddR\t8gfc-sfppR\004bponR\006bridgeR\004cdmaR\017cisco-flexstackR\024cisco-flexstack-plusR\017cisco-stackwiseR\023cisco-stackwise-160R\022cisco-stackwise-1tR\023cisco-stackwise-320R\023cisco-stackwise-480R\022cisco-stackwise-80R\024cisco-stackwise-plusR\006docsisR\002e1R\002e3R\004eponR\023extreme-summitstackR\027extreme-summitstack-128R\027extreme-summitstack-256R\027extreme-summitstack-512R\004gponR\003gsmR\013ieee802.11aR\014ieee802.11acR\014ieee802.11adR\014ieee802.11axR\014ieee802.11ayR\014ieee802.11beR\013ieee802.11gR\013ieee802.11nR\014ieee802.15.1R\014ieee802.15.4R\016infiniband-ddrR\016infiniband-edrR\016infiniband-fdrR\020infiniband-fdr10R\016infiniband-hdrR\016infiniband-ndrR\016infiniband-qdrR\016infiniband-sdrR\016infiniband-xdrR\013juniper-vcpR\003lagR\003lteR\004mocaR\007ng-pon2R\005otherR\016other-wirelessR\nsonet-oc12R\013sonet-oc192R\014sonet-oc1920R\tsonet-oc3R\014sonet-oc3840R\nsonet-oc48R\013sonet-oc768R\002t1R\002t3R\007virtualR\004xdslR\006xg-ponR\007xgs-pon'
  _globals['_INTERFACE'].fields_by_name['duplex']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['duplex']._serialized_options = b'\372B\024r\022R\004autoR\004fullR\004half'
  _globals['_INTERFACE'].fields_by_name['mode']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['mode']._serialized_options = b'\372B&r$R\006accessR\006q-in-qR\006taggedR\ntagged-all'
  _globals['_INTERFACE'].fields_by_name['rf_role']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['rf_role']._serialized_options = b'\372B\017r\rR\002apR\007station'
  _globals['_INTERFACE'].fields_by_name['rf_channel']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['rf_channel']._serialized_options = b'\372B\314\030r\311\030R\0162.4g-1-2412-22R\0172.4g-10-2457-22R\0172.4g-11-2462-22R\0172.4g-12-2467-22R\0172.4g-13-2472-22R\0162.4g-2-2417-22R\0162.4g-3-2422-22R\0162.4g-4-2427-22R\0162.4g-5-2432-22R\0162.4g-6-2437-22R\0162.4g-7-2442-22R\0162.4g-8-2447-22R\0162.4g-9-2452-22R\0165g-100-5500-20R\0165g-102-5510-40R\0165g-104-5520-20R\0165g-106-5530-80R\0165g-108-5540-20R\0165g-110-5550-40R\0165g-112-5560-20R\0175g-114-5570-160R\0165g-116-5580-20R\0165g-118-5590-40R\0165g-120-5600-20R\0165g-122-5610-80R\0165g-124-5620-20R\0165g-126-5630-40R\0165g-128-5640-20R\0165g-132-5660-20R\0165g-134-5670-40R\0165g-136-5680-20R\0165g-138-5690-80R\0165g-140-5700-20R\0165g-142-5710-40R\0165g-144-5720-20R\0165g-149-5745-20R\0165g-151-5755-40R\0165g-153-5765-20R\0165g-155-5775-80R\0165g-157-5785-20R\0165g-159-5795-40R\0165g-161-5805-20R\0175g-163-5815-160R\0165g-165-5825-20R\0165g-167-5835-40R\0165g-169-5845-20R\0165g-171-5855-80R\0165g-173-5865-20R\0165g-175-5875-40R\0165g-177-5885-20R\r5g-32-5160-20R\r5g-34-5170-40R\r5g-36-5180-20R\r5g-38-5190-40R\r5g-40-5200-20R\r5g-42-5210-80R\r5g-44-5220-20R\r5g-46-5230-40R\r5g-48-5240-20R\0165g-50-5250-160R\r5g-52-5260-20R\r5g-54-5270-40R\r5g-56-5280-20R\r5g-58-5290-80R\r5g-60-5300-20R\r5g-62-5310-40R\r5g-64-5320-20R\02060g-1-58320-2160R\02160g-10-61560-4320R\02160g-11-63720-4320R\02160g-12-65880-4320R\02160g-13-68040-4320R\02160g-17-60480-6480R\02160g-18-62640-6480R\02160g-19-64800-6480R\02060g-2-60480-2160R\02160g-20-66960-6480R\02160g-25-61560-6480R\02160g-26-63720-6480R\02160g-27-65880-6480R\02060g-3-62640-2160R\02060g-4-64800-2160R\02060g-5-66960-2160R\02060g-6-69120-2160R\02060g-9-59400-4320R\0146g-1-5955-20R\0166g-101-6455-20R\0166g-103-6465-80R\0166g-105-6475-20R\0166g-107-6485-40R\0166g-109-6495-20R\r6g-11-6005-40R\0176g-111-6505-160R\0166g-113-6515-20R\0166g-115-6525-40R\0166g-117-6535-20R\0166g-119-6545-80R\0166g-121-6555-20R\0166g-123-6565-40R\0166g-125-6575-20R\0166g-129-6595-20R\r6g-13-6015-20R\0166g-131-6605-40R\0166g-133-6615-20R\0166g-135-6625-80R\0166g-137-6635-20R\0166g-139-6645-40R\0166g-141-6655-20R\0176g-143-6665-160R\0166g-145-6675-20R\0166g-147-6685-40R\0166g-149-6695-20R\0166g-15-6025-160R\0166g-151-6705-80R\0166g-153-6715-20R\0166g-155-6725-40R\0166g-157-6735-20R\0176g-159-6745-320R\0166g-161-6755-20R\0166g-163-6765-40R\0166g-165-6775-20R\0166g-167-6785-80R\0166g-169-6795-20R\r6g-17-6035-20R\0166g-171-6805-40R\0166g-173-6815-20R\0176g-175-6825-160R\0166g-177-6835-20R\0166g-179-6845-40R\0166g-181-6855-20R\0166g-183-6865-80R\0166g-185-6875-20R\0166g-187-6885-40R\0166g-189-6895-20R\r6g-19-6045-40R\0166g-193-6915-20R\0166g-195-6925-40R\0166g-197-6935-20R\0166g-199-6945-80R\0166g-201-6955-20R\0166g-203-6965-40R\0166g-205-6975-20R\0176g-207-6985-160R\0166g-209-6995-20R\r6g-21-6055-20R\0166g-211-7005-40R\0166g-213-7015-20R\0166g-215-7025-80R\0166g-217-7035-20R\0166g-219-7045-40R\0166g-221-7055-20R\0166g-225-7075-20R\0166g-227-7085-40R\0166g-229-7095-20R\r6g-23-6065-80R\0166g-233-7115-20R\r6g-25-6075-20R\r6g-27-6085-40R\r6g-29-6095-20R\0146g-3-5965-40R\0166g-31-6105-320R\r6g-33-6115-20R\r6g-35-6125-40R\r6g-37-6135-20R\r6g-39-6145-80R\r6g-41-6155-20R\r6g-43-6165-40R\r6g-45-6175-20R\0166g-47-6185-160R\r6g-49-6195-20R\0146g-5-5975-20R\r6g-51-6205-40R\r6g-53-6215-20R\r6g-55-6225-80R\r6g-57-6235-20R\r6g-59-6245-40R\r6g-61-6255-20R\r6g-65-6275-20R\r6g-67-6285-40R\r6g-69-6295-20R\0146g-7-5985-80R\r6g-71-6305-80R\r6g-73-6315-20R\r6g-75-6325-40R\r6g-77-6335-20R\0166g-79-6345-160R\r6g-81-6355-20R\r6g-83-6365-40R\r6g-85-6375-20R\r6g-87-6385-80R\r6g-89-6395-20R\0146g-9-5995-20R\r6g-91-6405-40R\r6g-93-6415-20R\0166g-95-6425-320R\r6g-97-6435-20R\r6g-99-6445-40'
  _globals['_INTERFACE'].fields_by_name['poe_mode']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['poe_mode']._serialized_options = b'\372B\013r\tR\002pdR\003pse'
  _globals['_INTERFACE'].fields_by_name['poe_type']._loaded_options = None
  _globals['_INTERFACE'].fields_by_name['poe_type']._serialized_options = b'\372B\233\001r\230\001R\021passive-24v-2pairR\021passive-24v-4pairR\021passive-48v-2pairR\021passive-48v-4pairR\021type1-ieee802.3afR\021type2-ieee802.3atR\021type3-ieee802.3btR\021type4-ieee802.3bt'
  _globals['_INVENTORYITEM_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_INVENTORYITEM_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_INVENTORYITEM'].fields_by_name['status']._loaded_options = None
  _globals['_INVENTORYITEM'].fields_by_name['status']._serialized_options = b'\372B=r;R\006activeR\017decommissioningR\006failedR\007offlineR\007plannedR\006staged'
  _globals['_INVENTORYITEMROLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_INVENTORYITEMROLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_L2VPN_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_L2VPN_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_L2VPN'].fields_by_name['type']._loaded_options = None
  _globals['_L2VPN'].fields_by_name['type']._serialized_options = b'\372BursR\006ep-lanR\007ep-treeR\003eplR\007evp-lanR\010evp-treeR\004evplR\tevpn-vpwsR\tmpls-evpnR\010pbb-evpnR\003spbR\004vplsR\004vpwsR\005vxlanR\nvxlan-evpn'
  _globals['_L2VPN'].fields_by_name['status']._loaded_options = None
  _globals['_L2VPN'].fields_by_name['status']._serialized_options = b'\372B$r\"R\006activeR\017decommissioningR\007planned'
  _globals['_L2VPNTERMINATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_L2VPNTERMINATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_LOCATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_LOCATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_LOCATION'].fields_by_name['status']._loaded_options = None
  _globals['_LOCATION'].fields_by_name['status']._serialized_options = b'\372B6r4R\006activeR\017decommissioningR\007plannedR\007retiredR\007staging'
  _globals['_MACADDRESS_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MACADDRESS_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_MANUFACTURER_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MANUFACTURER_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_MODULE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MODULE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_MODULE'].fields_by_name['status']._loaded_options = None
  _globals['_MODULE'].fields_by_name['status']._serialized_options = b'\372B=r;R\006activeR\017decommissioningR\006failedR\007offlineR\007plannedR\006staged'
  _globals['_MODULEBAY_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MODULEBAY_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_MODULETYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MODULETYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_MODULETYPE'].fields_by_name['airflow']._loaded_options = None
  _globals['_MODULETYPE'].fields_by_name['airflow']._serialized_options = b'\372BUrSR\rfront-to-rearR\rleft-to-rightR\007passiveR\rrear-to-frontR\rright-to-leftR\014side-to-rear'
  _globals['_MODULETYPE'].fields_by_name['weight_unit']._loaded_options = None
  _globals['_MODULETYPE'].fields_by_name['weight_unit']._serialized_options = b'\372B\021r\017R\001gR\002kgR\002lbR\002oz'
  _globals['_PLATFORM_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_PLATFORM_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_POWERFEED_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_POWERFEED_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_POWERFEED'].fields_by_name['status']._loaded_options = None
  _globals['_POWERFEED'].fields_by_name['status']._serialized_options = b'\372B$r\"R\006activeR\006failedR\007offlineR\007planned'
  _globals['_POWERFEED'].fields_by_name['type']._loaded_options = None
  _globals['_POWERFEED'].fields_by_name['type']._serialized_options = b'\372B\026r\024R\007primaryR\tredundant'
  _globals['_POWERFEED'].fields_by_name['supply']._loaded_options = None
  _globals['_POWERFEED'].fields_by_name['supply']._serialized_options = b'\372B\nr\010R\002acR\002dc'
  _globals['_POWERFEED'].fields_by_name['phase']._loaded_options = None
  _globals['_POWERFEED'].fields_by_name['phase']._serialized_options = b'\372B\035r\033R\014single-phaseR\013three-phase'
  _globals['_POWEROUTLET_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_POWEROUTLET_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_POWEROUTLET'].fields_by_name['type']._loaded_options = None
  _globals['_POWEROUTLET'].fields_by_name['type']._serialized_options = b'\372B\275\nr\272\nR\007CS6360CR\007CS6364CR\007CS8164CR\007CS8264CR\007CS8364CR\007CS8464CR\013dc-terminalR\teaton-c39R\thardwiredR\007hdot-cxR\021iec-60309-2p-e-4hR\021iec-60309-2p-e-6hR\021iec-60309-2p-e-9hR\021iec-60309-3p-e-4hR\021iec-60309-3p-e-6hR\021iec-60309-3p-e-9hR\023iec-60309-3p-n-e-4hR\023iec-60309-3p-n-e-6hR\023iec-60309-3p-n-e-9hR\022iec-60309-p-n-e-4hR\022iec-60309-p-n-e-6hR\022iec-60309-p-n-e-9hR\riec-60320-c13R\riec-60320-c15R\riec-60320-c19R\riec-60320-c21R\014iec-60320-c5R\014iec-60320-c7R\013iec-60906-1R\005ita-eR\005ita-fR\005ita-gR\005ita-hR\005ita-iR\005ita-jR\005ita-kR\005ita-lR\005ita-mR\021ita-multistandardR\005ita-nR\005ita-oR\023molex-micro-fit-1x2R\023molex-micro-fit-2x2R\023molex-micro-fit-2x4R\rnbr-14136-10aR\rnbr-14136-20aR\nnema-1-15rR\013nema-10-30rR\013nema-10-50rR\013nema-14-20rR\013nema-14-30rR\013nema-14-50rR\013nema-14-60rR\013nema-15-15rR\013nema-15-20rR\013nema-15-30rR\013nema-15-50rR\013nema-15-60rR\nnema-5-15rR\nnema-5-20rR\nnema-5-30rR\nnema-5-50rR\nnema-6-15rR\nnema-6-20rR\nnema-6-30rR\nnema-6-50rR\013nema-l1-15rR\014nema-l10-30rR\014nema-l14-20rR\014nema-l14-30rR\014nema-l14-50rR\014nema-l14-60rR\014nema-l15-20rR\014nema-l15-30rR\014nema-l15-50rR\014nema-l15-60rR\014nema-l21-20rR\014nema-l21-30rR\014nema-l22-20rR\014nema-l22-30rR\013nema-l5-15rR\013nema-l5-20rR\013nema-l5-30rR\013nema-l5-50rR\013nema-l6-15rR\013nema-l6-20rR\013nema-l6-30rR\013nema-l6-50rR\024neutrik-powercon-20aR\024neutrik-powercon-32aR\026neutrik-powercon-true1R\032neutrik-powercon-true1-topR\005otherR\nsaf-d-gridR\023ubiquiti-smartpowerR\005usb-aR\005usb-cR\013usb-micro-b'
  _globals['_POWEROUTLET'].fields_by_name['feed_leg']._loaded_options = None
  _globals['_POWEROUTLET'].fields_by_name['feed_leg']._serialized_options = b'\372B\013r\tR\001AR\001BR\001C'
  _globals['_POWEROUTLET'].fields_by_name['status']._loaded_options = None
  _globals['_POWEROUTLET'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\010disabledR\007enabledR\006faulty'
  _globals['_POWERPANEL_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_POWERPANEL_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_POWERPORT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_POWERPORT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_POWERPORT'].fields_by_name['type']._loaded_options = None
  _globals['_POWERPORT'].fields_by_name['type']._serialized_options = b'\372B\365\nr\362\nR\007cs6361cR\007cs6365cR\007cs8165cR\007cs8265cR\007cs8365cR\007cs8465cR\013dc-terminalR\thardwiredR\021iec-60309-2p-e-4hR\021iec-60309-2p-e-6hR\021iec-60309-2p-e-9hR\021iec-60309-3p-e-4hR\021iec-60309-3p-e-6hR\021iec-60309-3p-e-9hR\023iec-60309-3p-n-e-4hR\023iec-60309-3p-n-e-6hR\023iec-60309-3p-n-e-9hR\022iec-60309-p-n-e-4hR\022iec-60309-p-n-e-6hR\022iec-60309-p-n-e-9hR\riec-60320-c14R\riec-60320-c16R\riec-60320-c20R\riec-60320-c22R\014iec-60320-c6R\014iec-60320-c8R\013iec-60906-1R\005ita-cR\005ita-eR\006ita-efR\005ita-fR\005ita-gR\005ita-hR\005ita-iR\005ita-jR\005ita-kR\005ita-lR\005ita-mR\005ita-nR\005ita-oR\023molex-micro-fit-1x2R\023molex-micro-fit-2x2R\023molex-micro-fit-2x4R\rnbr-14136-10aR\rnbr-14136-20aR\nnema-1-15pR\013nema-10-30pR\013nema-10-50pR\013nema-14-20pR\013nema-14-30pR\013nema-14-50pR\013nema-14-60pR\013nema-15-15pR\013nema-15-20pR\013nema-15-30pR\013nema-15-50pR\013nema-15-60pR\nnema-5-15pR\nnema-5-20pR\nnema-5-30pR\nnema-5-50pR\nnema-6-15pR\nnema-6-20pR\nnema-6-30pR\nnema-6-50pR\013nema-l1-15pR\014nema-l10-30pR\014nema-l14-20pR\014nema-l14-30pR\014nema-l14-50pR\014nema-l14-60pR\014nema-l15-20pR\014nema-l15-30pR\014nema-l15-50pR\014nema-l15-60pR\014nema-l21-20pR\014nema-l21-30pR\014nema-l22-20pR\014nema-l22-30pR\013nema-l5-15pR\013nema-l5-20pR\013nema-l5-30pR\013nema-l5-50pR\013nema-l6-15pR\013nema-l6-20pR\013nema-l6-30pR\013nema-l6-50pR\023neutrik-powercon-20R\023neutrik-powercon-32R\026neutrik-powercon-true1R\032neutrik-powercon-true1-topR\005otherR\nsaf-d-gridR\023ubiquiti-smartpowerR\007usb-3-bR\rusb-3-micro-bR\005usb-aR\005usb-bR\005usb-cR\013usb-micro-aR\014usb-micro-abR\013usb-micro-bR\nusb-mini-aR\nusb-mini-b'
  _globals['_PREFIX_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_PREFIX_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_PREFIX'].fields_by_name['status']._loaded_options = None
  _globals['_PREFIX'].fields_by_name['status']._serialized_options = b'\372B+r)R\006activeR\tcontainerR\ndeprecatedR\010reserved'
  _globals['_PROVIDER_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_PROVIDER_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_PROVIDERACCOUNT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_PROVIDERACCOUNT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_PROVIDERNETWORK_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_PROVIDERNETWORK_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RIR_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_RIR_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RACK_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_RACK_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RACK'].fields_by_name['status']._loaded_options = None
  _globals['_RACK'].fields_by_name['status']._serialized_options = b'\372B4r2R\006activeR\tavailableR\ndeprecatedR\007plannedR\010reserved'
  _globals['_RACK'].fields_by_name['form_factor']._loaded_options = None
  _globals['_RACK'].fields_by_name['form_factor']._serialized_options = b'\372BtrrR\0142-post-frameR\0164-post-cabinetR\0144-post-frameR\014wall-cabinetR\025wall-cabinet-verticalR\nwall-frameR\023wall-frame-vertical'
  _globals['_RACK'].fields_by_name['width']._loaded_options = None
  _globals['_RACK'].fields_by_name['width']._serialized_options = b'\372B\n\"\0100\n0\0230\0250\027'
  _globals['_RACK'].fields_by_name['weight_unit']._loaded_options = None
  _globals['_RACK'].fields_by_name['weight_unit']._serialized_options = b'\372B\021r\017R\001gR\002kgR\002lbR\002oz'
  _globals['_RACK'].fields_by_name['outer_unit']._loaded_options = None
  _globals['_RACK'].fields_by_name['outer_unit']._serialized_options = b'\372B\nr\010R\002inR\002mm'
  _globals['_RACK'].fields_by_name['airflow']._loaded_options = None
  _globals['_RACK'].fields_by_name['airflow']._serialized_options = b'\372B r\036R\rfront-to-rearR\rrear-to-front'
  _globals['_RACKRESERVATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_RACKRESERVATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RACKROLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_RACKROLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RACKTYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_RACKTYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_RACKTYPE'].fields_by_name['form_factor']._loaded_options = None
  _globals['_RACKTYPE'].fields_by_name['form_factor']._serialized_options = b'\372BtrrR\0142-post-frameR\0164-post-cabinetR\0144-post-frameR\014wall-cabinetR\025wall-cabinet-verticalR\nwall-frameR\023wall-frame-vertical'
  _globals['_RACKTYPE'].fields_by_name['width']._loaded_options = None
  _globals['_RACKTYPE'].fields_by_name['width']._serialized_options = b'\372B\n\"\0100\n0\0230\0250\027'
  _globals['_RACKTYPE'].fields_by_name['outer_unit']._loaded_options = None
  _globals['_RACKTYPE'].fields_by_name['outer_unit']._serialized_options = b'\372B\nr\010R\002inR\002mm'
  _globals['_RACKTYPE'].fields_by_name['weight_unit']._loaded_options = None
  _globals['_RACKTYPE'].fields_by_name['weight_unit']._serialized_options = b'\372B\021r\017R\001gR\002kgR\002lbR\002oz'
  _globals['_REARPORT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_REARPORT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_REARPORT'].fields_by_name['type']._loaded_options = None
  _globals['_REARPORT'].fields_by_name['type']._serialized_options = b'\372B\253\003r\250\003R\t110-punchR\0044p2cR\0044p4cR\0046p2cR\0046p4cR\0046p6cR\0048p2cR\0048p4cR\0048p6cR\0048p8cR\003bncR\002csR\001fR\002fcR\006fc-apcR\005fc-pcR\006fc-upcR\004gg45R\002lcR\006lc-apcR\005lc-pcR\006lc-upcR\003lshR\007lsh-apcR\006lsh-pcR\007lsh-upcR\003lx5R\007lx5-apcR\006lx5-pcR\007lx5-upcR\003mpoR\005mrj21R\004mtrjR\001nR\005otherR\002scR\006sc-apcR\005sc-pcR\006sc-upcR\007sma-905R\007sma-906R\002snR\006spliceR\002stR\007tera-1pR\007tera-2pR\007tera-4pR\006urm-p2R\006urm-p4R\006urm-p8R\005usb-aR\005usb-bR\005usb-cR\013usb-micro-aR\014usb-micro-abR\013usb-micro-bR\nusb-mini-aR\nusb-mini-b'
  _globals['_REGION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_REGION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_ROLE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_ROLE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_ROUTETARGET_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_ROUTETARGET_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_SERVICE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICE'].fields_by_name['device']._loaded_options = None
  _globals['_SERVICE'].fields_by_name['device']._serialized_options = b'\030\001'
  _globals['_SERVICE'].fields_by_name['virtual_machine']._loaded_options = None
  _globals['_SERVICE'].fields_by_name['virtual_machine']._serialized_options = b'\030\001'
  _globals['_SERVICE'].fields_by_name['protocol']._loaded_options = None
  _globals['_SERVICE'].fields_by_name['protocol']._serialized_options = b'\372B\022r\020R\004sctpR\003tcpR\003udp'
  _globals['_SITE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_SITE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_SITE'].fields_by_name['status']._loaded_options = None
  _globals['_SITE'].fields_by_name['status']._serialized_options = b'\372B6r4R\006activeR\017decommissioningR\007plannedR\007retiredR\007staging'
  _globals['_SITEGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_SITEGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TAG'].fields_by_name['object_types']._loaded_options = None
  _globals['_TAG'].fields_by_name['object_types']._serialized_options = b'\372B\372\014\222\001\366\014\"\363\014r\360\014R\020circuits.circuitR\025circuits.circuitgroupR\037circuits.circuitgroupassignmentR\033circuits.circuitterminationR\024circuits.circuittypeR\021circuits.providerR\030circuits.provideraccountR\030circuits.providernetworkR\027circuits.virtualcircuitR\"circuits.virtualcircuitterminationR\033circuits.virtualcircuittypeR\ndcim.cableR\020dcim.consoleportR\026dcim.consoleserverportR\013dcim.deviceR\016dcim.devicebayR\017dcim.deviceroleR\017dcim.devicetypeR\016dcim.frontportR\016dcim.interfaceR\022dcim.inventoryitemR\026dcim.inventoryitemroleR\rdcim.locationR\017dcim.macaddressR\021dcim.manufacturerR\013dcim.moduleR\016dcim.modulebayR\017dcim.moduletypeR\026dcim.moduletypeprofileR\rdcim.platformR\016dcim.powerfeedR\020dcim.poweroutletR\017dcim.powerpanelR\016dcim.powerportR\tdcim.rackR\024dcim.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\013dcim.regionR\tdcim.siteR\016dcim.sitegroupR\023dcim.virtualchassisR\031dcim.virtualdevicecontextR\023extras.journalentryR\016ipam.aggregateR\010ipam.asnR\ripam.asnrangeR\016ipam.fhrpgroupR\016ipam.ipaddressR\014ipam.iprangeR\013ipam.prefixR\010ipam.rirR\tipam.roleR\020ipam.routetargetR\014ipam.serviceR\tipam.vlanR\016ipam.vlangroupR\032ipam.vlantranslationpolicyR\030ipam.vlantranslationruleR\010ipam.vrfR\017tenancy.contactR\031tenancy.contactassignmentR\024tenancy.contactgroupR\023tenancy.contactroleR\016tenancy.tenantR\023tenancy.tenantgroupR\026virtualization.clusterR\033virtualization.clustergroupR\032virtualization.clustertypeR\032virtualization.virtualdiskR\035virtualization.virtualmachineR\032virtualization.vminterfaceR\rvpn.ikepolicyR\017vpn.ikeproposalR\017vpn.ipsecpolicyR\020vpn.ipsecprofileR\021vpn.ipsecproposalR\tvpn.l2vpnR\024vpn.l2vpnterminationR\nvpn.tunnelR\017vpn.tunnelgroupR\025vpn.tunnelterminationR\024wireless.wirelesslanR\031wireless.wirelesslangroupR\025wireless.wirelesslink'
  _globals['_TENANT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_TENANT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TENANTGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_TENANTGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TUNNEL_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_TUNNEL_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TUNNEL'].fields_by_name['status']._loaded_options = None
  _globals['_TUNNEL'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\010disabledR\007planned'
  _globals['_TUNNEL'].fields_by_name['encapsulation']._loaded_options = None
  _globals['_TUNNEL'].fields_by_name['encapsulation']._serialized_options = b'\372BMrKR\003greR\005ip-ipR\017ipsec-transportR\014ipsec-tunnelR\004l2tpR\007openvpnR\004pptpR\twireguard'
  _globals['_TUNNELGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_TUNNELGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TUNNELTERMINATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_TUNNELTERMINATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_TUNNELTERMINATION'].fields_by_name['role']._loaded_options = None
  _globals['_TUNNELTERMINATION'].fields_by_name['role']._serialized_options = b'\372B\024r\022R\003hubR\004peerR\005spoke'
  _globals['_VLAN_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VLAN_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VLAN'].fields_by_name['status']._loaded_options = None
  _globals['_VLAN'].fields_by_name['status']._serialized_options = b'\372B r\036R\006activeR\ndeprecatedR\010reserved'
  _globals['_VLAN'].fields_by_name['qinq_role']._loaded_options = None
  _globals['_VLAN'].fields_by_name['qinq_role']._serialized_options = b'\372B\020r\016R\005cvlanR\005svlan'
  _globals['_VLANGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VLANGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VMINTERFACE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VMINTERFACE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VMINTERFACE'].fields_by_name['mode']._loaded_options = None
  _globals['_VMINTERFACE'].fields_by_name['mode']._serialized_options = b'\372B&r$R\006accessR\006q-in-qR\006taggedR\ntagged-all'
  _globals['_VRF_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VRF_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALCHASSIS_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALCHASSIS_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALCIRCUIT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALCIRCUIT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALCIRCUIT'].fields_by_name['status']._loaded_options = None
  _globals['_VIRTUALCIRCUIT'].fields_by_name['status']._serialized_options = b'\372BJrHR\006activeR\016decommissionedR\016deprovisioningR\007offlineR\007plannedR\014provisioning'
  _globals['_VIRTUALCIRCUITTERMINATION_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALCIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALCIRCUITTERMINATION'].fields_by_name['role']._loaded_options = None
  _globals['_VIRTUALCIRCUITTERMINATION'].fields_by_name['role']._serialized_options = b'\372B\024r\022R\003hubR\004peerR\005spoke'
  _globals['_VIRTUALCIRCUITTYPE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALCIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALDEVICECONTEXT_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALDEVICECONTEXT_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALDEVICECONTEXT'].fields_by_name['status']._loaded_options = None
  _globals['_VIRTUALDEVICECONTEXT'].fields_by_name['status']._serialized_options = b'\372B\034r\032R\006activeR\007offlineR\007planned'
  _globals['_VIRTUALDISK_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALDISK_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALMACHINE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_VIRTUALMACHINE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_VIRTUALMACHINE'].fields_by_name['status']._loaded_options = None
  _globals['_VIRTUALMACHINE'].fields_by_name['status']._serialized_options = b'\372BErCR\006activeR\017decommissioningR\006failedR\007offlineR\006pausedR\007plannedR\006staged'
  _globals['_WIRELESSLAN_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_WIRELESSLAN_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_WIRELESSLAN'].fields_by_name['status']._loaded_options = None
  _globals['_WIRELESSLAN'].fields_by_name['status']._serialized_options = b'\372B*r(R\006activeR\ndeprecatedR\010disabledR\010reserved'
  _globals['_WIRELESSLAN'].fields_by_name['auth_type']._loaded_options = None
  _globals['_WIRELESSLAN'].fields_by_name['auth_type']._serialized_options = b'\372B+r)R\004openR\003wepR\016wpa-enterpriseR\014wpa-personal'
  _globals['_WIRELESSLAN'].fields_by_name['auth_cipher']._loaded_options = None
  _globals['_WIRELESSLAN'].fields_by_name['auth_cipher']._serialized_options = b'\372B\023r\021R\003aesR\004autoR\004tkip'
  _globals['_WIRELESSLANGROUP_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_WIRELESSLANGROUP_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_WIRELESSLINK_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_WIRELESSLINK_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_WIRELESSLINK'].fields_by_name['status']._loaded_options = None
  _globals['_WIRELESSLINK'].fields_by_name['status']._serialized_options = b'\372B\'r%R\tconnectedR\017decommissioningR\007planned'
  _globals['_WIRELESSLINK'].fields_by_name['auth_type']._loaded_options = None
  _globals['_WIRELESSLINK'].fields_by_name['auth_type']._serialized_options = b'\372B+r)R\004openR\003wepR\016wpa-enterpriseR\014wpa-personal'
  _globals['_WIRELESSLINK'].fields_by_name['auth_cipher']._loaded_options = None
  _globals['_WIRELESSLINK'].fields_by_name['auth_cipher']._serialized_options = b'\372B\023r\021R\003aesR\004autoR\004tkip'
  _globals['_WIRELESSLINK'].fields_by_name['distance_unit']._loaded_options = None
  _globals['_WIRELESSLINK'].fields_by_name['distance_unit']._serialized_options = b'\372B\021r\017R\002ftR\002kmR\001mR\002mi'
  _globals['_CUSTOMFIELD'].fields_by_name['type']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['type']._serialized_options = b'\372BrrpR\007booleanR\004dateR\010datetimeR\007decimalR\007integerR\004jsonR\010longtextR\013multiobjectR\013multiselectR\006objectR\006selectR\004textR\003url'
  _globals['_CUSTOMFIELD'].fields_by_name['related_object_type']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['related_object_type']._serialized_options = b'\372B\204\016r\201\016R\020circuits.circuitR\025circuits.circuitgroupR\037circuits.circuitgroupassignmentR\033circuits.circuitterminationR\024circuits.circuittypeR\021circuits.providerR\030circuits.provideraccountR\030circuits.providernetworkR\027circuits.virtualcircuitR\"circuits.virtualcircuitterminationR\033circuits.virtualcircuittypeR\ndcim.cableR\016dcim.cablepathR\025dcim.cableterminationR\020dcim.consoleportR\026dcim.consoleserverportR\013dcim.deviceR\016dcim.devicebayR\017dcim.deviceroleR\017dcim.devicetypeR\016dcim.frontportR\016dcim.interfaceR\022dcim.inventoryitemR\026dcim.inventoryitemroleR\rdcim.locationR\017dcim.macaddressR\021dcim.manufacturerR\013dcim.moduleR\016dcim.modulebayR\017dcim.moduletypeR\026dcim.moduletypeprofileR\rdcim.platformR\016dcim.powerfeedR\020dcim.poweroutletR\017dcim.powerpanelR\016dcim.powerportR\tdcim.rackR\024dcim.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\013dcim.regionR\tdcim.siteR\016dcim.sitegroupR\023dcim.virtualchassisR\031dcim.virtualdevicecontextR\022extras.customfieldR\033extras.customfieldchoicesetR\021extras.customlinkR\023extras.journalentryR\nextras.tagR\016ipam.aggregateR\010ipam.asnR\ripam.asnrangeR\016ipam.fhrpgroupR\030ipam.fhrpgroupassignmentR\016ipam.ipaddressR\014ipam.iprangeR\013ipam.prefixR\010ipam.rirR\tipam.roleR\020ipam.routetargetR\014ipam.serviceR\tipam.vlanR\016ipam.vlangroupR\032ipam.vlantranslationpolicyR\030ipam.vlantranslationruleR\010ipam.vrfR\017tenancy.contactR\031tenancy.contactassignmentR\024tenancy.contactgroupR\023tenancy.contactroleR\016tenancy.tenantR\023tenancy.tenantgroupR\026virtualization.clusterR\033virtualization.clustergroupR\032virtualization.clustertypeR\032virtualization.virtualdiskR\035virtualization.virtualmachineR\032virtualization.vminterfaceR\rvpn.ikepolicyR\017vpn.ikeproposalR\017vpn.ipsecpolicyR\020vpn.ipsecprofileR\021vpn.ipsecproposalR\tvpn.l2vpnR\024vpn.l2vpnterminationR\nvpn.tunnelR\017vpn.tunnelgroupR\025vpn.tunnelterminationR\024wireless.wirelesslanR\031wireless.wirelesslangroupR\025wireless.wirelesslink'
  _globals['_CUSTOMFIELD'].fields_by_name['filter_logic']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['filter_logic']._serialized_options = b'\372B\032r\030R\010disabledR\005exactR\005loose'
  _globals['_CUSTOMFIELD'].fields_by_name['ui_visible']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['ui_visible']._serialized_options = b'\372B\032r\030R\006alwaysR\006hiddenR\006if-set'
  _globals['_CUSTOMFIELD'].fields_by_name['ui_editable']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['ui_editable']._serialized_options = b'\372B\023r\021R\006hiddenR\002noR\003yes'
  _globals['_CUSTOMFIELD'].fields_by_name['object_types']._loaded_options = None
  _globals['_CUSTOMFIELD'].fields_by_name['object_types']._serialized_options = b'\372B\372\014\222\001\366\014\"\363\014r\360\014R\020circuits.circuitR\025circuits.circuitgroupR\037circuits.circuitgroupassignmentR\033circuits.circuitterminationR\024circuits.circuittypeR\021circuits.providerR\030circuits.provideraccountR\030circuits.providernetworkR\027circuits.virtualcircuitR\"circuits.virtualcircuitterminationR\033circuits.virtualcircuittypeR\ndcim.cableR\020dcim.consoleportR\026dcim.consoleserverportR\013dcim.deviceR\016dcim.devicebayR\017dcim.deviceroleR\017dcim.devicetypeR\016dcim.frontportR\016dcim.interfaceR\022dcim.inventoryitemR\026dcim.inventoryitemroleR\rdcim.locationR\017dcim.macaddressR\021dcim.manufacturerR\013dcim.moduleR\016dcim.modulebayR\017dcim.moduletypeR\026dcim.moduletypeprofileR\rdcim.platformR\016dcim.powerfeedR\020dcim.poweroutletR\017dcim.powerpanelR\016dcim.powerportR\tdcim.rackR\024dcim.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\013dcim.regionR\tdcim.siteR\016dcim.sitegroupR\023dcim.virtualchassisR\031dcim.virtualdevicecontextR\023extras.journalentryR\016ipam.aggregateR\010ipam.asnR\ripam.asnrangeR\016ipam.fhrpgroupR\016ipam.ipaddressR\014ipam.iprangeR\013ipam.prefixR\010ipam.rirR\tipam.roleR\020ipam.routetargetR\014ipam.serviceR\tipam.vlanR\016ipam.vlangroupR\032ipam.vlantranslationpolicyR\030ipam.vlantranslationruleR\010ipam.vrfR\017tenancy.contactR\031tenancy.contactassignmentR\024tenancy.contactgroupR\023tenancy.contactroleR\016tenancy.tenantR\023tenancy.tenantgroupR\026virtualization.clusterR\033virtualization.clustergroupR\032virtualization.clustertypeR\032virtualization.virtualdiskR\035virtualization.virtualmachineR\032virtualization.vminterfaceR\rvpn.ikepolicyR\017vpn.ikeproposalR\017vpn.ipsecpolicyR\020vpn.ipsecprofileR\021vpn.ipsecproposalR\tvpn.l2vpnR\024vpn.l2vpnterminationR\nvpn.tunnelR\017vpn.tunnelgroupR\025vpn.tunnelterminationR\024wireless.wirelesslanR\031wireless.wirelesslangroupR\025wireless.wirelesslink'
  _globals['_CUSTOMFIELDCHOICESET'].fields_by_name['base_choices']._loaded_options = None
  _globals['_CUSTOMFIELDCHOICESET'].fields_by_name['base_choices']._serialized_options = b'\372B\035r\033R\004IATAR\010ISO_3166R\tUN_LOCODE'
  _globals['_JOURNALENTRY_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_JOURNALENTRY_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_JOURNALENTRY'].fields_by_name['kind']._loaded_options = None
  _globals['_JOURNALENTRY'].fields_by_name['kind']._serialized_options = b'\372B\"r R\006dangerR\004infoR\007successR\007warning'
  _globals['_MODULETYPEPROFILE_CUSTOMFIELDSENTRY']._loaded_options = None
  _globals['_MODULETYPEPROFILE_CUSTOMFIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CUSTOMLINK'].fields_by_name['button_class']._loaded_options = None
  _globals['_CUSTOMLINK'].fields_by_name['button_class']._serialized_options = b'\372BormR\005blackR\004blueR\004cyanR\007defaultR\nghost-darkR\004grayR\005greenR\006indigoR\006orangeR\004pinkR\006purpleR\003redR\004tealR\005whiteR\006yellow'
  _globals['_CUSTOMLINK'].fields_by_name['object_types']._loaded_options = None
  _globals['_CUSTOMLINK'].fields_by_name['object_types']._serialized_options = b'\372B\276\014\222\001\272\014\"\267\014r\264\014R\020circuits.circuitR\025circuits.circuitgroupR\033circuits.circuitterminationR\024circuits.circuittypeR\021circuits.providerR\030circuits.provideraccountR\030circuits.providernetworkR\027circuits.virtualcircuitR\"circuits.virtualcircuitterminationR\033circuits.virtualcircuittypeR\ndcim.cableR\020dcim.consoleportR\026dcim.consoleserverportR\013dcim.deviceR\016dcim.devicebayR\017dcim.deviceroleR\017dcim.devicetypeR\016dcim.frontportR\016dcim.interfaceR\022dcim.inventoryitemR\026dcim.inventoryitemroleR\rdcim.locationR\017dcim.macaddressR\021dcim.manufacturerR\013dcim.moduleR\016dcim.modulebayR\017dcim.moduletypeR\026dcim.moduletypeprofileR\rdcim.platformR\016dcim.powerfeedR\020dcim.poweroutletR\017dcim.powerpanelR\016dcim.powerportR\tdcim.rackR\024dcim.rackreservationR\rdcim.rackroleR\rdcim.racktypeR\rdcim.rearportR\013dcim.regionR\tdcim.siteR\016dcim.sitegroupR\023dcim.virtualchassisR\031dcim.virtualdevicecontextR\023extras.journalentryR\016ipam.aggregateR\010ipam.asnR\ripam.asnrangeR\016ipam.fhrpgroupR\016ipam.ipaddressR\014ipam.iprangeR\013ipam.prefixR\010ipam.rirR\tipam.roleR\020ipam.routetargetR\014ipam.serviceR\tipam.vlanR\016ipam.vlangroupR\032ipam.vlantranslationpolicyR\030ipam.vlantranslationruleR\010ipam.vrfR\017tenancy.contactR\024tenancy.contactgroupR\023tenancy.contactroleR\016tenancy.tenantR\023tenancy.tenantgroupR\026virtualization.clusterR\033virtualization.clustergroupR\032virtualization.clustertypeR\032virtualization.virtualdiskR\035virtualization.virtualmachineR\032virtualization.vminterfaceR\rvpn.ikepolicyR\017vpn.ikeproposalR\017vpn.ipsecpolicyR\020vpn.ipsecprofileR\021vpn.ipsecproposalR\tvpn.l2vpnR\024vpn.l2vpnterminationR\nvpn.tunnelR\017vpn.tunnelgroupR\025vpn.tunnelterminationR\024wireless.wirelesslanR\031wireless.wirelesslangroupR\025wireless.wirelesslink'
  _globals['_ENTITY']._serialized_start=96
  _globals['_ENTITY']._serialized_end=5709
  _globals['_INGESTREQUEST']._serialized_start=5712
  _globals['_INGESTREQUEST']._serialized_end=6068
  _globals['_INGESTRESPONSE']._serialized_start=6070
  _globals['_INGESTRESPONSE']._serialized_end=6110
  _globals['_ASN']._serialized_start=6113
  _globals['_ASN']._serialized_end=6539
  _globals['_ASN_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_ASN_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_ASNRANGE']._serialized_start=6542
  _globals['_ASNRANGE']._serialized_end=6981
  _globals['_ASNRANGE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_ASNRANGE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_AGGREGATE']._serialized_start=6984
  _globals['_AGGREGATE']._serialized_end=7494
  _globals['_AGGREGATE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_AGGREGATE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CABLE']._serialized_start=7497
  _globals['_CABLE']._serialized_end=8506
  _globals['_CABLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CABLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CABLEPATH']._serialized_start=8509
  _globals['_CABLEPATH']._serialized_end=8667
  _globals['_CABLETERMINATION']._serialized_start=8670
  _globals['_CABLETERMINATION']._serialized_end=9537
  _globals['_CIRCUIT']._serialized_start=9540
  _globals['_CIRCUIT']._serialized_end=10666
  _globals['_CIRCUIT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CIRCUIT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CIRCUITGROUP']._serialized_start=10669
  _globals['_CIRCUITGROUP']._serialized_end=11043
  _globals['_CIRCUITGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CIRCUITGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CIRCUITGROUPASSIGNMENT']._serialized_start=11046
  _globals['_CIRCUITGROUPASSIGNMENT']._serialized_end=11396
  _globals['_CIRCUITTERMINATION']._serialized_start=11399
  _globals['_CIRCUITTERMINATION']._serialized_end=12435
  _globals['_CIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CIRCUITTYPE']._serialized_start=12438
  _globals['_CIRCUITTYPE']._serialized_end=12789
  _globals['_CIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CLUSTER']._serialized_start=12792
  _globals['_CLUSTER']._serialized_end=13624
  _globals['_CLUSTER_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CLUSTER_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CLUSTERGROUP']._serialized_start=13627
  _globals['_CLUSTERGROUP']._serialized_end=13943
  _globals['_CLUSTERGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CLUSTERGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CLUSTERTYPE']._serialized_start=13946
  _globals['_CLUSTERTYPE']._serialized_end=14260
  _globals['_CLUSTERTYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CLUSTERTYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONSOLEPORT']._serialized_start=14263
  _globals['_CONSOLEPORT']._serialized_end=15012
  _globals['_CONSOLEPORT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONSOLEPORT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONSOLESERVERPORT']._serialized_start=15015
  _globals['_CONSOLESERVERPORT']._serialized_end=15776
  _globals['_CONSOLESERVERPORT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONSOLESERVERPORT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONTACT']._serialized_start=15779
  _globals['_CONTACT']._serialized_end=16412
  _globals['_CONTACT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONTACT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONTACTASSIGNMENT']._serialized_start=16415
  _globals['_CONTACTASSIGNMENT']._serialized_end=23585
  _globals['_CONTACTASSIGNMENT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONTACTASSIGNMENT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONTACTGROUP']._serialized_start=23588
  _globals['_CONTACTGROUP']._serialized_end=24014
  _globals['_CONTACTGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONTACTGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CONTACTROLE']._serialized_start=24017
  _globals['_CONTACTROLE']._serialized_end=24331
  _globals['_CONTACTROLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_CONTACTROLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CUSTOMFIELDOBJECTREFERENCE']._serialized_start=24334
  _globals['_CUSTOMFIELDOBJECTREFERENCE']._serialized_end=29897
  _globals['_CUSTOMFIELDVALUE']._serialized_start=29900
  _globals['_CUSTOMFIELDVALUE']._serialized_end=30438
  _globals['_DEVICE']._serialized_start=30441
  _globals['_DEVICE']._serialized_end=32218
  _globals['_DEVICE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_DEVICE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_DEVICEBAY']._serialized_start=32221
  _globals['_DEVICEBAY']._serialized_end=32677
  _globals['_DEVICEBAY_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_DEVICEBAY_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_DEVICEROLE']._serialized_start=32680
  _globals['_DEVICEROLE']._serialized_end=33179
  _globals['_DEVICEROLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_DEVICEROLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_DEVICETYPE']._serialized_start=33182
  _globals['_DEVICETYPE']._serialized_end=34330
  _globals['_DEVICETYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_DEVICETYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_FHRPGROUP']._serialized_start=34333
  _globals['_FHRPGROUP']._serialized_end=34911
  _globals['_FHRPGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_FHRPGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_FHRPGROUPASSIGNMENT']._serialized_start=34914
  _globals['_FHRPGROUPASSIGNMENT']._serialized_end=42311
  _globals['_FRONTPORT']._serialized_start=42314
  _globals['_FRONTPORT']._serialized_end=43419
  _globals['_FRONTPORT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_FRONTPORT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_GENERICOBJECT']._serialized_start=43422
  _globals['_GENERICOBJECT']._serialized_end=50181
  _globals['_IKEPOLICY']._serialized_start=50184
  _globals['_IKEPOLICY']._serialized_end=50729
  _globals['_IKEPOLICY_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IKEPOLICY_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IKEPROPOSAL']._serialized_start=50732
  _globals['_IKEPROPOSAL']._serialized_end=51642
  _globals['_IKEPROPOSAL_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IKEPROPOSAL_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IPADDRESS']._serialized_start=51645
  _globals['_IPADDRESS']._serialized_end=52674
  _globals['_IPADDRESS_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IPADDRESS_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IPRANGE']._serialized_start=52677
  _globals['_IPRANGE']._serialized_end=53413
  _globals['_IPRANGE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IPRANGE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IPSECPOLICY']._serialized_start=53416
  _globals['_IPSECPOLICY']._serialized_end=53914
  _globals['_IPSECPOLICY_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IPSECPOLICY_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IPSECPROFILE']._serialized_start=53917
  _globals['_IPSECPROFILE']._serialized_end=54405
  _globals['_IPSECPROFILE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IPSECPROFILE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_IPSECPROPOSAL']._serialized_start=54408
  _globals['_IPSECPROPOSAL']._serialized_end=55244
  _globals['_IPSECPROPOSAL_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_IPSECPROPOSAL_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_INTERFACE']._serialized_start=55247
  _globals['_INTERFACE']._serialized_end=62389
  _globals['_INTERFACE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_INTERFACE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_INVENTORYITEM']._serialized_start=62392
  _globals['_INVENTORYITEM']._serialized_end=63824
  _globals['_INVENTORYITEM_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_INVENTORYITEM_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_INVENTORYITEMROLE']._serialized_start=63827
  _globals['_INVENTORYITEMROLE']._serialized_end=64190
  _globals['_INVENTORYITEMROLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_INVENTORYITEMROLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_L2VPN']._serialized_start=64193
  _globals['_L2VPN']._serialized_end=65013
  _globals['_L2VPN_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_L2VPN_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_L2VPNTERMINATION']._serialized_start=65016
  _globals['_L2VPNTERMINATION']._serialized_end=73619
  _globals['_L2VPNTERMINATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_L2VPNTERMINATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_LOCATION']._serialized_start=73622
  _globals['_LOCATION']._serialized_end=74275
  _globals['_LOCATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_LOCATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MACADDRESS']._serialized_start=74278
  _globals['_MACADDRESS']._serialized_end=74821
  _globals['_MACADDRESS_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MACADDRESS_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MANUFACTURER']._serialized_start=74824
  _globals['_MANUFACTURER']._serialized_end=75140
  _globals['_MANUFACTURER_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MANUFACTURER_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MODULE']._serialized_start=75143
  _globals['_MODULE']._serialized_end=75796
  _globals['_MODULE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MODULE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MODULEBAY']._serialized_start=75799
  _globals['_MODULEBAY']._serialized_end=76359
  _globals['_MODULEBAY_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MODULEBAY_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MODULETYPE']._serialized_start=76362
  _globals['_MODULETYPE']._serialized_end=77189
  _globals['_MODULETYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MODULETYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_PLATFORM']._serialized_start=77192
  _globals['_PLATFORM']._serialized_end=77582
  _globals['_PLATFORM_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_PLATFORM_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_POWERFEED']._serialized_start=77585
  _globals['_POWERFEED']._serialized_end=78570
  _globals['_POWERFEED_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_POWERFEED_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_POWEROUTLET']._serialized_start=78573
  _globals['_POWEROUTLET']._serialized_end=80694
  _globals['_POWEROUTLET_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_POWEROUTLET_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_POWERPANEL']._serialized_start=80697
  _globals['_POWERPANEL']._serialized_end=81137
  _globals['_POWERPANEL_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_POWERPANEL_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_POWERPORT']._serialized_start=81140
  _globals['_POWERPORT']._serialized_end=83189
  _globals['_POWERPORT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_POWERPORT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_PREFIX']._serialized_start=83192
  _globals['_PREFIX']._serialized_end=84159
  _globals['_PREFIX_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_PREFIX_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_PROVIDER']._serialized_start=84162
  _globals['_PROVIDER']._serialized_end=84606
  _globals['_PROVIDER_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_PROVIDER_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_PROVIDERACCOUNT']._serialized_start=84609
  _globals['_PROVIDERACCOUNT']._serialized_end=85045
  _globals['_PROVIDERACCOUNT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_PROVIDERACCOUNT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_PROVIDERNETWORK']._serialized_start=85048
  _globals['_PROVIDERNETWORK']._serialized_end=85495
  _globals['_PROVIDERNETWORK_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_PROVIDERNETWORK_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_RIR']._serialized_start=85498
  _globals['_RIR']._serialized_end=85847
  _globals['_RIR_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_RIR_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_RACK']._serialized_start=85850
  _globals['_RACK']._serialized_end=87622
  _globals['_RACK_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_RACK_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_RACKRESERVATION']._serialized_start=87625
  _globals['_RACKRESERVATION']._serialized_end=88048
  _globals['_RACKRESERVATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_RACKRESERVATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_RACKROLE']._serialized_start=88051
  _globals['_RACKROLE']._serialized_end=88396
  _globals['_RACKROLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_RACKROLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_RACKTYPE']._serialized_start=88399
  _globals['_RACKTYPE']._serialized_end=89660
  _globals['_RACKTYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_RACKTYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_REARPORT']._serialized_start=89663
  _globals['_REARPORT']._serialized_end=90692
  _globals['_REARPORT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_REARPORT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_REGION']._serialized_start=90695
  _globals['_REGION']._serialized_end=91103
  _globals['_REGION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_REGION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_ROLE']._serialized_start=91106
  _globals['_ROLE']._serialized_end=91446
  _globals['_ROLE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_ROLE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_ROUTETARGET']._serialized_start=91449
  _globals['_ROUTETARGET']._serialized_end=91847
  _globals['_ROUTETARGET_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_ROUTETARGET_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_SERVICE']._serialized_start=91850
  _globals['_SERVICE']._serialized_end=92748
  _globals['_SERVICE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_SERVICE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_SITE']._serialized_start=92751
  _globals['_SITE']._serialized_end=93732
  _globals['_SITE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_SITE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_SITEGROUP']._serialized_start=93735
  _globals['_SITEGROUP']._serialized_end=94152
  _globals['_SITEGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_SITEGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_TAG']._serialized_start=94155
  _globals['_TAG']._serialized_end=96033
  _globals['_TENANT']._serialized_start=96036
  _globals['_TENANT']._serialized_end=96446
  _globals['_TENANT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_TENANT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_TENANTGROUP']._serialized_start=96449
  _globals['_TENANTGROUP']._serialized_end=96872
  _globals['_TENANTGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_TENANTGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_TUNNEL']._serialized_start=96875
  _globals['_TUNNEL']._serialized_end=97633
  _globals['_TUNNEL_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_TUNNEL_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_TUNNELGROUP']._serialized_start=97636
  _globals['_TUNNELGROUP']._serialized_end=97950
  _globals['_TUNNELGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_TUNNELGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_TUNNELTERMINATION']._serialized_start=97953
  _globals['_TUNNELTERMINATION']._serialized_end=106022
  _globals['_TUNNELTERMINATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_TUNNELTERMINATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VLAN']._serialized_start=106025
  _globals['_VLAN']._serialized_end=106798
  _globals['_VLAN_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VLAN_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VLANGROUP']._serialized_start=106801
  _globals['_VLANGROUP']._serialized_end=107620
  _globals['_VLANGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VLANGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VLANTRANSLATIONPOLICY']._serialized_start=107622
  _globals['_VLANTRANSLATIONPOLICY']._serialized_end=107720
  _globals['_VLANTRANSLATIONRULE']._serialized_start=107723
  _globals['_VLANTRANSLATIONRULE']._serialized_end=107916
  _globals['_VMINTERFACE']._serialized_start=107919
  _globals['_VMINTERFACE']._serialized_end=109018
  _globals['_VMINTERFACE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VMINTERFACE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VRF']._serialized_start=109021
  _globals['_VRF']._serialized_end=109618
  _globals['_VRF_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VRF_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALCHASSIS']._serialized_start=109621
  _globals['_VIRTUALCHASSIS']._serialized_end=110065
  _globals['_VIRTUALCHASSIS_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALCHASSIS_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALCIRCUIT']._serialized_start=110068
  _globals['_VIRTUALCIRCUIT']._serialized_end=110805
  _globals['_VIRTUALCIRCUIT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALCIRCUIT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALCIRCUITTERMINATION']._serialized_start=110808
  _globals['_VIRTUALCIRCUITTERMINATION']._serialized_end=111287
  _globals['_VIRTUALCIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALCIRCUITTERMINATION_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALCIRCUITTYPE']._serialized_start=111290
  _globals['_VIRTUALCIRCUITTYPE']._serialized_end=111655
  _globals['_VIRTUALCIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALCIRCUITTYPE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALDEVICECONTEXT']._serialized_start=111658
  _globals['_VIRTUALDEVICECONTEXT']._serialized_end=112375
  _globals['_VIRTUALDEVICECONTEXT_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALDEVICECONTEXT_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALDISK']._serialized_start=112378
  _globals['_VIRTUALDISK']._serialized_end=112759
  _globals['_VIRTUALDISK_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALDISK_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_VIRTUALMACHINE']._serialized_start=112762
  _globals['_VIRTUALMACHINE']._serialized_end=113873
  _globals['_VIRTUALMACHINE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_VIRTUALMACHINE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_WIRELESSLAN']._serialized_start=113876
  _globals['_WIRELESSLAN']._serialized_end=114934
  _globals['_WIRELESSLAN_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_WIRELESSLAN_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_WIRELESSLANGROUP']._serialized_start=114937
  _globals['_WIRELESSLANGROUP']._serialized_end=115375
  _globals['_WIRELESSLANGROUP_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_WIRELESSLANGROUP_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_WIRELESSLINK']._serialized_start=115378
  _globals['_WIRELESSLINK']._serialized_end=116331
  _globals['_WIRELESSLINK_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_WIRELESSLINK_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CUSTOMFIELD']._serialized_start=116334
  _globals['_CUSTOMFIELD']._serialized_end=121197
  _globals['_CUSTOMFIELDCHOICESET']._serialized_start=121200
  _globals['_CUSTOMFIELDCHOICESET']._serialized_end=121506
  _globals['_JOURNALENTRY']._serialized_start=121509
  _globals['_JOURNALENTRY']._serialized_end=130166
  _globals['_JOURNALENTRY_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_JOURNALENTRY_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_MODULETYPEPROFILE']._serialized_start=130169
  _globals['_MODULETYPEPROFILE']._serialized_end=130561
  _globals['_MODULETYPEPROFILE_CUSTOMFIELDSENTRY']._serialized_start=6400
  _globals['_MODULETYPEPROFILE_CUSTOMFIELDSENTRY']._serialized_end=6491
  _globals['_CUSTOMLINK']._serialized_start=130564
  _globals['_CUSTOMLINK']._serialized_end=132652
  _globals['_INGESTERSERVICE']._serialized_start=132654
  _globals['_INGESTERSERVICE']._serialized_end=132732
# @@protoc_insertion_point(module_scope)
